using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using System.Security.Principal;
using Vha.Vtk.Common;
using Vha.Vtk.TimeKeeping;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using System.Text;
using Vha.Vss.Utility;

namespace VTK.DailyTimeKeeping
{
	/// <summary>
	/// Summary description for SingleDayPosting.
	/// </summary>
	public class MultipleDayEdit : System.Web.UI.Page
	{
		protected System.Web.UI.HtmlControls.HtmlForm myForm;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.DropDownList CombinationList;
		protected System.Web.UI.WebControls.DropDownList DayList;
		protected System.Web.UI.WebControls.DropDownList HourList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label DataGridHeader;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.DataGrid TimeSheetDataGrid;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.DataGrid CombinationDataGrid;
		protected System.Web.UI.WebControls.Label MonthLabel;
		protected System.Web.UI.WebControls.Label ChooseVolunteerLabel;
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.DropDownList MonthList;
		protected System.Web.UI.WebControls.Panel ChooserPanel;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Panel EditPanel;
		protected System.Web.UI.WebControls.ImageButton Last;
		protected System.Web.UI.WebControls.ImageButton Next;
		protected System.Web.UI.WebControls.ImageButton Prev;
		protected System.Web.UI.WebControls.ImageButton First;
		protected System.Web.UI.WebControls.Panel PagerPanel;
		protected System.Web.UI.WebControls.Label PageStats;
		protected System.Web.UI.WebControls.Button ResetButton;
		protected System.Web.UI.WebControls.Button SearchButton;
		protected System.Web.UI.WebControls.TextBox SearchText;
		protected System.Web.UI.WebControls.DropDownList SearchOptionList;
		protected System.Web.UI.WebControls.Panel SearchPanel;
		protected VTK.Volunteer.VolunteerChooserControl VolunteerChooserControl1;
	
		public MultipleDayEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Multiple Postings Regular Hours")) 
				{
					if (!Page.IsPostBack)
					{
						//set today to current date time
						DateTime today = DateTime.Now ;

						DataSet dsm = Vha.Vtk.MealTickets.MealsProvided.GetMonthsList() ;
						DataTable dtm = dsm.Tables["MonthsList"] ;

						//define columns in list box
						MonthList.DataTextField = "Display" ;
						MonthList.DataValueField = "Month" ;

						//bind monthlist to DataTable
						MonthList.DataSource = dtm ;
						MonthList.DataBind() ;
						dsm.Dispose() ;
						dtm.Dispose() ;

						//if we have no months, then we can't continue
						if (MonthList.Items.Count < 1)
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "There are no available Months") ;
							DeleteButton.Enabled = false ;
							NewButton.Enabled = false ;
							PostButton.Enabled = false ;
							ChooseButton.Enabled = false ;
						}
						else
						{
							// set month to return value or current
							if (ViewState["month"] != null)
							{ MonthList.SelectedIndex = Convert.ToInt32(ViewState["month"].ToString()) ;}
							else
							{ VtkUtility.SetSelectedSingle(MonthList.Items, today.Month.ToString()) ;}

							if (ViewState["volId"] != null)
							{
								RefreshVolunteer() ;
							}
							else
							{ ChooseVolunteerLabel.Text = "[none selected]" ;}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					ViewState["stnId"] = VtkPageHeader1.DivSelectedId.ToString();
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}	
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheet Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheet Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheet Record: " + err.Message) ;}
		}

		override protected bool OnBubbleEvent(object Sender, EventArgs e) 
		{
			bool bubbleValue = false ;
			if (VolunteerChooserControl1.VolunteerChooserSuccess)
			{
				//check if volunteer has been terminated
				if (VolunteerChooserControl1.VolunteerChooserTerminated)
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer has been TERMINATED, No actions allowed") ;
					bubbleValue = true ;
				}
				else
				{
					ViewState["volId"] = VolunteerChooserControl1.VolunteerChooserId.ToString() ;
					ViewState["volName"] = VolunteerChooserControl1.VolunteerChooserName.ToString() ;
					ViewState["volTerm"] = VolunteerChooserControl1.VolunteerChooserTerminated.ToString() ;
					bubbleValue = true ;
					RefreshVolunteer() ;
				}
				VolunteerChooserControl1.BubbleEventClear() ;
			}
			return bubbleValue ;
		}

		private void SetFields()
		{
			//clear fields
			DayList.SelectedIndex = 0 ;
			MonthLabel.Text = MonthList.SelectedItem.Text ;
			CombinationList.SelectedIndex =0 ;
			HourList.SelectedIndex = 0 ;
			ViewState["timeVersion"] = string.Empty ;
			DeleteButton.Enabled = false ;
		}

		private string MissingFields()
		{
			bool flag = false ;
			string fields = string.Empty ;
			if (ViewState["volId"] == null)
			{
				fields = "Volunteer" ;
				flag = true;
			}
			else if (Convert.ToInt32(CombinationList.SelectedItem.Value) < 0)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Combination Code" ;
				flag = true ;
			}
			if (DayList.SelectedIndex < 1)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Date" ;
				flag = true ;
			}
			if (HourList.SelectedIndex < 1)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Hours" ;
				flag = true ;
			}

			return fields ;
		}

		private void GetDataGrid(int volId)
		{
			//if we have no months, then we can't continue
			if (MonthList.Items.Count > 0)
			{
				try
				{
					//clear current fields
					SetFields() ;

					//must have a station and month/year
					string moyr = MonthList.SelectedItem.Text ;
					int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
					int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;
					int siteId = VtkPageHeader1.DivSelectedId ;
					string sText = SearchText.Text ;
					string sOption = SearchOptionList.SelectedItem.Value ;
					//populate list of TimeSheets, get dataset(volunteer, site, month, year, include closed records)
					//ref. Vha.Vtk.TimeKeeping.VolunteerHours
					DataSet dsts ;
					DataTable dtts ;
					if (sOption == "HoursWorked")
					{
						dsts = VolunteerHours.GetVolunteersMonthlyQuickList(volId, siteId, month, year, false) ;
						//must have a search value
						if (sText != string.Empty)
						{ dsts.Tables["VolunteerHourListMonthly"].DefaultView.RowFilter =  sOption + " = " + Convert.ToInt32(sText) ;}
						dtts = dsts.Tables["VolunteerHourListMonthly"] ;
					}
					else
					{
						dsts = VolunteerHours.GetVolunteersMonthlyQuickList(volId, siteId, month, year, false) ;
						//must have a search value
						if (sText != string.Empty)
						{ dsts.Tables["VolunteerHourListMonthly"].DefaultView.RowFilter =  sOption + " LIKE '" + sText + "*'" ;}
						dtts = dsts.Tables["VolunteerHourListMonthly"] ;
					}
					//bind datagrid to DataTable
					TimeSheetDataGrid.DataSource = dtts ;
					TimeSheetDataGrid.DataBind() ;
					dsts.Dispose() ;

					SetPagerStats();
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheets Grid: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheets Grid: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Time Sheets Grid: " + err.Message) ;}
			}
		}

		private void GetCombinationList(int volId)
		{
			try
			{
				int siteId = VtkPageHeader1.DivSelectedId ;
				//populate list of Combination, get dataset
				//ref. Vha.Vtk.TimeKeeping.CombinationAssignment
				DataSet dscom = CombinationAssignment.GetActiveQuickList(volId, siteId) ;
				DataTable dtcom = dscom.Tables["CombinationAssignmentList"] ;

				//define columns in list box
				CombinationList.DataTextField = "DisplayName" ;
				CombinationList.DataValueField = "Id" ;
				// if no combinations, show message
				if (dtcom.Rows.Count < 1)
				{
					//add a row
					DataRow drcom = dtcom.NewRow() ;
					drcom["DisplayName"] = " *Volunteer has no Combination Code* " ;
					drcom["Id"] = "-1" ;
					dtcom.Rows.Add(drcom) ;
				}

				//bind list box to DataTable and cleanup
				CombinationList.DataSource = dtcom ;
				CombinationList.DataBind() ;
				//bind to datagrid
				CombinationDataGrid.DataSource = dtcom ;
				CombinationDataGrid.DataBind() ;
				dscom.Dispose() ;
				dtcom.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Combination List: " + err.Message) ;}
		}

		private void RefreshVolunteer()
		{
			//volunteer has been choosen, update fields and remove choosercontrol
			int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
			ChooseVolunteerLabel.Text = ViewState["volName"].ToString() ;
			DataGridHeader.Text = ViewState["volName"].ToString() ;
			SearchText.Text = string.Empty ;
			SearchOptionList.SelectedIndex = 0 ;
			GetDataGrid(volId) ;
			GetCombinationList(volId) ;
			//turn off chooser
			ChooserPanel.Visible = false ;
			EditPanel.Visible = true ;
		}

		private DateTime CheckDay(int day)
		{
			DateTime d = DateTime.MinValue ;
			string moyr = MonthList.SelectedItem.Text ;
			int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
			int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;

			try
			{
				d = new DateTime(year, month, day) ;
				ViewState["date"] = d.ToShortDateString();
				return d ;
			}
			catch
			{ return d ;}
		}

		private bool RecordExists()
		{
			// MSG 11/22/2004 Hour's breakout change.
			// Added routine to check now primary key components.

			for (int i = 0; i < TimeSheetDataGrid.Items.Count; i++)
			{
				DateTime dViewStateDate, dGridDate;
				dViewStateDate = Convert.ToDateTime(ViewState["date"].ToString());
				dGridDate = Convert.ToDateTime(TimeSheetDataGrid.Items[i].Cells[1].Text);

				if( ViewState["volId"].ToString() == TimeSheetDataGrid.Items[i].Cells[5].Text &&
					ViewState["stnId"].ToString() == TimeSheetDataGrid.Items[i].Cells[6].Text  &&
					ViewState["orgId"].ToString() == TimeSheetDataGrid.Items[i].Cells[7].Text  &&
					ViewState["svcId"].ToString() == TimeSheetDataGrid.Items[i].Cells[8].Text  &&
					ViewState["schId"].ToString() == TimeSheetDataGrid.Items[i].Cells[9].Text  &&
					dViewStateDate.ToShortDateString() == dGridDate.ToShortDateString() )
					return true;
			}
			return false;
		}

		private void GetTimeButton_Click(object sender, System.EventArgs e)
		{
			if(ViewState["volId"] != null)
			{ GetDataGrid(Convert.ToInt32(ViewState["volId"].ToString())) ;}
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			ViewState["volId"] = null ;
			ViewState["volName"] = null ;
			ViewState["volTerm"] = null ;
			//turn off chooser
			ChooserPanel.Visible = true ;
			EditPanel.Visible = false ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			// MSG 11/22/2004 Hour's breakout change.
			// Removed ID as primary key added Vol ID, Stn ID, Org ID,
			// Svc ID, Sch ID and Dateworked as primary key.

			//get selected timesheet
			int ivolId = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[5].Text);
			int istnId = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[6].Text);
			int iorgId = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[7].Text);
			int isvcId = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[8].Text);
			int ischId = Convert.ToInt32(TimeSheetDataGrid.SelectedItem.Cells[9].Text);
			DateTime ddate = Convert.ToDateTime(TimeSheetDataGrid.SelectedItem.Cells[1].Text);
					
			try
			{
				//create handle and save id and version
				Vha.Vtk.TimeKeeping.VolunteerHours tshdl = new VolunteerHours(ivolId, istnId, iorgId, ischId, isvcId, ddate, VtkUtility.GetAppCon());
				// set current month and year in header
				VtkUtility.SetSelectedSingle(MonthList.Items, tshdl.DateWorked.Month.ToString()) ;
				//VtkUtility.SetSelectedSingle(YearList.Items, tshdl.DateWorked.Year.ToString()) ;
				//clear fields, it will alse set month & year in body
				SetFields() ;
				//set viewstate variables
				ViewState["volId"] = tshdl.VolunteerId ;
				ViewState["stnId"] = tshdl.StationId ;
				ViewState["orgId"] = tshdl.OrganizationId ;
				ViewState["svcId"] = tshdl.BenefitingServiceId ;
				ViewState["schId"] = tshdl.ScheduleId ;
				ViewState["date"] = tshdl.DateWorked ;
				ViewState["timeVersion"] = tshdl.Version.ToString();
				//populate fields
				if (tshdl.DateWorked > DateTime.MinValue)
				{ DayList.SelectedIndex = tshdl.DateWorked.Day ;}
				else
				{ DayList.SelectedIndex = 0 ;}

				if (tshdl.HoursWorked > 0)
				{
					VtkUtility.SetSelectedSingle(HourList.Items, tshdl.HoursWorked.ToString());
				}
				else
				{ HourList.SelectedIndex = 0 ;}

				int org = tshdl.OrganizationId ;
				int svc = tshdl.BenefitingServiceId ;
				int sch = tshdl.ScheduleId ;
				int comId = int.MinValue ;

				foreach (DataGridItem dgi in CombinationDataGrid.Items)
				{
					if (dgi.Cells[1].Text == org.ToString())
					{
						if (dgi.Cells[2].Text == sch.ToString())
						{
							if (dgi.Cells[3].Text == svc.ToString())
							{ comId = Convert.ToInt32(dgi.Cells[0].Text) ;}
						}
					}
				}
				if (comId > int.MinValue)
				{
					VtkUtility.SetSelectedSingle(CombinationList.Items,comId.ToString());
				}
				//enable buttons
				DeleteButton.Enabled = true ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Timesheet Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Timesheet Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Timesheet Record: " + err.Message) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			// MSG 11/22/2004 Hour's breakout change.
			// Removed ID as primary key added Vol ID, Stn ID, Org ID,
			// Svc ID, Sch ID and Dateworked as primary key.

			//check for required fields
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following field(s) are Required: " + missingdata) ;}
			else
			{
				//check DayList
				DateTime DateWorked = CheckDay(Convert.ToInt32(DayList.SelectedItem.Value.ToString())) ;
				if (DateWorked == DateTime.MinValue)
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, "An incorrect date was entered") ;
				}
				else
				{
					//disable post button until we are done
					PostButton.Enabled = false ;
					//flag to check if version number has changed
					bool versionOk = true ;
					int volId = Convert.ToInt32(ViewState["volId"].ToString()) ;
					Vha.Vtk.TimeKeeping.VolunteerHours tshdl ;
					string moyr = MonthList.SelectedItem.Text ;
					int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
					int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;

					//check for closed records
					if (Vha.Vtk.Kernel.Data.SystemTables.RollupLog.IsMonthEditable(month, year))
					{
						try
						{
							//existing record
							if (RecordExists())
							{
								int ivolId = Convert.ToInt32(ViewState["volId"].ToString());
								int istnId = Convert.ToInt32(ViewState["stnId"].ToString());
								int iorgId = Convert.ToInt32(ViewState["orgId"].ToString());
								int isvcId = Convert.ToInt32(ViewState["svcId"].ToString());
								int ischId = Convert.ToInt32(ViewState["schId"].ToString());
								DateTime ddate = Convert.ToDateTime(ViewState["date"].ToString());
					
								//create handle and open current record
								tshdl = new VolunteerHours(ivolId, istnId, iorgId, ischId, isvcId, ddate, VtkUtility.GetAppCon()) ;

								//check version
								if (ViewState["timeVersion"].ToString() != tshdl.Version.ToString())
								{
									VtkUtility.ErrMsgAdd(ErrorMessage, "Current Volunteer Time Sheet record has changed while you were editing, Please press EXIT and start over. ") ;
									versionOk = false ;
								}
							}
								//new record
							else
							{
								//create handle and open new record
								tshdl = VolunteerHours.AddRecord(volId, VtkUtility.GetAppCon()) ;
							}
							if (versionOk)
							{
								//save current fields
								tshdl.StationId = Convert.ToInt32(ViewState["stnId"].ToString());
								tshdl.DateWorked = DateWorked ;
								tshdl.HoursWorked = Convert.ToInt32(HourList.SelectedItem.Value.ToString()) ;
								//seperate combination, find in datagrid
								string comId = CombinationList.SelectedItem.Value.ToString() ;
								int org = int.MinValue ;
								int sch = int.MinValue ;
								int svc = int.MinValue ;

								foreach (DataGridItem dgi in CombinationDataGrid.Items)
								{
									if (dgi.Cells[0].Text == comId)
									{
										org = Convert.ToInt32(dgi.Cells[1].Text) ;
										sch = Convert.ToInt32(dgi.Cells[2].Text) ;
										svc = Convert.ToInt32(dgi.Cells[3].Text) ;
										break ;
									}
								}
								tshdl.OrganizationId = org ;
								tshdl.ScheduleId = sch ;
								tshdl.BenefitingServiceId = svc ;

								//save and close
								tshdl.Save() ;
								tshdl.Dispose() ;
								//update confirmation message
								ConfirmationMessage.Text = "Record Posted!" ;
								//update DataGrid
								GetDataGrid(volId) ;

								//clear fields and disable buttons
								SetFields() ;
								DeleteButton.Enabled = false ;
								//set default values
							}
						}
						catch (VhaValidationException valErr)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Timesheet Record: " + valErr.Message) ;}
						catch (VhaTransactionException transErr)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Timesheet Record: " + transErr.Message) ;}
						catch (Exception err)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Timesheet Record: " + err.Message) ;}
						finally
						{ PostButton.Enabled = true ;}
					}
					else
					{
						SetFields() ;
						VtkUtility.ErrMsgAdd(ErrorMessage, "Time Sheets are CLOSED for the given month and year, record NOT posted") ;
					}
				}
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			string moyr = MonthList.SelectedItem.Text ;
			int month = Convert.ToInt32(MonthList.SelectedItem.Value) ;
			int year =  Convert.ToInt32(moyr.Substring((moyr.IndexOf(" ")+1), 4)) ;
			//check for closed records
			if (Vha.Vtk.Kernel.Data.SystemTables.RollupLog.IsMonthEditable(month, year))
			{
				SetFields() ;
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Time Sheets are CLOSED for the given month and year, No actions allowed") ;
			}
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			// MSG 11/22/2004 Hour's breakout change.
			// Removed ID as primary key added Vol ID, Stn ID, Org ID,
			// Svc ID, Sch ID and Dateworked as primary key.

			if (RecordExists())
			{
				//get id of existing record
				int ivolId = Convert.ToInt32(ViewState["volId"].ToString());
				int istnId = Convert.ToInt32(ViewState["stnId"].ToString());
				int iorgId = Convert.ToInt32(ViewState["orgId"].ToString());
				int isvcId = Convert.ToInt32(ViewState["svcId"].ToString());
				int ischId = Convert.ToInt32(ViewState["schId"].ToString());
				DateTime ddate = Convert.ToDateTime(ViewState["date"].ToString());


				Vha.Vtk.TimeKeeping.VolunteerHours tshdl ;
				try
				{
					//create handle and open current record
					tshdl = new VolunteerHours(ivolId, istnId, iorgId, ischId, isvcId, ddate, VtkUtility.GetAppCon()) ;
					//delete, save and close
					tshdl.Delete() ;
					tshdl.Save() ;
					tshdl.Dispose() ;

					//update confirmation message
					ConfirmationMessage.Text = "Record Deleted!" ;
					//update DataGrid
					GetDataGrid(ivolId) ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Timesheet Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Timesheet Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Timesheet Record: " + err.Message) ;}
			}

		}

		private void SearchButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				if (SearchText.Text == string.Empty)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "Sort text is invalid.") ;}
				else
				{
					TimeSheetDataGrid.CurrentPageIndex = 0;
					GetDataGrid(Convert.ToInt32(ViewState["volId"].ToString())) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
		}

		private void ResetButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				//reset search fields
				SearchText.Text = string.Empty ;
				SearchOptionList.SelectedIndex = 0 ;
				TimeSheetDataGrid.CurrentPageIndex = 0;
				GetDataGrid(Convert.ToInt32(ViewState["volId"].ToString())) ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error searching the table: " + err.Message) ;}
		}

		#region Paging Data

		private void PageGrid(object obj, DataGridPageChangedEventArgs e)
		{
			TimeSheetDataGrid.CurrentPageIndex = 0;
			GetDataGrid(Convert.ToInt32(ViewState["volId"].ToString())) ;
		}

		private void SetPagerStats()
		{
			int currentPageIndex = TimeSheetDataGrid.CurrentPageIndex + 1;
			int pageCount = TimeSheetDataGrid.PageCount;

			PageStats.Text = "Page " + currentPageIndex.ToString() + " of " + pageCount.ToString();
		}

		private void Pager_Click(object sender, System.Web.UI.ImageClickEventArgs e)
		{			
			ImageButton objSender = (ImageButton)sender;
			switch(objSender.CommandArgument)
			{
				case "PREV":
					if(TimeSheetDataGrid.CurrentPageIndex > 0)
						TimeSheetDataGrid.CurrentPageIndex --;
					break;
				case "NEXT":
					if(TimeSheetDataGrid.CurrentPageIndex < (TimeSheetDataGrid.PageCount - 1))
						TimeSheetDataGrid.CurrentPageIndex ++;
					break;
				case "FIRST":
					TimeSheetDataGrid.CurrentPageIndex = 0;
					break;
				case "LAST":					
					TimeSheetDataGrid.CurrentPageIndex = TimeSheetDataGrid.PageCount - 1;
					break;
			}
			GetDataGrid(Convert.ToInt32(ViewState["volId"].ToString())) ;
		}
		#endregion

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.MonthList.SelectedIndexChanged += new System.EventHandler(this.GetTimeButton_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.SearchButton.Click += new System.EventHandler(this.SearchButton_Click);
			this.ResetButton.Click += new System.EventHandler(this.ResetButton_Click);
			this.TimeSheetDataGrid.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.PageGrid);
			this.TimeSheetDataGrid.SelectedIndexChanged += new System.EventHandler(this.EditButton_Click);
			this.First.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Prev.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Next.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Last.Click += new System.Web.UI.ImageClickEventHandler(this.Pager_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
