using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Donations;
using Vha.Vtk.TimeKeeping;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for Awards Management.
	/// </summary>
	public class AwardsManagement : System.Web.UI.Page
	{
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Panel DatePanel;
		protected System.Web.UI.WebControls.RadioButtonList AdultYouthList;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.Panel AwardPanel;
		protected System.Web.UI.WebControls.RadioButtonList ShowTerminatedRadioButtonList1;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.Button PostButton1;
		protected System.Web.UI.WebControls.DataGrid AwardGrid;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			//Page.RegisterOnSubmitStatement("PostButton", "return confirm('                !!!!WARNING!!!!  \\n This process will code all the volunteer awards selected. \\n Remember this process is irreversible once posted. \\n Do you still want to proceed?')") ;

			try
			{
				if (VtkPageHeader1.IsDivSelected("Awards Coding"))
				{

					if (!Page.IsPostBack)
					{
						//DatePanel contains parameters to select awards, ask this first
						DatePanel.Visible = true ;
						PrintButton.Visible = true ;
						AwardPanel.Visible = false ;
						PostButton.Visible = false ;
						InitializeDates() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
					
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Award List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Award List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Award List: " + err.Message) ;}

		}

		private void UpdateAwardGrid(string sortExpress, string AdltYth, int showTerm, System.DateTime inputDt)
		{
			DataSet dsAward ;
			DataTable dtAward ;
			string displayName = string.Empty ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			string error = "";
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
//				These values are now passed in as arguments.
//				string AdltYth = AdultYouthList.SelectedItem.Value;
//				string showTerm = ShowTerminatedRadioButtonList1.SelectedItem.Value ;
//				System.DateTime inputDt = Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);

				dsAward = Vha.Vtk.Common.Award.GetQuickListBy_StationId(siteId, AdltYth, showTerm, inputDt);		
				dtAward = dsAward.Tables["GetQuickListBy_StationId"] ;

				AwardGrid.DataSource = dtAward ;
//				dtAward.DefaultView.Sort = sortExpress;
				AwardGrid.DataBind() ;
				//SetPagerStats();
				dsAward.Dispose() ;
				dtAward.Dispose() ;
			}
		}

		private void AwardGrid_SortCommand(object source, System.Web.UI.WebControls.DataGridSortCommandEventArgs e)
		{
			// get input variables for sort
			DateTime beginDate = Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			string adultYouth = AdultYouthList.SelectedItem.Value;
			int terminated = 0 ;
			if (ShowTerminatedRadioButtonList1.SelectedIndex == 1) 
				terminated = 1;

			if(e.SortExpression == "VolName")
			{

				UpdateAwardGrid(e.SortExpression, adultYouth, terminated, beginDate);
			}
			else
			{
				UpdateAwardGrid(e.SortExpression + ", VolName", adultYouth, terminated, beginDate);
			}
		}

		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+1); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					// put a 0 in front of the month if it is month 1-9, you need this or the validator will fail
					string monthdisplay = month.ToString();
					if (month < 10) monthdisplay = "0" + monthdisplay;

					// get number of days in the month
					int daysInMonth = System.DateTime.DaysInMonth(year, month);

					count = count + 1;
					BegMonthYearList.Items.Add(monthdisplay + "/" + daysInMonth.ToString() + "/" + year.ToString());

					// stop if current month year
					if ((month.ToString() + "/" + year.ToString()) == 
						(System.Convert.ToString(System.DateTime.Today.ToString("M/yyyy"))))
					{
						break;
					}
				}
			}
			// set 12 months from today as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			int begmonthcounter=BegMonthYearList.Items.Count-12;
			if (begmonthcounter<0) begmonthcounter=0;
			BegMonthYearList.SelectedIndex=begmonthcounter;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.AwardGrid.SortCommand += new System.Web.UI.WebControls.DataGridSortCommandEventHandler(this.AwardGrid_SortCommand);
			this.PostButton1.Click += new System.EventHandler(this.PostButton1_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			//CheckBox cbx = new CheckBox();
			string awardList = "";
			int saveResult = 0;
			awardList = Show_SelectedNew();
			saveAwards(awardList, out saveResult);
			if(saveResult != 0)
			{
				// get input variables for sort
				DateTime beginDate = Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
				string adultYouth = AdultYouthList.SelectedItem.Value;
				int terminated = 0 ;
				if (ShowTerminatedRadioButtonList1.SelectedIndex == 1) 
					terminated = 1;
				UpdateAwardGrid("AwardCode, VolName", adultYouth, terminated, beginDate );
				ConfirmationMessage.Text = "Record posted!";
			}
		}

		private void saveAwards(string awardList, out int sResult)
		{
			sResult=0;
			try
			{
				sResult = Vha.Vtk.TimeKeeping.StationProfile.SaveAwards(awardList, VTK.Utility.VtkUtility.GetAppCon());
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving Award List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving Award List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving Award List: " + err.Message) ;}


		}

		private string Show_SelectedNew()
		{
			string awardList="";

			foreach( DataGridItem di in AwardGrid.Items )
			{
				CheckBox cb = (CheckBox)di.FindControl("chkAward") ;
				if( cb !=null && cb.Checked )
				{
					if (awardList != "")
					{
						awardList+= "P";
					}
					awardList+= di.Cells[9].Text + "A";
					awardList+= di.Cells[8].Text;
				}
			}

			return awardList;
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			// get input variables for sort
			DateTime beginDate = Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			string adultYouth = AdultYouthList.SelectedItem.Value;
			int terminated = 0 ;
			if (ShowTerminatedRadioButtonList1.SelectedIndex == 1) 
				terminated = 1;
			
			//DatePanel.Visible = false ;
			BegMonthYearList.Enabled = false;
			AdultYouthList.Enabled = false;
			ShowTerminatedRadioButtonList1.Enabled = false;
			PrintButton.Visible = false ;
			AwardPanel.Visible = true ;
			PostButton.Visible = true ;

			UpdateAwardGrid("AwardCode, VolName", adultYouth, terminated, beginDate );
			Page.RegisterOnSubmitStatement("PostButton", "return confirm('         !!!!WARNING!!!!  \\n This process will code the awards for the selected volunteers.\\n The process may take some time to post the awards and \\n it is an irreversible process. Do you want to proceed?')") ;

		}

		private void PostButton1_Click(object sender, System.EventArgs e)
		{
			PostButton_Click(sender, e);
		}

	}
}
