using System;
using System.Collections;
using System.Configuration;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using Vha.Vss.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for MealListEdit.
	/// </summary>
	public class MealListEdit : System.Web.UI.Page
	{
		protected IDictionary config;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.TextBox VolunteerText;
		protected System.Web.UI.WebControls.DropDownList VolunteerList;
		protected System.Web.UI.WebControls.Button ChooseButton;
		protected System.Web.UI.WebControls.TextBox UnscheduledText;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.DataGrid MealListGrid;
		protected System.Web.UI.WebControls.Label MealListDateLabel;
		protected System.Web.UI.WebControls.ListBox TermList;
		protected System.Web.UI.WebControls.Panel Panel1;
		protected System.Web.UI.WebControls.Label MealNumberLabel;
		protected System.Web.UI.WebControls.RadioButtonList MealNumberList;
		protected System.Web.UI.WebControls.Label FirstMealLabel;
		protected System.Web.UI.WebControls.Label SecondMealLabel;
		protected System.Web.UI.WebControls.Button NewButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.DropDownList DeviceList;

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Edit Meals")) 
				{
					if (!Page.IsPostBack) 
					{
						/*
						try
						{
							config = (IDictionary)ConfigurationSettings.GetConfig("VssConfiguration/Application");
						}
						catch{}
						PrinterList.XmlDataSourceParms.XmlDocumentObject.Load((string)config["Printers"]);
						PrinterList.XmlDataSourceParms.XPathQuery = "/Printers/Division[@Id='" + VtkPageHeader1.DivSelectedId.ToString() + "]/Printer";
						*/
						SetFields() ;
						int siteId = VtkPageHeader1.DivSelectedId ;
						int numberMeal = 1 ;
						if (ViewState["numberMeal"] != null)
						{
							numberMeal = Convert.ToInt32(ViewState["numberMeal"].ToString()) ;
						}
						else
						{
							Vha.Vtk.Common.StationParameters sphdl = new Vha.Vtk.Common.StationParameters(siteId, VtkUtility.GetAppCon()) ;
							numberMeal = sphdl.NumberOfMeals ;
							//if site supports multiple meals, prompt user for the right one
							if (numberMeal > 1)
							{
								Panel1.Visible = false ;
								MealNumberList.Visible = true ;
								MealNumberLabel.Visible = true ;
							}
							else
							{ ViewState["numberMeal"] = "1" ;}
						}
						//populate meal grid
						GetMealListGrid(numberMeal) ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + err.Message) ;}
		}


		private void SetFields()
		{
			//clear fields
			VolunteerList.SelectedIndex = 0 ;
			VolunteerText.Text = string.Empty ;
			UnscheduledText.Text = string.Empty ;
			VolunteerList.Visible = false ;
			UnscheduledText.Visible = true ;
			ViewState["volId"] = string.Empty ;
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if ((ViewState["volId"].ToString() == string.Empty)&&(UnscheduledText.Text == string.Empty))
			{ fields = "A Volunteer or an Unscheduled Volunteer Name is required!" ;}
			if ((ViewState["volId"].ToString() != string.Empty)&&(UnscheduledText.Text != string.Empty))
			{ fields = "Enter a Volunteer or an Unscheduled Volunteer Name, not both!" ;}
			return fields ;
		}

		private void MealNumberList_Click(object sender, System.EventArgs e)
		{
			int numberMeal = Convert.ToInt32(MealNumberList.SelectedItem.Value.ToString()) ;
			ViewState["numberMeal"] = numberMeal.ToString() ;
			Panel1.Visible = true ;
			MealNumberList.Visible = false ;
			MealNumberLabel.Visible = false ;
			//populate meal grid
			GetMealListGrid(numberMeal) ;
		}

		private void GetMealListGrid(int numberMeal)
		{
			try
			{
				//clear current fields
				SetFields() ;
				DateTime today = DateTime.Now.Date ;
				int siteId = VtkPageHeader1.DivSelectedId ;
				//last parameter of GetMealTicketList is for volunteer id, 0 means all volunteers
//				DataSet dsml = Vha.Vtk.MealTickets.MealsProvided.GetMealTicketList(today, siteId, numberMeal, 0) ;

//				DataTable dtml = dsml.Tables["MealTicketList"] ;

				NameObjectCollection mealList = Vha.Vtk.MealTickets.MealsProvided.GetMealTicketDRList(today, siteId, numberMeal, 0) ;
				NameObjectCollection mealRec = new NameObjectCollection();
				DataTable dtMeal = new DataTable("MealTicketList");

				DataColumn dcMeal;
				DataRow drMeal;
				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				//1
				dcMeal= new DataColumn();
				dcMeal.DataType = System.Type.GetType("System.Int32");
				dcMeal.ColumnName = "MealId";
				dtMeal.Columns.Add(dcMeal);

				//2
				dcMeal= new DataColumn();
				dcMeal.DataType = System.Type.GetType("System.Int32");
				dcMeal.ColumnName = "VolunteerId";
				dtMeal.Columns.Add(dcMeal);

				//3
				dcMeal= new DataColumn();
				dcMeal.DataType  = typeof(string);
				dcMeal.MaxLength = 120;
				dcMeal.ColumnName = "VolunteerName";
				dtMeal.Columns.Add(dcMeal);

				//4
				dcMeal= new DataColumn();
				dcMeal.DataType  = typeof(bool);
				dcMeal.ColumnName = "IsUnScheduled";
				dtMeal.Columns.Add(dcMeal);

				//5
				dcMeal= new DataColumn();
				dcMeal.DataType  = typeof(string);
				dcMeal.MaxLength = 120;
				dcMeal.ColumnName = "UnscheduledName";
				dtMeal.Columns.Add(dcMeal);

				//6
				dcMeal= new DataColumn();
				dcMeal.DataType  = System.Type.GetType("System.DateTime");
				dcMeal.ColumnName = "TimeLastPrinted";
				dtMeal.Columns.Add(dcMeal);

				//7
				dcMeal= new DataColumn();
				dcMeal.DataType  = typeof(string);
				dcMeal.MaxLength = 3;
				dcMeal.ColumnName = "IsReprinted";
				dtMeal.Columns.Add(dcMeal);

				//8
				dcMeal= new DataColumn();
				dcMeal.DataType = System.Type.GetType("System.Int32");
				dcMeal.ColumnName = "NumberOfMeal";
				dtMeal.Columns.Add(dcMeal);

				int mealCount;
				mealCount = mealList.Count;
				int intMeal;
				for (intMeal=1; intMeal <= mealCount; intMeal++)
				{
					mealRec = (NameObjectCollection)mealList.Get(intMeal-1);
					if (mealRec.Count > 0)
					{
						drMeal = dtMeal.NewRow();
						drMeal["MealId"] = (Int32)mealRec.Get("Column1");
						drMeal["VolunteerId"] = (Int32)mealRec.Get("Column2");
						drMeal["VolunteerName"] = (string)mealRec.Get("Column3");
						if (mealRec.Get("Column4") != System.DBNull.Value)
							drMeal["IsUnScheduled"] = (bool)mealRec.Get("Column4");
						else
							drMeal["IsUnScheduled"] = System.DBNull.Value;

						if (mealRec.Get("Column5") != System.DBNull.Value)
							drMeal["UnscheduledName"] = (string)mealRec.Get("Column5");
						else
							drMeal["UnscheduledName"] = System.DBNull.Value;

						if (mealRec.Get("Column6") != System.DBNull.Value)
							drMeal["TimeLastPrinted"] = (DateTime)mealRec.Get("Column6");
						else
							drMeal["TimeLastPrinted"] = System.DBNull.Value;

						drMeal["IsReprinted"] = (string)mealRec.Get("Column7");
						drMeal["NumberOfMeal"] = (Int32)mealRec.Get("Column8");
						
						dtMeal.Rows.Add(drMeal);
					}
				}

				//bind datagrid to DataTable
				MealListGrid.DataSource = dtMeal ;
				MealListGrid.DataBind() ;
//				dsml.Dispose() ;
				dtMeal.Dispose() ;
				mealList.Dispose();
				mealRec.Dispose();

				MealListDateLabel.Text = DateTime.Now.ToShortDateString() ;
				if (numberMeal == 1)
				{
					FirstMealLabel.Visible = true ;
					SecondMealLabel.Visible = false ;
				}
				else
				{
					FirstMealLabel.Visible = false ;
					SecondMealLabel.Visible = true ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Meal List: " + err.Message) ;}

		}

		private void ChooseVolunteer_Click(object sender, System.EventArgs e)
		{
			string volId ;
			string volName ;

			//this is when the user must choose from VolunteerList
			//check to see if they selected one
			if (VolunteerList.SelectedIndex > -1)
			{
				//get ID from list
				volId = VolunteerList.SelectedItem.Value.ToString() ;
				volName = VolunteerList.SelectedItem.Text.ToString() ;
				//check termination data in list
				bool term = false ;
				foreach (ListItem li in TermList.Items)
				{
					if (li.Value == volId)
					{
						//get termination date
						if (li.Text != null)
						{ 
							if (li.Text.ToString() != string.Empty)
							{term = true ;}
						}
						break ;
					}
				}
				if (term)
				{
					SetFields() ;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer has been TERMINATED, No actions allowed") ;
				}
				else
				{
					SetFields() ;
					ChooseButton.Enabled = true ;
					VolunteerText.Text = volName ;
					ViewState["volId"] = volId ;
					//disable unscheduledtext, can't have both fields
					UnscheduledText.Visible = false ;
				}
			}
		}

		private void ChooseButton_Click(object sender, System.EventArgs e)
		{
			int volId ;
			//remove spaces and check that name has at least 3 characters
			VolunteerText.Text = VolunteerText.Text.ToUpper().Trim() ;

			if (VolunteerText.Text.Length < 3)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first 3 or more characters of the Volunteer's last name and press 'Choose Volunteer'") ;}
			else
			{
				SelectCriteria sc = new SelectCriteria() ;
				sc.StartsWith = VolunteerText.Text ;
				sc.MaxRecords = 75 ;
				try
				{
					DataSet ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerList(sc, VtkPageHeader1.DivSelectedId, VtkUtility.GetAppCon()) ;
					DataTable dt = ds.Tables["VolunteerList"] ;

//					NameObjectCollection VolList = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerDRList(sc, VtkPageHeader1.DivSelectedId, VtkUtility.GetAppCon()) ;
//					NameObjectCollection VolRec = new NameObjectCollection();
//					DataTable dt = new DataTable("VolunteerList");
//
//					DataColumn dcVol;
//					DataRow drVol;
//					// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
//					//1
//					dcVol= new DataColumn();
//					dcVol.DataType = System.Type.GetType("System.Int32");
//					dcVol.ColumnName = "Id";
//					dt.Columns.Add(dcVol);
//
//					//2
//					dcVol= new DataColumn();
//					dcVol.DataType  = typeof(string);
//					dcVol.MaxLength = 120;
//					dcVol.ColumnName = "fullNameForReportsField";
//					dt.Columns.Add(dcVol);
//
//					//3
//					dcVol= new DataColumn();
//					dcVol.DataType  = System.Type.GetType("System.DateTime");
//					dcVol.ColumnName = "TerminationDate";
//					dt.Columns.Add(dcVol);
//
//
//					int VolCount;
//					VolCount = VolList.Count;
//					int intVol;
//					for (intVol=1; intVol <= VolCount; intVol++)
//					{
//						VolRec = (NameObjectCollection)VolList.Get(intVol-1);
//						if (VolRec.Count > 0)
//						{
//							drVol = dt.NewRow();
//							drVol["Id"] = (Int32)VolRec.Get("Column1");
//							drVol["fullNameForReportsField"] = (string)VolRec.Get("Column2");
//
//							if (VolRec.Get("Column3") != System.DBNull.Value)
//								drVol["TerminationDate"] = (DateTime)VolRec.Get("Column3");
//							else
//								drVol["TerminationDate"] = System.DBNull.Value;
//
//							dt.Rows.Add(drVol);
//						}
//					}

					//if only one record, set fields
					if (dt.Rows.Count == 1)
					{
						DataRow dr = dt.Rows[0] ;
						//check if volunteer has been terminated
						if ((dr["TerminationDate"].ToString() != null)&&(dr["TerminationDate"].ToString() != string.Empty))
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer has been TERMINATED, No actions allowed") ;}
						else
						{
							SetFields() ;
							VolunteerText.Text = dr["DisplayName"].ToString() ;
							volId = (int) dr["Id"] ;
							ViewState["volId"] = volId.ToString() ;
						}
					}
					else
					{
						//if more than one, use list
						if (dt.Rows.Count > 1)
						{

							//add the first row, uses Rows.InsertAt(
							DataRow dr = dt.NewRow() ;
							dr["DisplayName"] = " -Select Volunteer- " ;
							dr["Id"] = -1 ;
							dt.Rows.InsertAt(dr,0) ;

							VolunteerList.Visible = true ;
							//define columns in list box
							VolunteerList.DataTextField = "DisplayName" ;
							VolunteerList.DataValueField = "ID" ;

							//bind list box to DataTable
							VolunteerList.DataSource = dt ;
							VolunteerList.DataBind() ;

							//define column in term list box, this track termination date
							TermList.DataTextField = "TerminationDate" ;
							TermList.DataValueField = "ID" ;
							TermList.DataSource = dt ;
							TermList.DataBind() ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}
					}

					//ds.Dispose() ;
					dt.Dispose() ;
					//disable unscheduledtext, can't have both fields
					UnscheduledText.Visible = false ;

					}
					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
				}
			}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				string mealId = MealListGrid.SelectedItem.Cells[1].Text ;
				string volName = MealListGrid.SelectedItem.Cells[2].Text ;
				string printed = MealListGrid.SelectedItem.Cells[5].Text ;
				string reprint = "true" ;
				string price = string.Empty ;
				int siteId = VtkPageHeader1.DivSelectedId ;
				//if not volunteer name, get from unscheduled
				if (volName == "&nbsp;")
				{ volName = MealListGrid.SelectedItem.Cells[4].Text ;}
				//if not printed set reprint to "false"
				if (printed == "&nbsp;")
				{ reprint = "false" ;}
				//get meal price from site parameters
				Vha.Vtk.Common.StationParameters sphdl = new Vha.Vtk.Common.StationParameters(siteId, VtkUtility.GetAppCon()) ;
				if (sphdl.MealPrice != Decimal.MinValue) 
				{ price = sphdl.MealPrice.ToString() ;}
				sphdl.Dispose() ;

				if (mealId == "&nbsp;")
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "MealTicket record is corrupted, cannot be printed") ;}
				else
				{ Response.Redirect("PrintMealTicket.aspx?MealId=" + mealId + "&Name=" + volName + "&Price=" + price + "&Reprint=" + reprint);}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error printing Meal Ticket: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error printing Meal Ticket: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error printing Meal Ticket: " + err.Message) ;}
		}

		private void MealListGrid_DeleteCommand(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			int numberMeal ;
			// get the row to delete; Cell[1]=Id
			string mealId = e.Item.Cells[1].Text ;
			try
			{
				//create handle for meal list
				Vha.Vtk.MealTickets.MealsProvided mlhdl = new Vha.Vtk.MealTickets.MealsProvided(Convert.ToInt32(mealId), VtkUtility.GetAppCon()) ;
				mlhdl.IsRemovedFromList = true ;
				mlhdl.Save() ;
				mlhdl.Dispose() ;
				if (ViewState["numberMeal"] != null)
				{
					numberMeal = Convert.ToInt32(ViewState["numberMeal"].ToString()) ;
					//update meal grid
					GetMealListGrid(numberMeal) ;
					//update confirmation message
					ConfirmationMessage.Text = "Record Deleted!" ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from Meal List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from Meal List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from Meal List: " + err.Message) ;}

		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			DateTime today = DateTime.Now.Date ;
			int numberMeal = Convert.ToInt32(ViewState["numberMeal"].ToString());
			int siteId = VtkPageHeader1.DivSelectedId ;
			int volIdint = 0 ;
			string volIdstr ;
			bool isdup = false ;  // checks for duplicate existing volunteer's in list
			//check required fields
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, missingdata) ;}
			else
			{
				try
				{
					//disable post button until we are done
					PostButton.Enabled = false ;
					//define handle
					Vha.Vtk.MealTickets.MealsProvided mlhdl ;
					//check if adding an existing volunteer
					if (ViewState["volId"].ToString() != string.Empty)
					{
						volIdstr = ViewState["volId"].ToString() ;
						volIdint = Convert.ToInt32(volIdstr.ToString());
						//they have choosen a volunteer, check if it already exist in grid, cell 3 is volunteer id
						foreach (DataGridItem dgi in MealListGrid.Items)
						{
							if (dgi.Cells[3].Text.ToString() == volIdstr)
							{
								isdup = true ;
								volIdint = 0 ;
								break ;
							}
						}
					}
					if (isdup)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer already exist's in the Meal List!") ;}
					else
					{
						mlhdl = Vha.Vtk.MealTickets.MealsProvided.AddRecord(VtkUtility.GetAppCon()) ;
						mlhdl.DateOfMeal = today ;
						mlhdl.InstitutionId = siteId ;
						mlhdl.NumberOfMeals = numberMeal ;
						mlhdl.HowAdded = "M" ;
						mlhdl.IsReprinted = false ;
						if (volIdint > 0)
						{ mlhdl.VolunteerId = volIdint ;}
						else
						{
							mlhdl.IsUnscheduled = true ;
							mlhdl.NameOfUnscheduled = UnscheduledText.Text ;
						}
						mlhdl.Save() ;
						mlhdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update DataGrid
						GetMealListGrid(numberMeal) ;
						SetFields() ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Meal Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Meal Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Meal Record: " + err.Message) ;}
				finally
				{ PostButton.Enabled = true ;}
			}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.VolunteerList.SelectedIndexChanged += new System.EventHandler(this.ChooseVolunteer_Click);
			this.ChooseButton.Click += new System.EventHandler(this.ChooseButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.MealListGrid.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.MealListGrid_DeleteCommand);
			this.MealListGrid.SelectedIndexChanged += new System.EventHandler(this.PrintButton_Click);
			this.MealNumberList.SelectedIndexChanged += new System.EventHandler(this.MealNumberList_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
