using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for Organization.
	/// </summary>
	public class OrganizationEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox OrganizationIdText;
		protected System.Web.UI.WebControls.TextBox OrganizationNameText;
		protected System.Web.UI.WebControls.TextBox OrganizationAbbreviationText;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.CheckBox OrganizationInactiveCheckBox;
		protected System.Web.UI.WebControls.DropDownList OrganizationCodeList;
		protected System.Web.UI.WebControls.Label OrganizationIdLabel;
		protected System.Web.UI.WebControls.Label OrganizationNameLabel;
		protected System.Web.UI.WebControls.Label OrganizationAbbreviationLabel;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.RangeValidator RangeValidator1;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.HtmlControls.HtmlGenericControl orgBody;
	
		public OrganizationEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Organization Codes")) 
				{
					if (!Page.IsPostBack) 
					{
						//update the organization list based on station id
						GetOrganizationList(VtkPageHeader1.DivSelectedId) ;

						//enable new,edit buttons
						NewButton.Enabled = true ;
						EditButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void GetOrganizationList(int siteId)
		{
			try
			{
				//tracks last code of org.
				int lastCode = 899 ;

				//check station id, must have, and use in selecting organizations
				if (siteId > 0)
				{
					//populate list of Organizations, get dataset, sort by code
					DataSet dsorg = Vha.Vtk.Common.Organization.GetOrganizationsQuickList(siteId) ;
					//dsorg.Tables["OrganizationList"].DefaultView.Sort = "Code ASC" ;
					DataTable dtorg = dsorg.Tables["AllOrganizations"] ;

					//loop and find last code
					foreach (DataRow dr in dtorg.Rows)
					{
						//check code, save the last code. It will be used to add new orgs.
						if (dr["Code"].ToString() != string.Empty)
						{
							if (Convert.ToInt32(dr["Code"]) > lastCode)
							{ lastCode = Convert.ToInt32(dr["Code"]) ;}
						}
					}
					
					//add the first row
					DataRow drorg = dtorg.NewRow() ;
					drorg["DisplayName"] = " -Select Organization Code- " ;
					drorg["Id"] = 0 ;
					dtorg.Rows.InsertAt(drorg, 0) ;

					//save last code
					ViewState["lastCode"] = lastCode.ToString() ;

					//define columns in list box
					OrganizationCodeList.DataTextField = "DisplayName" ;
					OrganizationCodeList.DataValueField = "Id" ;

					//bind list box to DataTable and dispose
					OrganizationCodeList.DataSource = dtorg ;
					OrganizationCodeList.DataBind() ;
					dsorg.Dispose() ;
					dtorg.Dispose() ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Station Record") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields("Local") ;
			OrganizationCodeList.SelectedIndex = 0 ;

			//last code from OrganizationCodeList add 1
			int lastCode = Convert.ToInt32(ViewState["lastCode"]) ;
			lastCode++ ;
			//can't be greater than 999
			if (lastCode < 1000)
			{
				//set text values
				OrganizationIdText.Text = lastCode.ToString() ;
			}

			//enable save button
			PostButton.Enabled = true ;

			//place focus on OrganizationIdText field
			//orgBody.Attributes.Add("onLoad","document.orgForm.OrganizationNameText.focus()") ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Organization was selected
			if (OrganizationCodeList.SelectedIndex>0)
			{
				//get selected Organization
				string orgid = OrganizationCodeList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle
					Vha.Vtk.Common.Organization orghdl = new Vha.Vtk.Common.Organization(Convert.ToInt32(orgid), VtkUtility.GetAppCon()) ;

					//get Scope and clear fields
					string orgScope = orghdl.Scope.ToString() ;
					SetFields(orgScope) ;
					//save id and version
					ViewState["organizationId"] = orghdl.ID ;
					ViewState["organizationVersion"] = orghdl.Version.ToString() ;

					//scope is national, display only
					if (orgScope == "N")
					{
						//populate label fields to edit
						OrganizationIdLabel.Text = orghdl.Code.ToString() ;
						OrganizationNameLabel.Text = orghdl.OrganizationName.ToString() ;
						OrganizationAbbreviationLabel.Text = orghdl.Abbreviation.ToString() ;
						OrganizationInactiveCheckBox.Checked = orghdl.IsInactive ;
						//disable Save button
						PostButton.Enabled = false ;
					}
						//local services, edit text fields
					else
					{
						//set text fields to values
						OrganizationIdText.Text = orghdl.Code.ToString() ;
						OrganizationNameText.Text = orghdl.OrganizationName.ToString() ;
						OrganizationAbbreviationText.Text = orghdl.Abbreviation.ToString() ;
						OrganizationInactiveCheckBox.Checked = orghdl.IsInactive ;
						//enable Save button
						PostButton.Enabled = true ;

						//place focus on OrganizationIdText field
						//orgBody.Attributes.Add("onLoad","document.orgForm.OrganizationNameText.focus()") ;
					}
					orghdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + err.Message) ;}
			}
			else
			{
				SetFields("Local") ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Organization Code to Edit") ;
			}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (OrganizationIdText.Text != string.Empty)
			{
				//flag to check if version number has changed
				bool versionOk = true ;
				try
				{
					Vha.Vtk.Common.Organization orghdl ;
					//check if edit existing record
					if (ViewState["organizationId"].ToString() != string.Empty)
					{
						string orgid = ViewState["organizationId"].ToString() ;
						//create handle and open current record
						orghdl = new Vha.Vtk.Common.Organization(Convert.ToInt32(orgid), VtkUtility.GetAppCon()) ;

						//check version
						if (ViewState["organizationVersion"].ToString() != orghdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Organization record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
						//new record
					else
					{
						//create handle and open new record
						orghdl = Vha.Vtk.Common.Organization.AddRecord(VtkUtility.GetAppCon()) ;
					}
					if (versionOk)
					{
						orghdl.Code = OrganizationIdText.Text ;
						orghdl.OrganizationName = OrganizationNameText.Text ;
						orghdl.Abbreviation = OrganizationAbbreviationText.Text ;
						orghdl.IsInactive = OrganizationInactiveCheckBox.Checked ;
						orghdl.Scope = "L" ;

						//get current station, must have
						orghdl.StationId = VtkPageHeader1.DivSelectedId ;

						//save and close
						orghdl.Save() ;
						orghdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update Organization List
						GetOrganizationList(VtkPageHeader1.DivSelectedId) ;
						SetFields("L") ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was no record to Save") ;}
		}

		protected void SetFields(string scope)
		{
			//set text fields to empty
			OrganizationIdText.Text = string.Empty ;
			OrganizationNameText.Text = string.Empty ;
			OrganizationAbbreviationText.Text = string.Empty ;
			OrganizationInactiveCheckBox.Checked = false ;
			//set label fields to empty
			OrganizationIdLabel.Text = string.Empty ;
			OrganizationNameLabel.Text = string.Empty ;
			OrganizationAbbreviationLabel.Text = string.Empty ;

			ViewState["organizationId"] = string.Empty ;
			ViewState["organizationVersion"] = string.Empty ;

			//scope is national, labels are visible
			if (scope == "N")
			{
				//set text fields invisible
				OrganizationIdText.Visible = false ;
				OrganizationNameText.Visible = false ;
				OrganizationAbbreviationText.Visible = false ;
				OrganizationInactiveCheckBox.Enabled = false ;
				//set label fields visible
				OrganizationIdLabel.Visible = true ;
				OrganizationNameLabel.Visible = true ;
				OrganizationAbbreviationLabel.Visible = true ;
			}
			else
			{
				//scope is local, label fields are visible
				//set text field to visible
				OrganizationIdText.Visible = true ;
				OrganizationNameText.Visible = true ;
				OrganizationAbbreviationText.Visible = true ;
				OrganizationInactiveCheckBox.Enabled = true ;
				//set label fields invisible
				OrganizationIdLabel.Visible = false ;
				OrganizationNameLabel.Visible = false ;
				OrganizationAbbreviationLabel.Visible = false ;
			}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
