using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for ServiceAssignment.
	/// </summary>
	public class ServiceAssignmentEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox ServiceNameText;
		protected System.Web.UI.WebControls.DropDownList ServiceCodeList;
		protected System.Web.UI.WebControls.TextBox ServiceIdText;
		protected System.Web.UI.WebControls.TextBox ServiceAbbreviationText;
		protected System.Web.UI.WebControls.TextBox ServiceSubdivisionText;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ServiceIdLabel;
		protected System.Web.UI.WebControls.Label ServiceNameLabel;
		protected System.Web.UI.WebControls.Label ServiceAbbreviationLabel;
		protected System.Web.UI.WebControls.Label ServiceSubdivisionLabel;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.HtmlControls.HtmlGenericControl serviceBody;

	
		public ServiceAssignmentEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Service Codes")) 
				{
					if (!Page.IsPostBack) 
					{
						//update service list
						GetServiceList(VtkPageHeader1.DivSelectedId) ;
						//setup for new record
						SetFields("L") ;
						RecordIdLabel.Text = "New" ;
						PostButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + err.Message) ;}
		}

		private void GetServiceList(int siteId)
		{
			try
			{
				//tracks last code of service
				int lastCode = 799 ;
				string code = null ;
				//check site id, must have, and use in selecting services
				if (siteId > 0)
				{
					//populate list of Services, get dataset, sort by code
					DataSet dssrv = Service.GetSiteQuickListByName(siteId) ;
					//dssrv.Tables["ServiceList"].DefaultView.Sort = "Code ASC" ;
					DataTable dtsrv = dssrv.Tables["ServiceList"] ;
					//add the first row
					DataRow drsrv = dtsrv.NewRow() ;
					drsrv["DisplayName"] = " -Select Service Code- " ;
					drsrv["ID"] = 0 ;
					dtsrv.Rows.InsertAt(drsrv, 0) ;

					//loop and find last code
					foreach (DataRow dr in dtsrv.Rows)
					{
						//check code, save the last code. It will be used to add new orgs.
						if (dr["Code"].ToString() != string.Empty)
						{
							code = dr["Code"].ToString().Substring(0,3) ;
							if (Convert.ToInt32(code) > lastCode)
							{ lastCode = Convert.ToInt32(code) ;}
						}
					}

					//save last code
					ViewState["lastCode"] = lastCode.ToString() ;

					//define columns in list box
					ServiceCodeList.DataTextField = "DisplayName" ;
					ServiceCodeList.DataValueField = "ID" ;

					//bind list box to DataTable and dispose
					ServiceCodeList.DataSource = dtsrv ;
					ServiceCodeList.DataBind() ;
					dssrv.Dispose() ;
					dtsrv.Dispose() ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Station Record") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + err.Message) ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			ServiceCodeList.SelectedIndex = 0 ;
			//setup for new record
			SetFields("L") ;
			RecordIdLabel.Text = "New" ;
			PostButton.Enabled = true ;
			//last code from ServiceList add 1
			int lastCode = Convert.ToInt32(ViewState["lastCode"]) ;
			lastCode++ ;
			//can't be greater than 900
			if (lastCode < 900)
			{
				//set text values
				ServiceIdText.Text = lastCode.ToString() ;
			}

		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Service was selected
			if (ServiceCodeList.SelectedIndex>0)
			{
				//get selected Service
				string srvid = ServiceCodeList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save Id and version
					//ref. Vha.Vtk.Common.Service
					Service srvhdl = new Service(Convert.ToInt32(srvid), VtkUtility.GetAppCon()) ;
					//get scope
					string srvScope = srvhdl.Scope.ToString() ;
					SetFields(srvScope) ;
					ViewState["serviceId"] = srvhdl.ID.ToString() ;
					ViewState["serviceVersion"] = srvhdl.Version.ToString() ;
					RecordIdLabel.Text = ViewState["serviceId"].ToString() ;

					//scope is national, display only
					if (srvScope == "N")
					{
						//populate label fields to edit
						ServiceIdLabel.Text = srvhdl.Code.ToString() ;
						ServiceNameLabel.Text = srvhdl.ServiceName.ToString() ;
						ServiceAbbreviationLabel.Text = srvhdl.Abbreviation.ToString() ;
						ServiceSubdivisionLabel.Text = srvhdl.Subdivision.ToString() ;
						//disable Save button
						PostButton.Enabled = false ;
					}
					//local services, edit text fields
					else
					{
						//set text fields to values
						ServiceIdText.Text = srvhdl.Code.ToString() ;
						ServiceNameText.Text = srvhdl.ServiceName.ToString() ;
						ServiceAbbreviationText.Text = srvhdl.Abbreviation.ToString() ;
						ServiceSubdivisionText.Text = srvhdl.Subdivision.ToString() ;
						//enable Save button
						PostButton.Enabled = true ;

						//place focus on ServiceNameText field
						//serviceBody.Attributes.Add("onLoad","document.serviceForm.ServiceNameText.focus()") ;
					}
					srvhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + err.Message) ;}
			}
			else
			{
				SetFields("Local") ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Service Code to Edit") ;
			}
		}

		private void PostButoon_Click(object sender, System.EventArgs e)
		{
			int srvid = 0 ;
			//flag to check if version number has changed
			bool versionOk = true ;
			//ref. Vha.Vtk.Common.Service
			Service srvhdl ;
			if (ServiceIdText.Text != string.Empty)
			{
				try
				{
					string sc = ServiceIdText.Text ;
					//need to check the pattern of the ServiceCode, must be 3 digits, optional 1 alpha
					if (!Regex.IsMatch(sc, @"^\d{3}\D??$"))
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Code must be 3 digits and an optional character!") ;}
					else
					{
						//check that first 3 digits are greater than 799
						if (Convert.ToInt32(sc.Substring(0,3)) < 800)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Code must be greater than 799") ;}
						else
						{
							//check if edit existing record
							if (ViewState["serviceId"].ToString() != string.Empty)
							{
								srvid = Convert.ToInt32(ViewState["serviceId"].ToString()) ;
								//create handle and open current record
								srvhdl = new Service(srvid, VtkUtility.GetAppCon()) ;
								//check version
								if (ViewState["serviceVersion"].ToString() != srvhdl.Version.ToString())
								{
									VtkUtility.ErrMsgAdd(ErrorMessage, "Current Service record has changed while you were editing, Please press EXIT and start over. ") ;
									versionOk = false ;
								}
							}
								//new record
							else
							{
								//create handle and open new record
								srvhdl = Service.AddRecord(VtkUtility.GetAppCon()) ;
							}
							if (versionOk)
							{
								//save current fields
								srvhdl.Code = ServiceIdText.Text ;
								srvhdl.ServiceName = ServiceNameText.Text ;
								srvhdl.Abbreviation = ServiceAbbreviationText.Text ;
								srvhdl.Subdivision = ServiceSubdivisionText.Text ;
								srvhdl.Scope = "L" ;

								//get current station, must have
								srvhdl.StationId = VtkPageHeader1.DivSelectedId ;

								//save and close
								srvhdl.Save() ;
								srvhdl.Dispose() ;

								//update confirmation message
								ConfirmationMessage.Text = "Record Posted!" ;
								//update service list and reset fields
								GetServiceList(VtkPageHeader1.DivSelectedId) ;
								SetFields("Local") ;
								RecordIdLabel.Text = "New" ;
							}
						}
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must enter a Service Code") ;}
		}

		protected void SetFields(string scope)
		{
			//set text fields to empty
			ServiceIdText.Text = string.Empty ;
			ServiceNameText.Text = string.Empty ;
			ServiceAbbreviationText.Text = string.Empty ;
			ServiceSubdivisionText.Text = string.Empty ;
			//set label fields to empty
			ServiceIdLabel.Text = string.Empty ;
			ServiceNameLabel.Text = string.Empty ;
			ServiceAbbreviationLabel.Text = string.Empty ;
			ServiceSubdivisionLabel.Text = string.Empty ;

			//clear variables
			ViewState["serviceId"] = string.Empty ;
			ViewState["serviceVersion"] = string.Empty ;

			//scope is national, labels are visible
			if (scope == "N")
			{
				//set label fields visible
				ServiceIdLabel.Visible = true ;
				ServiceNameLabel.Visible = true ;
				ServiceAbbreviationLabel.Visible = true ;
				ServiceSubdivisionLabel.Visible = true ;
				//set text fields to invisible
				ServiceIdText.Visible = false ;
				ServiceNameText.Visible = false ;
				ServiceAbbreviationText.Visible = false ;
				ServiceSubdivisionText.Visible = false ;
			}
			else
			{
				//scope is local, label fields are visible
				//set text fields to visible
				ServiceIdText.Visible = true ;
				ServiceNameText.Visible = true ;
				ServiceAbbreviationText.Visible = true ;
				ServiceSubdivisionText.Visible = true ;

				//set label fields to invisible
				ServiceIdLabel.Visible = false ;
				ServiceNameLabel.Visible = false ;
				ServiceAbbreviationLabel.Visible = false ;
				ServiceSubdivisionLabel.Visible = false ;
			}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButoon_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;		
		}

	}
}
