using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.TimeKeeping;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for InstitutionEdit.
	/// </summary>
	public class ServiceInformationEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.TextBox ComPhoneText;
		protected System.Web.UI.WebControls.TextBox ComPhone2Text;
		protected System.Web.UI.WebControls.TextBox ComFaxText;
		protected System.Web.UI.WebControls.TextBox ServiceTitleText;
		protected System.Web.UI.WebControls.TextBox MailStopText;
		protected System.Web.UI.WebControls.DropDownList ServiceTypeList;
		protected System.Web.UI.WebControls.CheckBox VAVSCheckBox;
		protected System.Web.UI.WebControls.TextBox OperatingCostsText;
		protected System.Web.UI.WebControls.TextBox StaffCostsText;
		protected System.Web.UI.WebControls.DropDownList ProgramList;
		protected System.Web.UI.WebControls.CheckBox UpdateCheckBox;
		protected System.Web.UI.WebControls.Label ReviewDateLabel;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.DataGrid SupervisedDataGrid;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button NextButton;
		protected System.Web.UI.WebControls.Button AddButton;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.RegularExpressionValidator OperatingCostValidator;
		protected System.Web.UI.WebControls.RegularExpressionValidator StaffCostValidator;
		protected System.Web.UI.WebControls.TextBox SupervisorText;
		protected System.Web.UI.WebControls.Label StationNameLabel;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Voluntary Services")) 
				{
					if (!Page.IsPostBack) 
					{
						int siteId = VtkPageHeader1.DivSelectedId ;
						//set station name in header label
						StationNameLabel.Text = VtkPageHeader1.DivSelectedName ;
						Vha.Vtk.ServicesDirectory.Services shdl = new Vha.Vtk.ServicesDirectory.Services(siteId, VtkUtility.GetAppCon()) ;
						//save version number and check during posting
						ViewState["Version"] = shdl.Version.ToString() ;
						//get values for fields
						ServiceTitleText.Text = shdl.ServiceTitle ;
						MailStopText.Text = shdl.MailStop ;
						ComPhoneText.Text = shdl.PrimaryPhone ;
						ComPhone2Text.Text = shdl.SecondaryPhone ;
						ComFaxText.Text = shdl.FaxNumber ;
						ReviewDateLabel.Text = shdl.LastUpdated.Date.ToShortDateString() ;
						SupervisorText.Text = shdl.ChiefManager ;
						if (shdl.OperatingCosts!=Decimal.MinValue) 
						{ OperatingCostsText.Text = shdl.OperatingCosts.ToString() ;}
						if (shdl.StaffCosts != Decimal.MinValue)
						{ StaffCostsText.Text = shdl.StaffCosts.ToString() ;}
						if (shdl.IsOwnVAVSCommittee)
						{ VAVSCheckBox.Checked = true ;}
						else
						{ VAVSCheckBox.Checked = false ;}

						GetServiceList() ;

						//set current value
						VtkUtility.SetSelectedSingle(ServiceTypeList.Items, shdl.TypeId.ToString()) ;

						GetProgramList(siteId) ;

						shdl.Dispose() ;
						GetSupervisedPrograms(siteId) ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Service Information record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Service Information record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Service Information record: " + err.Message) ;}
		}

		private void GetSupervisedPrograms(int siteId)
		{
			//DataSet spds = Vha.Vtk.ServicesDirectory.SupervisedProgramsCollection.GetCollectionDataSet(siteId, VtkUtility.GetAppCon()) ;
			DataSet spds = Vha.Vtk.ServicesDirectory.SupervisedPrograms.GetQuickListByInstitutionId(siteId, VtkUtility.GetAppCon()) ;
			DataTable spdt = spds.Tables["SupervisedProgramsList"] ;
			//SupervisedDataGrid.DataKeyField = "ProgramId" ;
			SupervisedDataGrid.DataSource = spdt ;
			SupervisedDataGrid.DataBind() ;
			// Now that supervised programs dataset is retrieved and bound, save it for later comparison
			// get unique ID to store dataset in unique location in session
			//string transactionId=Vha.Vtk.WebControlLibrary.VhaWebUtility.GetTransactionId(Session);
			//string supervisedTransactionId="tId_" + transactionId + "_SupervisedProgramsDataSet";
			// put unique ID in page-specific ViewState, so THIS PAGE's dataset can be retrieved later from Session
			//ViewState["SupervisedTransactionId"]=supervisedTransactionId;
			//ViewState["EndSupervisedTransactionId"]=transactionId;
			// put parking sticker dataset into session under page-specific unique location
			//Session[supervisedTransactionId]=spds ;
			spds.Dispose() ;
			spdt.Dispose() ;
		}

		private void GetServiceList()
		{
			//get service type list
			DataSet stds = Vha.Vtk.ServicesDirectory.ServiceType.GetQuickList(VtkUtility.GetAppCon()) ;
			DataTable stdt = stds.Tables["ServiceTypeList"] ;
			//add the first row, uses Rows.InsertAt(
			DataRow stdr = stdt.NewRow() ;
			stdr["Type"] = " -Select Service Type- " ;
			stdr["ID"] = 0 ;
			stdt.Rows.InsertAt(stdr, 0) ;
			//define columns in list box
			ServiceTypeList.DataTextField = "Type" ;
			ServiceTypeList.DataValueField = "ID" ;
			ServiceTypeList.DataSource = stdt ;
			ServiceTypeList.DataBind() ;
			stds.Dispose() ;
			stdt.Dispose() ;
		}

		private void GetProgramList(int siteId)
		{
			//get programs list
			DataSet pds = Vha.Vtk.ServicesDirectory.Programs.GetVoluntaryPrograms(siteId, VtkUtility.GetAppCon()) ;
			pds.Tables["ProgramsList"].DefaultView.Sort = "ProgramName ASC" ;
			DataTable pdt = pds.Tables["ProgramsList"] ;
			//add the first row, uses Rows.InsertAt(
			DataRow pdr = pdt.NewRow() ;
			pdr["ProgramName"] = " -Select Program- " ;
			pdr["ProgramId"] = 0 ;
			pdt.Rows.InsertAt(pdr, 0) ;
			//define columns in list box
			ProgramList.DataTextField = "ProgramName" ;
			ProgramList.DataValueField = "ProgramId" ;
			ProgramList.DataSource = pdt ;
			ProgramList.DataBind() ;
			pds.Dispose() ;
			pdt.Dispose() ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (ServiceTitleText.Text != string.Empty)
			{
				try
				{
					int siteId = VtkPageHeader1.DivSelectedId ;
					Vha.Vtk.ServicesDirectory.Services shdl = new Vha.Vtk.ServicesDirectory.Services(siteId, VtkUtility.GetAppCon()) ;
					//check version
					if (ViewState["Version"].ToString() == shdl.Version.ToString())
					{
						//get text fields
						shdl.ServiceTitle = ServiceTitleText.Text ;
						shdl.MailStop = MailStopText.Text ;
						shdl.PrimaryPhone = ComPhoneText.Text ;
						shdl.SecondaryPhone = ComPhone2Text.Text ;
						shdl.FaxNumber = ComFaxText.Text ;
						shdl.ChiefManager = SupervisorText.Text ;
						if (OperatingCostsText.Text != string.Empty)
						{ shdl.OperatingCosts = Convert.ToDecimal(OperatingCostsText.Text.ToString()) ;}
						if (StaffCostsText.Text != string.Empty)
						{ shdl.StaffCosts = Convert.ToDecimal(StaffCostsText.Text.ToString()) ;}
						//get checkboxes
						//if they checked Review date, set to today
						if (UpdateCheckBox.Checked)
						{ shdl.LastUpdated = DateTime.Now.Date ;}
						if (VAVSCheckBox.Checked)
						{ shdl.IsOwnVAVSCommittee = true ;}
						else
						{ shdl.IsOwnVAVSCommittee = false ;}
						if (ServiceTypeList.SelectedIndex == 0)
						{ shdl.TypeId = int.MinValue ;}
						else
						{ shdl.TypeId = Convert.ToInt32(ServiceTypeList.SelectedItem.Value.ToString()) ;}
						//save datagrid
						/*if (Session[(string)ViewState["SupervisedTransactionId"]]!=null) 
						{
							// get DataSet back from Session
							DataSet ds = (DataSet) Session[(string)ViewState["SupervisedTransactionId"]];
							if (ds.HasChanges()) 
							{
								// if it has changes, get bizlayer to SAVE
								Page.Trace.Warn("Warning", ds.GetXml());
								Vha.Vtk.ServicesDirectory.SupervisedProgramsCollection.SaveCollectionDataSet(siteId, VtkUtility.GetAppCon(), ds) ;
							} 
							// remove DataSet from Session
							Session.Remove((string)ViewState["SupervisedTransactionId"]);
							// remove transactionId from Session
							Vha.Vtk.WebControlLibrary.VhaWebUtility.EndTransaction(Session,
								(string) ViewState["EndSupervisedTransactionId"]);
						}
						*/

						//save, dispose, and show message
						shdl.Save() ;
						ViewState["Version"] = shdl.Version.ToString() ;
						shdl.Dispose() ;
						ConfirmationMessage.Text = "Record Posted!" ;
						//Response.Redirect("UserStaffEdit.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
					}
					else
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Service Information record has changed while you were editing, Please press EXIT and start over. ") ;}
				} 
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Service Information record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Service Information record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Service Information record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Title is Required!") ;}
		}

		private void AddButton_Click(object sender, System.EventArgs e)
		{
			if (ProgramList.SelectedIndex > 0)
			{
				/*if (Session[(string)ViewState["SupervisedTransactionId"]]!=null) 
				{
					// get dataset from session
					DataSet ds = (DataSet) Session[(string)ViewState["SupervisedTransactionId"]];
					DataTable dt = ds.Tables["SupervisedProgramsCollection"];
					// define an empty row, add to dataset
					DataRow dr = dt.NewRow();
					//get field values from programlist, put in new row and add back to dataset
					dr["ProgramId"] = Convert.ToInt32(ProgramList.SelectedItem.Value) ;
					dr["ProgramName"] = ProgramList.SelectedItem.Text ;
					dr["InstitutionId"] = VtkPageHeader1.DivSelectedId ;
					dt.Rows.Add(dr);
					// put dataset with new row back into Session
					Session[(string)ViewState["SupervisedTransactionId"]] = ds ;
					// rebind to dataset
					SupervisedDataGrid.DataSource = ((DataSet) Session[(string)ViewState["SupervisedTransactionId"]]).Tables["SupervisedProgramsCollection"].DefaultView;
					SupervisedDataGrid.DataBind() ;
				}
				*/
				try
				{
					//add a new record
					int siteId = VtkPageHeader1.DivSelectedId ;
					string proId = ProgramList.SelectedItem.Value ;
					Vha.Vtk.ServicesDirectory.SupervisedPrograms sphdl = Vha.Vtk.ServicesDirectory.SupervisedPrograms.AddRecord(Convert.ToInt32(proId), VtkUtility.GetAppCon()) ;
					sphdl.InstitutionId = siteId ;
					sphdl.Save() ;
					sphdl.Dispose() ;
					//reset the ProgramList
					ProgramList.SelectedIndex = 0 ;
					GetSupervisedPrograms(siteId) ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error adding a Supervised Program: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error adding a Supervised Program: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error adding a Supervised Program: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Program to Add to the Supervised Programs") ;}
		}

		private void DeleteButton_Click(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			/*// get the dataset from Session to mark a row for deletion
			DataSet ds = (DataSet) Session[(string)ViewState["SupervisedTransactionId"]];
			DataTable dt = ds.Tables["SupervisedProgramsCollection"];
			// get the row to delete
			int rowIndex = e.Item.DataSetIndex;
			// mark the row deleted in the DataSet
			dt.Rows[rowIndex].Delete();
			// put updated DataSet back into Session
			Session[(string)ViewState["SupervisedTransactionId"]]=ds;

			// rebind to DataSet (row is still in dataset, but binding ignores items marked for deletion)
			SupervisedDataGrid.DataSource=((DataSet) Session[(string)ViewState["SupervisedTransactionId"]]).Tables["SupervisedProgramsCollection"].DefaultView;
			SupervisedDataGrid.DataBind();	*/

			//id is in cell[0]
			string proId = e.Item.Cells[0].Text.ToString() ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			Vha.Vtk.ServicesDirectory.SupervisedPrograms sphdl = new Vha.Vtk.ServicesDirectory.SupervisedPrograms(Convert.ToInt32(proId), VtkUtility.GetAppCon()) ;
			sphdl.Delete() ;
			sphdl.Save() ;
			sphdl.Dispose() ;
			//reset the ProgramList
			ProgramList.SelectedIndex = 0 ;
			GetSupervisedPrograms(siteId) ;	
		}

		private void NextButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("UserStaffEdit.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../Index.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;		
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SupervisedDataGrid.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.DeleteButton_Click);
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NextButton.Click += new System.EventHandler(this.NextButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
