using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.FileMaintenance
{
	/// <summary>
	/// Summary description for SiteParameters.
	/// </summary>
	public class SiteParametersEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox MealPriceText;
		protected System.Web.UI.WebControls.TextBox CutOffTimeText;
		protected System.Web.UI.WebControls.TextBox HoursForLunchText;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.DropDownList DefaultLanguageList;
		protected System.Web.UI.WebControls.DropDownList AlternateLanguageList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.RangeValidator HoursForLunchValidator;
		protected System.Web.UI.WebControls.RangeValidator MealPriceValidator;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.RegularExpressionValidator CutOffTimeValidator;
		protected System.Web.UI.WebControls.TextBox HoursForMeal2Text;
		protected System.Web.UI.WebControls.TextBox CutOffTime2Text;
		protected System.Web.UI.WebControls.Label HoursForMeal2Label;
		protected System.Web.UI.WebControls.Label CutOffTime2Label;
		protected System.Web.UI.WebControls.RegularExpressionValidator CutOffTime2Validator;
		protected System.Web.UI.WebControls.RangeValidator HoursForMeal2Validator;
		protected System.Web.UI.WebControls.RadioButtonList NumberOfMealsList;
		protected System.Web.UI.WebControls.Label AlternateLanguageLabel;
		protected System.Web.UI.WebControls.CheckBox RequireLanguageCheckBox;
		protected System.Web.UI.WebControls.CheckBoxList MealsOnDayList;
		protected System.Web.UI.WebControls.RadioButtonList MealAuthorizationList;
		protected System.Web.UI.WebControls.TextBox IntroductionText;
		protected System.Web.UI.WebControls.DataGrid GPFGrid;
		protected System.Web.UI.WebControls.DataGrid REFGrid;
		protected System.Web.UI.WebControls.Label StarLabel1;
		protected System.Web.UI.WebControls.Label StarLabel2;
		protected System.Web.UI.WebControls.TextBox VoluntarySignText;
		protected System.Web.UI.WebControls.TextBox DirectorSignText;
		protected System.Web.UI.WebControls.TextBox DirectorSignValueText;
		protected System.Web.UI.WebControls.RadioButtonList VaLetterHeadList;
		protected System.Web.UI.WebControls.RangeValidator DirectorValueAmtValidator;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
	
		public SiteParametersEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try 
			{
				if (VtkPageHeader1.IsDivSelected("Site Parameters")) 
				{
					if (!Page.IsPostBack)
					{
						int siteId = VtkPageHeader1.DivSelectedId ;
						int numberOfMeals = 1 ;
						Vha.Vtk.Common.StationParameters sphdl = new Vha.Vtk.Common.StationParameters(siteId, VtkUtility.GetAppCon()) ;
						//save version number and check during posting
						ViewState["Version"] = sphdl.Version.ToString() ;
						//get text values for fields
						if (sphdl.MealPrice != Decimal.MinValue) 
						{
							MealPriceText.Text = sphdl.MealPrice.ToString() ;
						}
						if (sphdl.CutOffTimeForMeal1 != null)
						{
							CutOffTimeText.Text = sphdl.CutOffTimeForMeal1.ToString() ;
						}
						if (sphdl.DurationForMeal1 != int.MinValue) 
						{
							HoursForLunchText.Text = sphdl.DurationForMeal1.ToString() ;
						}
						//check number of meals, if not 2 then make all meal2 fields invisible
						numberOfMeals = sphdl.NumberOfMeals ;
						VtkUtility.SetSelectedSingle(NumberOfMealsList.Items, numberOfMeals.ToString()) ;
						NumberOfMeals(numberOfMeals) ;
						if (numberOfMeals > 1)
						{
							if (sphdl.CutOffTimeForMeal2 != null) 
							{
								CutOffTime2Text.Text = sphdl.CutOffTimeForMeal2.ToString() ;
							}
							if (sphdl.DurationForMeal2 != int.MinValue) 
							{
								HoursForMeal2Text.Text = sphdl.DurationForMeal2.ToString() ;
							}
						}

						IntroductionText.Text = sphdl.IntroductoryText ;
						DirectorSignText.Text = sphdl.DirectorSignatureLine;
						VoluntarySignText.Text = sphdl.VoluntarySignatureLine;
						if (sphdl.ValueAmount != Decimal.MinValue) 
						{
							DirectorSignValueText.Text = sphdl.ValueAmount.ToString();
						}
						if (sphdl.IsVALetterHead) 
						{VaLetterHeadList.SelectedIndex = 0;} 					
						else
						{VaLetterHeadList.SelectedIndex = 1;}


							//get radio button values for Meals on Day list
							foreach (ListItem li in MealsOnDayList.Items)
							{
								if (li.Value == "1")
								{
									if (sphdl.IsSaturdayMeal)
									{ li.Selected = true ;}
									else
									{ li.Selected = false ;}
								}
								if (li.Value == "2")
								{
									if (sphdl.IsSundayMeal)
									{ li.Selected = true ;}
									else
									{ li.Selected = false ;}
								}
								if (li.Value == "3")
								{
									if (sphdl.IsHolidayMeal)
									{ li.Selected = true ;}
									else
									{ li.Selected = false ;}
								}
							}
						//get meal authorization list
						DataSet dsml = Vha.Vtk.Common.StationParameters.GetMealAuthorizationList(VtkUtility.GetAppCon()) ;
						DataTable dtml = dsml.Tables["MealAuthorizationList"] ;

						foreach (DataRow drm in dtml.Rows)
						{
							ListItem lim = new ListItem(drm["External"].ToString(), drm["Key"].ToString()) ;
							MealAuthorizationList.Items.Add(lim) ;
							if ( sphdl.MealAuthorization.ToString() == lim.Value.ToString())
							{ lim.Selected = true ;}
						}
						RequireLanguageCheckBox.Checked = sphdl.IsRequireAlternateLanguage ;
						if (RequireLanguageCheckBox.Checked)
						{
							//make visiable AlternateLanguage
							AlternateLanguageList.Visible = true ;
							AlternateLanguageLabel.Visible = true ;
						}

						//get language list
						DataSet dslang = Vha.Vtk.Kernel.Data.SystemTables.Language.GetQuickList() ;
						DataTable dtlang = dslang.Tables["LanguageList"] ;

						//AlternateLanguageList.Items.Insert(0,new ListItem("none",int.MinValue.ToString()));
						foreach (DataRow dr in dtlang.Rows)
						{
							ListItem lia = new ListItem(dr["LanguageName"].ToString(), dr["ID"].ToString()) ;
							ListItem lia1 = new ListItem(dr["LanguageName"].ToString(), dr["ID"].ToString()) ;

							DefaultLanguageList.Items.Add(lia) ;
							if (sphdl.DefaultLanguageId.ToString() == lia.Value.ToString())
							{ lia.Selected = true ;}

							AlternateLanguageList.Items.Add(lia1) ;
							if (sphdl.AlternateLanguageId.ToString() == lia1.Value.ToString())
							{ lia1.Selected = true ;}
						}
						UpdateGPFGrid();
						UpdateREFGrid();
						//dispose and cleanup
						dslang.Dispose() ;
						dtlang.Dispose() ;
						sphdl.Dispose() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Site Parameters: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Site Parameters: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading Site Parameters: " + err.Message) ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string error = string.Empty ;
			int numberOfMeals ;
			if (ViewState["Version"].ToString() != string.Empty)
			{
				//check cutoff times & required hours
				error = ValidateParameters() ;
				if (error != string.Empty)
				{VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
				else
				{
					try
					{
						int siteId = VtkPageHeader1.DivSelectedId ;
						Vha.Vtk.Common.StationParameters sphdl = new Vha.Vtk.Common.StationParameters(siteId, VtkUtility.GetAppCon()) ;
						//check version
						if (ViewState["Version"].ToString() == sphdl.Version.ToString())
						{
							//get text fields
							sphdl.IntroductoryText = IntroductionText.Text ;
							sphdl.MealPrice = Convert.ToDecimal(MealPriceText.Text) ; 
							sphdl.CutOffTimeForMeal1 = CutOffTimeText.Text ; 
							sphdl.DurationForMeal1 = Convert.ToInt32(HoursForLunchText.Text) ; 
							numberOfMeals = Convert.ToInt32(NumberOfMealsList.SelectedItem.Value.ToString()) ;
							sphdl.NumberOfMeals = numberOfMeals ;
							//get values for 2nd meal
							if (numberOfMeals > 1)
							{ 
								sphdl.CutOffTimeForMeal2 = CutOffTime2Text.Text ; 
								sphdl.DurationForMeal2 = Convert.ToInt32(HoursForMeal2Text.Text) ;
							}
							else
							{
								//if no 2 meal, clear values
								sphdl.CutOffTimeForMeal2 = string.Empty ;
								sphdl.DurationForMeal2 = int.MinValue ;
							}

							//get radio button values for Meals on Day list
							foreach (ListItem li in MealsOnDayList.Items)
							{
								if (li.Value == "1")
								{
									if (li.Selected)
									{ sphdl.IsSaturdayMeal = true ;}
									else
									{ sphdl.IsSaturdayMeal = false ;}
								}
								if (li.Value == "2")
								{
									if (li.Selected)
									{ sphdl.IsSundayMeal = true ;}
									else
									{ sphdl.IsSundayMeal = false ;}
								}
								if (li.Value == "3")
								{
									if (li.Selected)
									{ sphdl.IsHolidayMeal = true ;}
									else
									{ sphdl.IsHolidayMeal = false ;}
								}
							}
							//Meal Authorization List
							if (MealAuthorizationList.SelectedIndex > -1)
							{ sphdl.MealAuthorization = MealAuthorizationList.SelectedItem.Value.ToString() ;}

							//Languages
							sphdl.DefaultLanguageId=Convert.ToInt32(DefaultLanguageList.SelectedItem.Value);
							if (RequireLanguageCheckBox.Checked)
							{
								sphdl.AlternateLanguageId=Convert.ToInt32(AlternateLanguageList.SelectedItem.Value);
								sphdl.IsRequireAlternateLanguage = true ;
							}
							else
							{
								sphdl.AlternateLanguageId = int.MinValue ;
								sphdl.IsRequireAlternateLanguage = false ;
							}
							sphdl.VoluntarySignatureLine = VoluntarySignText.Text;
							sphdl.DirectorSignatureLine = DirectorSignText.Text;

							if (DirectorSignValueText.Text == string.Empty)
							{ sphdl.ValueAmount = decimal.MinValue;}
							else
							{sphdl.ValueAmount = Convert.ToDecimal(DirectorSignValueText.Text);}
							if (VaLetterHeadList.SelectedItem.Value == "1")
							{sphdl.IsVALetterHead = true;}
							else
							{sphdl.IsVALetterHead = false;}

							//save, dispose, and exit
							sphdl.Save() ;
							sphdl.Dispose() ;
							Response.Redirect("/Vtk/Welcome.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;

						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Site Parameter record has changed while you were editing, Please press EXIT and start over. ") ;}
					} 
					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Site Parameters: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Site Parameters: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting Site Parameters: " + err.Message) ;}
				}
			}
		}

		private void NumberOfMeals_click(object sender, System.EventArgs e)
		{
			string numberOfMeals = NumberOfMealsList.SelectedItem.Value ;
			NumberOfMeals(Convert.ToInt32(numberOfMeals.ToString())) ;
		}

		private string ValidateParameters()
		{
			bool AddComma = false ;
			int cutOffTime ;
			int numberOfMeals = NumberOfMealsList.SelectedIndex ;
			string error = string.Empty ;
			//check required fields first
			if (MealPriceText.Text == string.Empty)
			{
				error = "Meal Price" ;
				AddComma = true ;
			}
			if (numberOfMeals < 0)
			{
				if (AddComma)
				{ error = error + ", " ;}
				error = error + "Number of Meals " ;
				AddComma = true ;
			}
			if (HoursForLunchText.Text == string.Empty)
			{
				if (AddComma)
				{ error = error + ", " ;}
				error = error + "Required Hours for 1 Meal" ;
				AddComma = true ;
			}
			if (CutOffTimeText.Text == string.Empty)
			{
				if (AddComma)
				{ error = error + ", " ;}
				error = error + "Cut Off Time for 1 Meal" ;
				AddComma = true ;
			}
			if (numberOfMeals > 0)
			{
				//number of meals is 2
				if (HoursForMeal2Text.Text == string.Empty)
				{
					if (AddComma)
					{ error = error + ", " ;}
					error = error + "Required Hours for 2 Meals" ;
					AddComma = true ;
				}
				if (CutOffTime2Text.Text == string.Empty)
				{
					if (AddComma)
					{ error = error + ", " ;}
					error = error + "Cut Off Time for 2 Meals" ;
					AddComma = true ;
				}
			}
			if (error != string.Empty)
			{ error = "The following field(s) are required: " + error ;}
			if (error == string.Empty)
			{
				//check that all times are less than 2400
				cutOffTime = Convert.ToInt32(CutOffTimeText.Text.ToString()) ;
				if (cutOffTime > 2400)
				{ error = "'Cut off time for 1 Meal' cannot be greater than 2400!   " ;}

				if (numberOfMeals > 0)
				{
					cutOffTime = Convert.ToInt32(CutOffTime2Text.Text.ToString()) ;
					if (cutOffTime > 2400)
					{ error = error + "'Cut off time for 2 Meals' cannot be greater than 2400!" ;}
				}
			}
			if (error == string.Empty && (numberOfMeals > 0))
			{
				//check that cutoff time 1 > cutoff time 2
				if (Convert.ToInt32(CutOffTimeText.Text.ToString()) <= Convert.ToInt32(CutOffTime2Text.Text.ToString()))
				{ error = "Cut off time for 1 Meal must be greater than Cut off time for 2 Meals !" ;}
				//check that hours for meal 1 < hours for meal 2
				if (Convert.ToInt32(HoursForLunchText.Text.ToString()) >= Convert.ToInt32(HoursForMeal2Text.Text.ToString()))
				{ error = "Required Hours for 2 Meals must be greater than Required Hours for 1 Meal !" ;}
			}
			if (error == string.Empty && (RequireLanguageCheckBox.Checked))
			{
				//check that alternate language is set and not equal to default language
				if (AlternateLanguageList.SelectedIndex == 0)
				{ error = "You must select an Alternate Language !" ;}
				if (AlternateLanguageList.SelectedIndex == DefaultLanguageList.SelectedIndex)
				{ error = "You cannot select the same language for both the default and the alternate languages!" ;}
			}
			return error ;
		}

		private void NumberOfMeals(int numberOfMeals)
		{
			if (numberOfMeals > 1)
			{
				CutOffTime2Text.Visible = true ;
				CutOffTime2Label.Visible = true ;
				HoursForMeal2Text.Visible = true ;
				HoursForMeal2Label.Visible = true ;
				StarLabel1.Visible = true;
				StarLabel2.Visible = true;
			}
			else
			{
				CutOffTime2Text.Visible = false ;
				CutOffTime2Label.Visible = false ;
				HoursForMeal2Text.Visible = false ;
				HoursForMeal2Label.Visible = false ;
				StarLabel1.Visible = false;
				StarLabel2.Visible = false;
			}
		}

		private void RequireLanguage_Click(object sender, System.EventArgs e)
		{
			if (RequireLanguageCheckBox.Checked)
			{
				//make visiable AlternateLanguage
				AlternateLanguageList.Visible = true ;
				AlternateLanguageLabel.Visible = true ;
			}
			else
			{
				//make invisiable AlternateLanguage
				AlternateLanguageList.Visible = false ;
				AlternateLanguageLabel.Visible = false ;
			}
		}

		private void UpdateGPFGrid()
		{
			DataSet dsGPF ;
			DataTable dtGPF ;
			string displayName = string.Empty ;
			int StationId = VtkPageHeader1.DivSelectedId ;
			string error = "";
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
				//GetQuickListGPFsBy_StationId
				dsGPF = Vha.Vtk.Donations.Donation.GetQuickListGPFsBy_StationId(StationId);		
				dtGPF = dsGPF.Tables["GetQuickListGPFsBy_StationId"] ;

				GPFGrid.DataSource = dtGPF ;
				DataRow drGPF = dtGPF.NewRow();
				object[] newRowColumns = new object[5];
//				newRowColumns[2] = "Enter new GPF here .....";
				newRowColumns[2] = "";
				drGPF.ItemArray = newRowColumns;

				dtGPF.Rows.Add(drGPF);
				//				dtAward.DefaultView.Sort = sortExpress;
				GPFGrid.DataBind() ;
				//SetPagerStats();
				dsGPF.Dispose() ;
				dtGPF.Dispose() ;
			}
		}

		private void GPFGrid_DeleteCommand(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			//int numberMeal ;
			// get the row to delete; Cell[0]=Id
			string GPFId = e.Item.Cells[0].Text ; 
			if (GPFId != "&nbsp;")
			{
				try
				{
					//Check if there are any donations where this GPF account has been used.
					DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListDonationsBy_GPFs(Convert.ToInt32(GPFId));
					DataTable dt = ds.Tables["DonationsBy_GPFs"];
					if (dt.Rows.Count == 0)
					{
						Vha.Vtk.Donations.DonGenPostFund gpfhdl = new Vha.Vtk.Donations.DonGenPostFund(Convert.ToInt32(GPFId), VtkUtility.GetAppCon()) ;
						gpfhdl.Delete() ;
						gpfhdl.Save();
						gpfhdl.Dispose() ;
						UpdateGPFGrid() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Deleted!" ;
					}
					else
					{VtkUtility.ErrMsgAdd(ErrorMessage, "General Post Fund Account is used in at least one donation in the past. GPF account can not be deleted. ") ;}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from General Post Fund: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from General Post Fund: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from General Post Fund: " + err.Message) ;}
			}
			else
			{VtkUtility.ErrMsgAdd(ErrorMessage, "This entry from the General Post Funds can not be deleted.") ;	}

		}

		private void GPFGrid_EditCommand(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			// get the row details to be saved; Cell[0]=Id, cell[1]=institutionfk, cell[2]=GPF
			string gpf="";
			TextBox txt = (TextBox)e.Item.Cells[2].FindControl("GPFText") ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			if( txt !=null && txt.Text.Length > 0)
			{
				gpf = txt.Text;
				if (gpf.Length <= 25)
				{
					try
					{

						Vha.Vtk.Donations.DonGenPostFund gpfhdl ;
						Int32 gpfId = 0;
						if (e.Item.Cells[0].Text != "&nbsp;")
						{gpfId = Convert.ToInt32(e.Item.Cells[0].Text);}

						if (gpfId > 0)
						{
							gpfhdl = new Vha.Vtk.Donations.DonGenPostFund(gpfId, VtkUtility.GetAppCon());
						}
						else
						{
							gpfhdl = Vha.Vtk.Donations.DonGenPostFund.AddRecord(VtkUtility.GetAppCon()) ;
						}

						gpfhdl.ID = gpfId;
						gpfhdl.InstitutionFK = siteId ;
						gpfhdl.GeneralPostFund = gpf ;
						gpfhdl.Save() ;
						gpfhdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "GPF Record Saved!" ;
						//update DataGrid
						UpdateGPFGrid() ;
					}

					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error while saving a record into General Post Fund: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error while saving a record into General Post Fund: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error while saving a record into General Post Fund: " + err.Message) ;}
				}
				else
				{VtkUtility.ErrMsgAdd(ErrorMessage, "General Post Fund, this field can be only 25 characters long ") ;	}
			}
			else
			{VtkUtility.ErrMsgAdd(ErrorMessage, "General Post Fund is required.") ;	}
		}

		private void UpdateREFGrid()
		{
			DataSet dsREF ;
			DataTable dtREF ;
			string displayName = string.Empty ;
			int StationId = VtkPageHeader1.DivSelectedId ;
			string error = "";
			if (error != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, error) ;}
			else
			{
				//GetQuickListReferencesBy_StationId
				dsREF = Vha.Vtk.Donations.Donation.GetQuickListReferencesBy_StationId(StationId);
				dtREF = dsREF.Tables["GetQuickListReferencesBy_StationId"] ;

				REFGrid.DataSource = dtREF ;
				DataRow drREF = dtREF.NewRow();
				object[] newRowColumns = new object[5];
//				newRowColumns[2] = "Enter new Reference here ..........";
				newRowColumns[1] = "0";
				newRowColumns[0] = "0";
				newRowColumns[2] = "";
				drREF.ItemArray = newRowColumns;
				dtREF.Rows.Add(drREF);
				//				dtAward.DefaultView.Sort = sortExpress;
				REFGrid.DataBind() ;
				//SetPagerStats();
				dsREF.Dispose() ;
				dtREF.Dispose() ;
			}
		}

		private void REFGrid_DeleteCommand(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			//int numberMeal ;
			// get the row to delete; Cell[0]=Id
			string REFId = e.Item.Cells[0].Text ; 
			if (REFId != "&nbsp;")
			{
				try
				{
					//Check if there are any donations where this GPF account has been used.
					DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListDonationsBy_REFs(Convert.ToInt32(REFId));
					DataTable dt = ds.Tables["DonationsBy_REFs"];
					if (dt.Rows.Count == 0)
					{
						//create handle for meal list
						Vha.Vtk.Donations.DonReference refhdl = new Vha.Vtk.Donations.DonReference(Convert.ToInt32(REFId), VtkUtility.GetAppCon()) ;
						refhdl.Delete() ;
						refhdl.Save();
						refhdl.Dispose() ;
						UpdateREFGrid() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Deleted!" ;
					}
					else
					{VtkUtility.ErrMsgAdd(ErrorMessage, "This Reference is used in at least one donation in the past. Reference entry can not be deleted. ") ;}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from References: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from References: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting from References: " + err.Message) ;}
			}
			else
			{VtkUtility.ErrMsgAdd(ErrorMessage, "This entry from the References can not be deleted.") ;	}

		}

		private void REFGrid_EditCommand(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			// get the row details to be saved; Cell[0]=Id, cell[1]=institutionfk, cell[2]=GPF
			string reference="";
			TextBox txt = (TextBox)e.Item.Cells[2].FindControl("REFText") ;
			int siteId = VtkPageHeader1.DivSelectedId ;
			if( txt !=null && txt.Text.Length > 0)
			{
				reference = txt.Text;
				if (reference.Length <= 50)
				{
					try
					{
						Vha.Vtk.Donations.DonReference refhdl ;

						Int32 refId = Convert.ToInt32(e.Item.Cells[0].Text);
						if (refId > 0)
						{
							refhdl = new Vha.Vtk.Donations.DonReference(refId, VtkUtility.GetAppCon())   ;
						}
						else
						{
							refhdl = Vha.Vtk.Donations.DonReference.AddRecord(VtkUtility.GetAppCon()) ;
						}

						refhdl.ID = refId;
						refhdl.InstitutionFK = siteId ;
						refhdl.DonationReference = reference ;
						refhdl.Save() ;
						refhdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Reference Record Saved!" ;
						//update DataGrid
						UpdateREFGrid() ;
					}

					catch (VhaValidationException valErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving a record into Reference: " + valErr.Message) ;}
					catch (VhaTransactionException transErr)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving a record into Reference: " + transErr.Message) ;}
					catch (Exception err)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error saving a record into Reference: " + err.Message) ;}
				}
				else
				{VtkUtility.ErrMsgAdd(ErrorMessage, "Donation Reference, this field can be only 50 characters long ") ;	}
			}
			else
			{VtkUtility.ErrMsgAdd(ErrorMessage, "Donation Reference is required.") ;	}
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("../welcome.aspx" + "?"+VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.NumberOfMealsList.SelectedIndexChanged += new System.EventHandler(this.NumberOfMeals_click);
			this.GPFGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.GPFGrid_EditCommand);
			this.GPFGrid.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.GPFGrid_DeleteCommand);
			this.REFGrid.EditCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.REFGrid_EditCommand);
			this.REFGrid.DeleteCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.REFGrid_DeleteCommand);
			this.RequireLanguageCheckBox.CheckedChanged += new System.EventHandler(this.RequireLanguage_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
