using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using Vha.Vtk.Kernel.Data.SystemTables;
using Vha.Vtk.TimeKeeping;

namespace VTK.National
{
	/// <summary>
	/// Summary description for StationEdit.
	/// </summary>
	public class InstitutionEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox ZipText;
		protected System.Web.UI.WebControls.DropDownList StateList;
		protected System.Web.UI.WebControls.TextBox Address2Text;
		protected System.Web.UI.WebControls.TextBox CityText;
		protected System.Web.UI.WebControls.TextBox Address1Text;
		protected System.Web.UI.WebControls.DropDownList VisnList;
		protected System.Web.UI.WebControls.DropDownList PrimaryStationList;
		protected System.Web.UI.WebControls.TextBox StationNumberText;
		protected System.Web.UI.WebControls.TextBox StationNameText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DropDownList InstitutionList;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label UserLabel;
		protected System.Web.UI.WebControls.DropDownList UserList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Button EditButton;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Stations"))
				{
					if (!Page.IsPostBack)
					{
						//update the Station & user lists
						GetInstitutionList() ;
						GetUserList() ;

						//get visn list
						DataSet vds = Vha.Vtk.Kernel.Data.SystemTables.AdministrativeUnit.GetQuickList() ;
						DataTable vdt = vds.Tables["AdministrativeUnitList"] ;
						//sort on unitnumber, which is the visn number
						vds.Tables["AdministrativeUnitList"].DefaultView.Sort = "UnitNumber ASC" ;
						//create a new column that will combine unitnumber and name
						vdt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
						//loop and build string for the new column, DisplayName
						foreach (DataRow dr in vdt.Rows)
						{
							string s = String.Copy("(" + dr["UnitNumber"] + ") " + dr["UnitName"].ToString()) ;
							dr["DisplayName"] = s ;
						}
						//add the first row, uses Rows.InsertAt(
						DataRow vdr = vdt.NewRow() ;
						vdr["DisplayName"] = " -Select VISN- " ;
						vdr["ID"] = -1 ;
						vdt.Rows.InsertAt(vdr, 0) ;
						//define columns in list box
						VisnList.DataTextField = "DisplayName" ;
						VisnList.DataValueField = "ID" ;
						VisnList.DataSource = vdt ;
						VisnList.DataBind() ;
						vds.Dispose() ;
						vdt.Dispose() ;

						//populate state list
						DataSet dsst = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList() ;
						DataTable dtst = dsst.Tables["StateList"] ;
						dtst.DefaultView.Sort = "Abbreviation ASC" ;
						//add the first row, uses Rows.InsertAt(
						DataRow sdr = dtst.NewRow() ;
						sdr["Abbreviation"] = " -Select State- " ;
						sdr["Id"] = -1 ;
						dtst.Rows.InsertAt(sdr, 0) ;
						StateList.DataTextField = "Abbreviation" ;
						StateList.DataValueField = "Id" ;
						StateList.DataSource = dtst.DefaultView ;
						StateList.DataBind() ;
						dsst.Dispose() ;
						dtst.Dispose() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + err.Message) ;}
		}

		protected void SetFields(bool userEdit)
		{
			//set text fields to empty
			StationNameText.Text = string.Empty ;
			StationNumberText.Text = string.Empty ;
			Address1Text.Text = string.Empty ;
			Address2Text.Text = string.Empty ;
			CityText.Text = string.Empty ;
			ZipText.Text = string.Empty ;
			PrimaryStationList.SelectedIndex = 0 ;
			VisnList.SelectedIndex = 0 ;
			StateList.SelectedIndex = 0 ;
			InstitutionList.SelectedIndex = 0 ;
			UserList.SelectedIndex = 0 ;
			UserList.Visible = true ;
			UserLabel.Visible = true ;
			//clear variables
			ViewState["Id"] = string.Empty ;
			ViewState["Version"] = string.Empty ;
			//station list is enabled when the VISN is selected, VisnList_Click
			PrimaryStationList.Enabled = false ;
			StationNameText.Enabled = userEdit ;
			StationNumberText.Enabled = userEdit ;
			Address1Text.Enabled = userEdit ;
			Address2Text.Enabled = userEdit ;
			CityText.Enabled = userEdit ;
			ZipText.Enabled = userEdit ;
			VisnList.Enabled = userEdit ;
			StateList.Enabled = userEdit ;
		}

		private void GetInstitutionList()
		{
			try
			{
				//get Station list
				DataSet ids = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList() ;
				DataTable idt = ids.Tables["InstitutionList"] ;
				idt.DefaultView.Sort = "DisplayName ASC" ;
				//add the first row, uses Rows.InsertAt(
				DataRow idr = idt.NewRow() ;
				idr["DisplayName"] = " -Select Station- " ;
				idr["ID"] = -1 ;
				idt.Rows.InsertAt(idr, 0) ;
				//define columns in list box
				InstitutionList.DataTextField = "DisplayName" ;
				InstitutionList.DataValueField = "ID" ;
				InstitutionList.DataSource = idt ;
				InstitutionList.DataBind() ;
				ids.Dispose() ;
				idt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station List: " + err.Message) ;}
		}

		private void GetPrimaryList(int visn)
		{
			try
			{
				//get primary station list for a given visn
				DataSet psds = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickListByVISN(visn) ;
				DataTable psdt = psds.Tables["InstitutionList"] ;
				//add the first row, uses Rows.InsertAt(
				DataRow psdr = psdt.NewRow() ;
				psdr["DisplayName"] = " -Select Station- " ;
				psdr["ID"] = 0 ;
				psdt.Rows.InsertAt(psdr, 0) ;
				//define columns in list box
				PrimaryStationList.DataTextField = "DisplayName" ;
				PrimaryStationList.DataValueField = "ID" ;
				PrimaryStationList.DataSource = psdt ;
				PrimaryStationList.DataBind() ;
				psds.Dispose() ;
				psdt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Primary Station List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Primary Station List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Primary Station List: " + err.Message) ;}
		}

		private void GetUserList() 
		{
			try 
			{
				//TODO: get a better bizlayer method for this
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.User.GetQuickList();
				DataTable dt = ds.Tables["UserList"];
				dt.DefaultView.Sort = "FullNameForReports ASC";
				//UserList.DataSource=dv;
				UserList.DataTextField="FullNameForReports";
				UserList.DataValueField="Id";
				UserList.DataSource = dt ;
				UserList.DataBind();
				UserList.Items.Insert(0,new ListItem(" - select user - ","-1"));
			}
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
		}

		private bool IsInRoleFromUser(int userId, string roleName, int siteId) 
		{
			bool returnVal = false;
			try 
			{
				Vha.Vtk.Kernel.Data.SystemTables.User myUser = new Vha.Vtk.Kernel.Data.SystemTables.User(userId,
					VtkUtility.GetAppCon());
				DataSet ds = UserRole.GetUserRoleAtSites(myUser.NtUserName,VtkUtility.GetAppCon());
				DataTable dt = ds.Tables["UserRolesAtSites"];
				foreach (DataRow dr in dt.Rows) 
				{
					if (((int)dr["InstitutionId"])==siteId) 
					{
						if (((string)dr["RoleName"])==roleName) 
						{
							returnVal=true;
							break;
						}
					}
				}
				myUser.Dispose();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
			return returnVal;
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (StationNameText.Text == string.Empty)
			{ fields = "Station Name, " ;}
			if (StationNumberText.Text == string.Empty)
			{ fields = fields + "Station Number, " ;}
			if (StateList.SelectedIndex < 1)
			{ fields = fields + "State, " ;}

			return fields ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			//check for required fields
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;}
			else
			{
				bool versionOk = true ;
				try
				{
					//define handle
					Vha.Vtk.Kernel.Data.SystemTables.Institution inhdl ;
					//check if new or existing record
					if (ViewState["Id"].ToString() != string.Empty)
					{
						string inId = ViewState["Id"].ToString() ;
						inhdl = new Vha.Vtk.Kernel.Data.SystemTables.Institution(Convert.ToInt32(inId), VtkUtility.GetAppCon()) ;
						//check version
						if (ViewState["Version"].ToString() != inhdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Station record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
					else
					{
						//new record
						inhdl = Vha.Vtk.Kernel.Data.SystemTables.Institution.AddRecord(VtkUtility.GetAppCon()) ;
					}
					if (versionOk)
					{
						//file fields
						inhdl.NameOfInstitution = StationNameText.Text ;
						inhdl.StationNumber = StationNumberText.Text.Trim() ;
						inhdl.StreetAddress1 = Address1Text.Text ;
						inhdl.StreetAddress2 = Address2Text.Text ;
						inhdl.City = CityText.Text.Trim() ;
						inhdl.ZipCode = ZipText.Text.Trim() ;
						//file list fields
						if (StateList.SelectedIndex > 0)
						{ inhdl.StateId = Convert.ToInt32(StateList.SelectedItem.Value.ToString()) ;}
						if (PrimaryStationList.SelectedIndex > 0)
						{ inhdl.ParentInstitutionId = Convert.ToInt32(PrimaryStationList.SelectedItem.Value.ToString()) ;}
						if (VisnList.SelectedIndex > 0)
						{ inhdl.AdministrativeParentId = Convert.ToInt32(VisnList.SelectedItem.Value.ToString()) ;}
						//save and close
						inhdl.Save() ;
						inhdl.Dispose() ;

						string stationNumber = inhdl.StationNumber ;
						string roleName ;
						int siteId = inhdl.ID ;
						//update userrole file with user administrator, can't be EMC
						if (UserList.SelectedIndex > 0 && (stationNumber != "101EMC"))
						{
							//Co role = VtkCOUserAdministrator, Games sites role = VtkGamesAdministrator, all other sites = VtkSiteUserAdministrator
							if (stationNumber == "101")
							{ roleName = "VtkCOUserAdministrator" ;}
							else if (stationNumber.Substring(0,3) == "101")
							{
								//games sites begin with 101: 101GAG, 101WSC, 101CAF, 101WCG
								roleName = "VtkGamesAdministrator" ;
							}
							else
							{ roleName = "VtkSiteUserAdministrator" ;}
																	   
							int usrId = Convert.ToInt32(UserList.SelectedItem.Value) ;
							//check if user already has role
							if (!IsInRoleFromUser(usrId, roleName, siteId))
							{
								//add VtkSiteUserAdministrator role to user
								Vha.Vtk.Kernel.Data.SystemTables.UserRole usrhdl = Vha.Vtk.Kernel.Data.SystemTables.UserRole.AddRecord(VtkUtility.GetAppCon());
								usrhdl.InstitutionId=siteId;
								//TODO: check return value here
								usrhdl.RoleId=Role.GetIdForRole(roleName);
								usrhdl.UserId=usrId;
								usrhdl.Save();
								usrhdl.Dispose();
							}
						}
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update Station List
						GetInstitutionList() ;
						SetFields(false) ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Station Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Station Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Station Record: " + err.Message) ;}
			}
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a institution was selected
			if (InstitutionList.SelectedIndex > 0)
			{
				//get selected institution
				string inid = InstitutionList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save id and version
					Vha.Vtk.Kernel.Data.SystemTables.Institution inhdl = new Vha.Vtk.Kernel.Data.SystemTables.Institution(Convert.ToInt32(inid), VtkUtility.GetAppCon()) ;
					SetFields(true) ;
					ViewState["Id"] = inhdl.ID ;
					ViewState["Version"] = inhdl.Version.ToString() ;
					//set text fields to values
					StationNameText.Text = inhdl.NameOfInstitution ;
					StationNumberText.Text = inhdl.StationNumber ;
					Address1Text.Text = inhdl.StreetAddress1 ;
					Address2Text.Text = inhdl.StreetAddress2 ;
					CityText.Text = inhdl.City ;
					ZipText.Text = inhdl.ZipCode ;
					//set list fields
					if (inhdl.StateId != int.MinValue)
					{ VtkUtility.SetSelectedSingle(StateList.Items, inhdl.StateId.ToString()) ;}
					if (inhdl.AdministrativeParentId != int.MinValue)
					{
						VtkUtility.SetSelectedSingle(VisnList.Items, inhdl.AdministrativeParentId.ToString()) ;
						GetPrimaryList(inhdl.AdministrativeParentId) ;
						PrimaryStationList.Enabled = true ;
					}
					if (inhdl.ParentInstitutionId != int.MinValue)
					{ VtkUtility.SetSelectedSingle(PrimaryStationList.Items, inhdl.ParentInstitutionId.ToString()) ;}
					//if station is EMC, can't assign user administrator role
					if (inhdl.StationNumber == "101EMC")
					{
						UserList.Visible = false ;
						UserLabel.Visible = false ;
					}
					//enable post button
					PostButton.Enabled = true ;

					inhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station Record: " + transErr.Message + transErr.TransactionType + transErr.ClassName, "Vha.Vtk.FileMaintenance.InstitutionEdit") ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Station Record: " + err.Message) ;}
			}
			else
			{
				SetFields(false) ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Station to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields(true) ;
			PostButton.Enabled = true ;
		}

		private void VisnList_Click(object sender, System.EventArgs e)
		{
			//check that a visn is defined and used to get primary station list
			if (VisnList.SelectedIndex > 0)
			{
				GetPrimaryList(Convert.ToInt32(VisnList.SelectedItem.Value)) ;
				PrimaryStationList.Enabled = true ;
			}
			else
			{ PrimaryStationList.Enabled = false ;}		
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx") ;
		}

		private void DivisionChange(object sender, System.EventArgs e)
		{
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.VisnList.SelectedIndexChanged += new System.EventHandler(this.VisnList_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


	}
}
