using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using CrystalDecisions.CrystalReports.Engine;
using CREngine = CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;

using Vha.Vtk;
using Vha.Vss.Utility;
using VTK.Utility;
using VTK.RptCR;
using VTK.Reports;
using System.Configuration;
using System.IO;
using System.Text;

namespace VTK.National
{
	/// <summary>
	///    Summary description for CrystalExport.
	/// </summary>
	public class NationalCrystalExport : System.Web.UI.Page
	{
		private IDictionary config;
		internal UIReportParams par = null;
		internal CREngine.ReportDocument rpt = null;
		private CREngine.Database crDatabase;
		private CREngine.Tables crTables;
		private TableLogOnInfo crTableLogOnInfo;
		private ConnectionInfo crConnectionInfo;

		private CREngine.Sections crSections;
		private CREngine.ReportObjects crReportObjects;
		private CREngine.SubreportObject crSubReportObject;

		public NationalCrystalExport()
		{
			try
			{
				config = (IDictionary)ConfigurationSettings.GetConfig("VssConfiguration/DSN");
			}
			catch{}
			Page.Init += new System.EventHandler(Page_Init);
		}

		protected void Page_Load(object sender, EventArgs e)
		{
			ExportReport();
		}

		protected void ExportReport() 
		{
			par = RptUtility.GetParams(Context);
			rpt = null;

			// set up filenames 
			StringBuilder sb = new StringBuilder(RptUtility.UniqueReportName(Page.User.Identity.Name));
			sb.Append(par.ReportType.ToString());
			sb.Append(RptUtility.ExportExtension(par.ReportFormat));
			string reportName = sb.ToString();
			string writeFileName=Request.ApplicationPath+"/temp/"+reportName;
			string deleteFileName=Request.PhysicalApplicationPath+"temp\\"+reportName;

			// load the report
			RptUtility.LoadReport(par.ReportType.ToString(), out rpt);
			//Creating connection to database from ODBC 
			DataEncoder dataDecoder = new DataEncoder("VhaVss");
			crConnectionInfo = new ConnectionInfo();
			crConnectionInfo.ServerName = (string)config["Name"];
			crConnectionInfo.UserID = (string)config["UserId"];
			crConnectionInfo.Password = dataDecoder.DecodeString(((string)config["Password"]).Substring(1, ((string)config["Password"]).Length - 2));
			crConnectionInfo.DatabaseName = (string)config["DBName"];
  

			//Looping thru each Table on the report to add the connection
			crDatabase = rpt.Database;
			crTables = crDatabase.Tables;

			foreach (CREngine.Table crTable in crTables)
			{
				crTableLogOnInfo = crTable.LogOnInfo;
				crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
				crTable.ApplyLogOnInfo(crTableLogOnInfo);
			}
      
			//Looping Through each of the sections, Reports in those sections, 
			//and SubReports in those Reports.
			crSections = rpt.ReportDefinition.Sections;
			foreach (CREngine.Section crSection in crSections)
			{
				crReportObjects = crSection.ReportObjects;
				foreach(CREngine.ReportObject crReportObject in crReportObjects)
				{
					if(crReportObject.Kind == ReportObjectKind.SubreportObject)
					{
						crSubReportObject = (CREngine.SubreportObject)crReportObject;
						crDatabase = crSubReportObject.OpenSubreport(crSubReportObject.SubreportName).Database;
						crTables = crDatabase.Tables;

						foreach(CREngine.Table crTable in crTables)
						{
							crTableLogOnInfo = crTable.LogOnInfo;
							crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
							crTable.ApplyLogOnInfo(crTableLogOnInfo);              
						}
					}
				}
			}

			// load the parameters
			RptUtility.LoadReportParamsExport(par, rpt);
			// set the export options
			ExportOptions opts = rpt.ExportOptions;
			RptUtility.SetExportOptions(opts,par.ReportFormat,reportName,Request.PhysicalApplicationPath);

			try 
			{
				//export the report to appdirectory\temp
				rpt.Export();
				rpt.Dispose(); 
				// stream the report back to the browser from the exported file
				Response.Clear();
				switch (par.ReportFormat) 
				{
					case UIReportFormat.Acrobat:
						Response.ContentType="application/pdf";
						break;
					case UIReportFormat.Excel:
						Response.ContentType="application/vnd.ms-excel";
						break;
					case UIReportFormat.Word:
						Response.ContentType="application/msword";
						break;
					default:
						break;
				} 
				//The next line -- disabling caching -- results in a blank web page.
				//Response.Cache.SetCacheability(System.Web.HttpCacheability.NoCache);
				Response.AppendHeader("content-disposition", " INLINE");
				FileInfo fileInfo=new FileInfo(deleteFileName);
				Response.AppendHeader("content-length", fileInfo.Length.ToString());
				//VtkUtility.PageCacheDisable(Page.Response);
				Response.WriteFile(writeFileName); 
				// flush so that the file pointer will be closed before calling delete()
				Response.Flush();
				fileInfo.Delete();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(err.Message,"CrystalExport: "+par.ReportType.ToString());
			} 
			finally 
			{
				Response.End();
			}
		}

		protected void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP+ Windows Form Designer.
			//
			InitializeComponent();
		}

		/// <summary>
		///    Required method for Designer support - do not modify
		///    the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.Load += new System.EventHandler(this.Page_Load);
		}
	}
}
