using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.DataClasses ;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.National
{
	/// <summary>
	/// Summary description for NationalOfficialsEdit.
	/// </summary>
	public class NationalOfficialsEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.DropDownList OfficialsList;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.WebControls.TextBox LastNameText;
		protected System.Web.UI.WebControls.TextBox FirstNameText;
		protected System.Web.UI.WebControls.TextBox MiddleNameText;
		protected System.Web.UI.WebControls.TextBox NamePrefixText;
		protected System.Web.UI.WebControls.TextBox TitleText;
		protected System.Web.UI.WebControls.TextBox NameSuffixText;
		protected System.Web.UI.WebControls.RadioButtonList NationalRadioButtonList;
		protected System.Web.UI.WebControls.DropDownList OrganizationList;
		protected System.Web.UI.WebControls.CheckBox CertifyingCheckBox;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate AppointedDate;
		protected System.Web.UI.WebControls.TextBox Address1Text;
		protected System.Web.UI.WebControls.DropDownList StateList;
		protected System.Web.UI.WebControls.TextBox CityText;
		protected System.Web.UI.WebControls.TextBox ZipText;
		protected System.Web.UI.WebControls.TextBox PhoneText;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Button DeleteButton;
		protected System.Web.UI.WebControls.Label ErrorMessage;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("National Officials Edit"))
				{
					if (!Page.IsPostBack)
					{
						//update the lists
						GetOrganizationList();

						//initialize date
						AppointedDate.YearListBegin = 1990 ;
						AppointedDate.YearListEnd = DateTime.Now.Year ;
						AppointedDate.InitializeControl() ;

						//populate state list
						DataSet dsst = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList() ;
						DataTable dtst = dsst.Tables["StateList"] ;
						dtst.DefaultView.Sort = "Abbreviation ASC" ;

						// insert a new row for the "not selected" item
						DataRow stdr = dtst.NewRow() ;
						stdr["Id"]=int.MinValue;
						stdr["Abbreviation"]="--";
						dtst.Rows.InsertAt(stdr,0);

						StateList.DataTextField = "Abbreviation" ;
						StateList.DataValueField = "Id" ;
						StateList.DataSource = dtst.DefaultView ;
						StateList.DataBind() ;
						dsst.Dispose() ;
						dtst.Dispose() ;

						SetFields() ;
						EditEnable(false) ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + err.Message) ;}
		}

		private void GetOfficialsList(int orgId)
	{
			try
			{
				//populate list of Officials, get dataset, sort by last name
				DataSet dsoff = Vha.Vtk.NationalOfficials.NationalOfficials.GetQuickListByOrganizationId(orgId) ;
				dsoff.Tables["NationalOfficialsList"].DefaultView.Sort = "LastName ASC" ;
				DataTable dtoff = dsoff.Tables["NationalOfficialsList"] ;

				//create a new column that will combine last & first names
				dtoff.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;

				if (dtoff.Rows.Count > 0)
				{
					//loop and build string for the new column, DisplayName
					foreach (DataRow dr in dtoff.Rows)
					{
						string s = String.Copy(dr["LastName"].ToString() + ", " + dr["FirstName"] + "  " + dr["Title"]) ;
						dr["DisplayName"] = s ;
					}
					
					//define columns in list box
					OfficialsList.DataTextField = "DisplayName" ;
					OfficialsList.DataValueField = "Id" ;

					//add the first row -- Sachy 07/11/2003
					DataRow droff = dtoff.NewRow() ;
					droff["DisplayName"] = " -Select an official- " ;
					droff["Id"] = 0 ;
					dtoff.Rows.InsertAt(droff, 0) ;

					//bind list box to DataTable and dispose
					OfficialsList.DataSource = dtoff ;
					OfficialsList.DataBind() ;
					//if only one, select it
					if (dtoff.Rows.Count == 1)
					{ OfficialsList.SelectedIndex = 0 ;}
				}
				else
				{
					OfficialsList.Items.Clear() ;
					OfficialsList.Items.Add(new ListItem("-No Officials to select-",int.MinValue.ToString()));
				}

				dsoff.Dispose() ;
				dtoff.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials List: " + err.Message) ;}
		}

		private void GetOrganizationList()
		{
			try
			{
				//populate list of Organizations, get dataset, sort by code
				DataSet dsorg = Vha.Vtk.Common.Organization.GetNationalQuickListByCode() ;
				dsorg.Tables["OrganizationList"].DefaultView.Sort = "Name ASC" ;
				DataTable dtorg = dsorg.Tables["OrganizationList"] ;

				//create a new column that will combine code and name
				dtorg.Columns.Add("CodeAndName", System.Type.GetType("System.String")) ;

				//loop and build string for the new column, CodeAndName
				foreach (DataRow dr in dtorg.Rows)
				{
					string s = String.Copy(dr["Name"] + " (" + dr["Code"].ToString() + ") ") ;
					dr["CodeAndName"] = s ;
				}
				
				//add the first row
				DataRow drorg = dtorg.NewRow() ;
				drorg["CodeAndName"] = " -Select Organization Code- " ;
				drorg["Id"] = 0 ;
				dtorg.Rows.InsertAt(drorg, 0) ;

				//define columns in list box
				OrganizationList.DataTextField = "CodeAndName" ;
				OrganizationList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				OrganizationList.DataSource = dtorg ;
				OrganizationList.DataBind() ;
				dsorg.Dispose() ;
				dtorg.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//set text fields to empty
			LastNameText.Text = string.Empty ;
			FirstNameText.Text = string.Empty ;
			MiddleNameText.Text = string.Empty ;
			NamePrefixText.Text = string.Empty ;
			NameSuffixText.Text = string.Empty ;
			TitleText.Text = string.Empty ;
			Address1Text.Text = string.Empty ;
			CityText.Text = string.Empty ;
			ZipText.Text = string.Empty ;
			PhoneText.Text = string.Empty ;
			AppointedDate.Date = DateTime.MinValue ;
			//set checkboxs
			CertifyingCheckBox.Checked = false ;
			//set lists
			NationalRadioButtonList.SelectedIndex = -1 ;
			StateList.SelectedIndex = 0 ;
			//OfficialsList.SelectedIndex = 0 ;

			ViewState["Id"] = string.Empty ;
			ViewState["Version"] = string.Empty ;
			//setup for a new record
			RecordIdLabel.Text = "New" ;
		}

		private void EditEnable(bool editable)
		{
			//set buttons, if editable or not, at pageload and  organizationlist_click
			NewButton.Enabled = editable ;
			EditButton.Enabled = editable ;
			PostButton.Enabled = editable ;
			//list is treated like edit buttons
			OfficialsList.Enabled = editable ;
			//
			if (!editable)
			{
				//clear officials list until organization is selected, same with edit buttons
				OfficialsList.Items.Clear() ;
				OfficialsList.Items.Add(new ListItem("Select an Organization first",int.MinValue.ToString()));
				RecordIdLabel.Text = "Select an Organization first" ;
			}
			//delete button should only be set if editing a record
			DeleteButton.Enabled = false ;
		}

		private string MissingFields()
		{
			bool flag = false ;
			string fields = string.Empty ;
			if (LastNameText.Text == string.Empty)
			{
				fields = "Last Name" ;
				flag = true ;
			}
			if (Address1Text.Text == string.Empty)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Street Address #1" ;
				flag = true ;
			}
			if (CityText.Text == string.Empty)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "City" ;
				flag = true ;
			}
			if (StateList.SelectedIndex < 1)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "State" ;
				flag = true ;
			}
			if (ZipText.Text == string.Empty)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "Zip" ;
				flag = true ;
			}
			if (NationalRadioButtonList.SelectedIndex < 0)
			{
				if (flag)
				{ fields = fields + ", " ;}
				fields = fields + "National Representative or Deputy" ;
				flag = true ;
			}

			return fields ;
		}

		private string CheckDates()
		{
			string errorMsg = string.Empty ;
			string msg = string.Empty ;
			//flag is for multiple date controller fields
			bool flag = false ;
			//the setting of date is needed to force the the object to set the ValidateErrorMessage
			DateTime date ;
			date = AppointedDate.Date ;
			msg = AppointedDate.ValidateErrorMessage ;
			if (msg != string.Empty && (msg != "Not selected"))
			{
				if (flag)
				{ errorMsg = errorMsg + ", " ;}
				errorMsg = errorMsg + "Date Appointed is invalid" ;
				flag = true ;
			}
			return errorMsg ;
		}

		private void OrganizationList_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			int orgId = 0 ;
			if (OrganizationList.SelectedIndex > 0)
			{
				orgId = Convert.ToInt32(OrganizationList.SelectedItem.Value) ;
				EditEnable(true) ;
				GetOfficialsList(orgId) ;
			}
			else
			{
				EditEnable(false) ;
			}
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Official was selected
			if (OfficialsList.SelectedIndex > 0)
			{
				try
				{
					//get selected Official
					string offid = OfficialsList.SelectedItem.Value.ToString() ;
					SetFields() ;
					//create handle and save id and version
					Vha.Vtk.NationalOfficials.NationalOfficials offhdl = new Vha.Vtk.NationalOfficials.NationalOfficials(Convert.ToInt32(offid), VtkUtility.GetAppCon()) ;
					ViewState["Id"] = offhdl.ID ;
					ViewState["Version"] = offhdl.Version.ToString() ;

					//populate label fields to edit
					//set text fields to values
					RecordIdLabel.Text = offhdl.ID.ToString() ;
					LastNameText.Text = offhdl.LastName ;
					FirstNameText.Text = offhdl.FirstName ;
					MiddleNameText.Text = offhdl.MiddleName ;
					NamePrefixText.Text = offhdl.NamePrefix ;
					NameSuffixText.Text = offhdl.NameSuffix ;
					TitleText.Text = offhdl.Title ;
					Address1Text.Text = offhdl.StreetAddress1 ;
					CityText.Text = offhdl.City ;
					ZipText.Text = offhdl.Zip ;
					PhoneText.Text = offhdl.Telephone ;
					AppointedDate.Date = offhdl.DateAppointed.Date ;
					//set checkboxs & lists
					VtkUtility.SetSelectedSingle(StateList.Items, offhdl.StateId.ToString()) ;
					//VtkUtility.SetSelectedSingle(OrganizationList.Items, offhdl.OrganizationId.ToString()) ;
					CertifyingCheckBox.Checked = offhdl.IsNationalCertifyingOfficial ;
					//NationalRepORNationalDep can only be a "D" or "R", NationRadioButtonList Index: 0=Rep, 1=Dep, 2=neither
					switch (offhdl.NationalRepORNationalDep)
					{
						case "R":
							NationalRadioButtonList.SelectedIndex = 0 ;
							break ;
						case "D":
							NationalRadioButtonList.SelectedIndex = 1 ;
							break ;
						default:
							NationalRadioButtonList.SelectedIndex = 2 ;
							break ;
					}

					//enable delete buttons
					DeleteButton.Enabled = true ;

					offhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Officials Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select an Official to Edit") ;}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			DeleteButton.Enabled = false ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			try
			{
				if (OrganizationList.SelectedIndex > 0)
				{
					string offid ;
					int orgId = Convert.ToInt32(OrganizationList.SelectedItem.Value) ;
					Vha.Vtk.NationalOfficials.NationalOfficials offhdl ;
					bool versionOk = true ;
					string errormsg = MissingFields() ;

					//check for missing data
					if (errormsg != string.Empty)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + errormsg) ;}
					else
					{
						//check for invalid date
						errormsg = CheckDates() ;
						if (errormsg != string.Empty)
						{ VtkUtility.ErrMsgAdd(ErrorMessage, errormsg) ;}
						else
						{
							//check if new or existing record
							if (ViewState["Id"].ToString() != string.Empty)
							{
								offid = ViewState["Id"].ToString() ;
								//create handle for existing record
								offhdl = new Vha.Vtk.NationalOfficials.NationalOfficials(Convert.ToInt32(offid), VtkUtility.GetAppCon()) ;
								//check version
								if (ViewState["Version"].ToString() != offhdl.Version.ToString())
								{
									VtkUtility.ErrMsgAdd(ErrorMessage, "Current Official's record has changed while you were editing, Please press EXIT and start over. ") ;
									versionOk = false ;
								}
							}
							else
							{
								//new record
								offhdl = Vha.Vtk.NationalOfficials.NationalOfficials.AddRecord(VtkUtility.GetAppCon()) ;
							}
							if (versionOk)
							{
								//file fields
								offhdl.LastName = LastNameText.Text ;
								offhdl.FirstName = FirstNameText.Text ;
								offhdl.MiddleName = MiddleNameText.Text ;
								offhdl.NamePrefix = NamePrefixText.Text ;
								offhdl.NameSuffix = NameSuffixText.Text ;
								offhdl.Title = TitleText.Text ;
								offhdl.StreetAddress1 = Address1Text.Text ;
								offhdl.City = CityText.Text ;
								offhdl.Zip = ZipText.Text ;
								offhdl.Telephone = PhoneText.Text ;
								offhdl.DateAppointed = AppointedDate.Date ;
								//set checkboxs & lists
								offhdl.StateId = Convert.ToInt32(StateList.SelectedItem.Value.ToString()) ;
								offhdl.OrganizationId = orgId ;
								offhdl.IsNationalCertifyingOfficial = CertifyingCheckBox.Checked ;
								//NationRadioButtonList Values: 1=Rep, 2=Dep, 0=neither
								switch (NationalRadioButtonList.SelectedItem.Value)
								{
									case "1":
										offhdl.NationalRepORNationalDep = "R" ;
										break ;
									case "2":
										offhdl.NationalRepORNationalDep = "D" ;
										break ;
									default:
										offhdl.NationalRepORNationalDep = string.Empty ;
										break ;
								}

								//save & disposte
								offhdl.Save() ;
								offhdl.Dispose() ;
								//update confirmation message
								ConfirmationMessage.Text = "Record Posted!" ;
								//update officials List
								GetOfficialsList(orgId) ;
								SetFields() ;
							}
						}
					}
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the record, Please exit and try again") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Officials Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Officials Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Officials Record: " + err.Message) ;}
		}

		private void DeleteButton_Click(object sender, System.EventArgs e)
		{
			string offid ;
			int orgId = Convert.ToInt32(OrganizationList.SelectedItem.Value) ;
			Vha.Vtk.NationalOfficials.NationalOfficials offhdl ;
			try
			{
				//check if new or existing record
				if (ViewState["Id"].ToString() != string.Empty)
				{
					offid = ViewState["Id"].ToString() ;
					//create handle for existing record
					offhdl = new Vha.Vtk.NationalOfficials.NationalOfficials(Convert.ToInt32(offid), VtkUtility.GetAppCon()) ;
					//delete & save
					offhdl.Delete() ;
					offhdl.Save() ;
					offhdl.Dispose() ;
					//update confirmation message
					ConfirmationMessage.Text = "Record Deleted!" ;
					//update officials List
					GetOfficialsList(orgId) ;

					SetFields() ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must select an Official to Delete") ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Officials Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Officials Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error deleting the Officials Record: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.OrganizationList.SelectedIndexChanged += new System.EventHandler(this.OrganizationList_Click);
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.DeleteButton.Click += new System.EventHandler(this.DeleteButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
