using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.DataClasses ;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.National
{
	/// <summary>
	/// Summary description for NationalOrganizationEdit.
	/// </summary>
	public class NationalOrganizationEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.CheckBox OrganizationInactiveCheckBox;
		protected System.Web.UI.WebControls.TextBox OrganizationAbbreviationText;
		protected System.Web.UI.WebControls.TextBox OrganizationNameText;
		protected System.Web.UI.WebControls.TextBox OrganizationIdText;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.DropDownList NACStatusList;
		protected System.Web.UI.WebControls.CheckBox NACCheckBox;
		protected System.Web.UI.WebControls.CheckBox ExecutiveCheckBox;
		protected System.Web.UI.WebControls.Label NACStatusLabel;
		protected System.Web.UI.WebControls.Label ExecutiveLabel;
		protected System.Web.UI.WebControls.DropDownList MonthList;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.DropDownList OrganizationCodeList;
	
		public NationalOrganizationEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("National Organization Codes"))
				{
					if (!Page.IsPostBack)
					{
						//populate list of NACStatus list
						DataSet dsns = Vha.Vtk.NationalOfficials.NACStatus.GetNacStatusList() ;
						DataTable dtns = dsns.Tables["NACStatusList"] ;
						//add the first row
						DataRow drns = dtns.NewRow() ;
						drns["MembershipStatus"] = " -Select NAC Status- " ;
						drns["ID"] = "0" ;
						dtns.Rows.InsertAt(drns, 0) ;
						NACStatusList.DataTextField = "MembershipStatus" ;
						NACStatusList.DataValueField = "ID" ;
						NACStatusList.DataSource = dtns ;
						NACStatusList.DataBind() ;
						dsns.Dispose() ;
						dtns.Dispose() ;

						//update the organization list
						GetOrganizationList() ;

						//enable new,edit buttons
						NewButton.Enabled = true ;
						EditButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		private void GetOrganizationList()
		{
			try
			{
				//tracks last code of org.
				int lastCode = 0 ;

				//populate list of Organizations, get dataset, sort by code
				DataSet dsorg = Vha.Vtk.Common.Organization.GetNationalQuickListByCode() ;
				dsorg.Tables["OrganizationList"].DefaultView.Sort = "Name ASC" ;
				DataTable dtorg = dsorg.Tables["OrganizationList"] ;

				//create a new column that will combine code and name
				dtorg.Columns.Add("CodeAndName", System.Type.GetType("System.String")) ;

				//loop and build string for the new column, CodeAndName
				foreach (DataRow dr in dtorg.Rows)
				{
					string s = String.Copy(dr["Name"] + " (" + dr["Code"].ToString() + ") ") ;
					dr["CodeAndName"] = s ;
					//check code, save the last code. It will be used to add new orgs.
					if (dr["Code"].ToString() != string.Empty)
					{
						if (Convert.ToInt32(dr["Code"]) > lastCode)
						{ lastCode = Convert.ToInt32(dr["Code"]) ;}
					}
				}
				
				//add the first row
				DataRow drorg = dtorg.NewRow() ;
				drorg["CodeAndName"] = " -Select Organization Code- " ;
				drorg["Id"] = 0 ;
				dtorg.Rows.InsertAt(drorg, 0) ;

				//save last code
				ViewState["lastCode"] = lastCode.ToString() ;

				//define columns in list box
				OrganizationCodeList.DataTextField = "CodeAndName" ;
				OrganizationCodeList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				OrganizationCodeList.DataSource = dtorg ;
				OrganizationCodeList.DataBind() ;
				dsorg.Dispose() ;
				dtorg.Dispose() ;

			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization List: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//set text fields to empty
			OrganizationIdText.Text = string.Empty ;
			OrganizationNameText.Text = string.Empty ;
			OrganizationAbbreviationText.Text = string.Empty ;
			OrganizationInactiveCheckBox.Checked = false ;
			NACStatusList.SelectedIndex = 0 ;
			MonthList.SelectedIndex = 0 ;
			ExecutiveCheckBox.Checked = false ;
			NACCheckBox.Checked = false ;
			ViewState["organizationId"] = string.Empty ;
			ViewState["organizationVersion"] = string.Empty ;
			NACCheck(false) ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Organization was selected
			if (OrganizationCodeList.SelectedIndex>0)
			{
				//get selected Organization
				string orgid = OrganizationCodeList.SelectedItem.Value.ToString() ;
				bool nacCheck ;
				try
				{
					//create handle and save id and version
					Vha.Vtk.Common.Organization orghdl = new Vha.Vtk.Common.Organization(Convert.ToInt32(orgid), VtkUtility.GetAppCon()) ;
					ViewState["organizationId"] = orghdl.ID ;
					ViewState["organizationVersion"] = orghdl.Version.ToString() ;

					//populate label fields to edit
					//set text fields to values
					OrganizationIdText.Text = orghdl.Code.ToString() ;
					OrganizationNameText.Text = orghdl.OrganizationName.ToString() ;
					OrganizationAbbreviationText.Text = orghdl.Abbreviation.ToString() ;
					OrganizationInactiveCheckBox.Checked = orghdl.IsInactive ;
					VtkUtility.SetSelectedSingle(MonthList.Items, orghdl.AnnualJointReviewMonth.ToString()) ;
					nacCheck = orghdl.IsOnNationalAdvisoryCommittee ;
					NACCheckBox.Checked = nacCheck ;
					NACCheck(nacCheck) ;
					if (nacCheck)
					{
						//get field values
						ExecutiveCheckBox.Checked = orghdl.IsNACExecutiveMember ;						
						VtkUtility.SetSelectedSingle(NACStatusList.Items, orghdl.NACMembershipStatusId.ToString()) ;
					}
					//enable Save button
					PostButton.Enabled = true ;

					//place focus on OrganizationIdText field
					//orgBody.Attributes.Add("onLoad","document.orgForm.OrganizationNameText.focus()") ;

					orghdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Organization Record: " + err.Message) ;}
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Organization Code to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			//OrganizationCodeList.SelectedIndex = 0 ;

			//last code from OrganizationCodeList add 1
			int lastCode = Convert.ToInt32(ViewState["lastCode"]) ;
			lastCode++ ;

			//set text values
			OrganizationIdText.Text = lastCode.ToString() ;
			//enable save button
			PostButton.Enabled = true ;

			//place focus on OrganizationIdText field
			//orgBody.Attributes.Add("onLoad","document.orgForm.OrganizationNameText.focus()") ;
		}

		private void NACCheckBox_Click(object sender, System.EventArgs e)
		{
			NACCheck(NACCheckBox.Checked) ;		
		}

		private void NACCheck(bool check)
		{
			if (check)
			{
				NACStatusList.Visible = true ;
				NACStatusLabel.Visible = true ;
				ExecutiveCheckBox.Visible = true ;
				ExecutiveLabel.Visible = true ;
			}
			else
			{
				NACStatusList.Visible = false ;
				NACStatusLabel.Visible = false ;
				ExecutiveCheckBox.Visible = false ;
				ExecutiveLabel.Visible = false ;
			}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (OrganizationIdText.Text != string.Empty)
			{
				//flag to check if version number has changed
				bool versionOk = true ;
				try
				{
					Vha.Vtk.Common.Organization orghdl ;
					//check if edit existing record or new record
					if (ViewState["organizationId"].ToString() != string.Empty)
					{
						string orgid = ViewState["organizationId"].ToString() ;
						//create handle and open current record
						orghdl = new Vha.Vtk.Common.Organization(Convert.ToInt32(orgid), VtkUtility.GetAppCon()) ;

						//check version
						if (ViewState["organizationVersion"].ToString() != orghdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Organization record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
						//new record
					else
					{
						//create handle and open new record
						orghdl = Vha.Vtk.Common.Organization.AddRecord(VtkUtility.GetAppCon()) ;
					}
					if (versionOk)
					{
						orghdl.Code = OrganizationIdText.Text ;
						orghdl.OrganizationName = OrganizationNameText.Text ;
						orghdl.Abbreviation = OrganizationAbbreviationText.Text ;
						orghdl.IsInactive = OrganizationInactiveCheckBox.Checked ;
						orghdl.Scope = "N" ;
						orghdl.IsOnNationalAdvisoryCommittee = NACCheckBox.Checked ;
						orghdl.IsNACExecutiveMember = ExecutiveCheckBox.Checked ;
						if (MonthList.SelectedIndex > 0)
						{ orghdl.AnnualJointReviewMonth = Convert.ToInt32(MonthList.SelectedItem.Value.ToString()) ;}
						if (NACStatusList.SelectedIndex > 0)
						{ orghdl.NACMembershipStatusId = Convert.ToInt32(NACStatusList.SelectedItem.Value.ToString()) ;}

						//save and close
						orghdl.Save() ;
						orghdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//clear all fields
						SetFields() ;
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Organization Record: " + err.Message) ;}
				finally
				{
					//update Organization List
					GetOrganizationList() ;
				}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was no record to Save") ;}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.NACCheckBox.CheckedChanged += new System.EventHandler(this.NACCheckBox_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
