using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;

namespace VTK.National
{
	/// <summary>
	/// Summary description for NationalProgramsEdit.
	/// </summary>
	public class NationalProgramsEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.TextBox CodeText;
		protected System.Web.UI.WebControls.Label ProgramIdLabel;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.DropDownList ProgramList;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Button NewButton;
		protected System.Web.UI.WebControls.Button PostButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.RangeValidator RangeValidator1;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.Label ErrorMessage;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if(VtkPageHeader1.IsDivSelected("National Programs")) 
				{
					if (!Page.IsPostBack)
					{
						GetProgramList() ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//set text fields to empty
			ProgramIdLabel.Text = string.Empty ;
			CodeText.Text = string.Empty ;
			NameText.Text = string.Empty ;

			ViewState["Id"] = string.Empty ;
			ViewState["Version"] = string.Empty ;
		}

		private void GetProgramList()
		{
			try
			{
				//get program list
				Page.Trace.Warn("Connection", VtkUtility.GetAppCon().ConnectString);
				DataSet pds = Vha.Vtk.ServicesDirectory.Programs.GetVoluntaryPrograms(0, VtkUtility.GetAppCon()) ;
				pds.Tables["ProgramsList"].DefaultView.Sort = "ProgramName" ;
				DataTable pdt = pds.Tables["ProgramsList"] ;
				pdt.Columns.Add("ProgramAndCode", System.Type.GetType("System.String")) ;

				//loop and build string for the new column, CodeAndName
				foreach (DataRow dr in pdt.Rows)
				{
					string s = String.Copy(dr["ProgramName"] + " (" + dr["ProgramCode"].ToString() + ") ") ;
					dr["ProgramAndCode"] = s ;
				}

				//add the first row, uses Rows.InsertAt(
				DataRow pdr = pdt.NewRow() ;
				pdr["ProgramAndCode"] = " -Select Program- " ;
				pdr["ProgramId"] = -1 ;
				pdt.Rows.InsertAt(pdr, 0) ;

				//define columns in list box
				ProgramList.DataTextField = "ProgramAndCode" ;
				ProgramList.DataValueField = "ProgramId" ;
				ProgramList.DataSource = pdt ;
				ProgramList.DataBind() ;
				pds.Dispose() ;
				pdt.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program List: " + err.Message) ;}
		}

		private string MissingFields()
		{
			string fields = string.Empty ;
			if (CodeText.Text == string.Empty)
			{ fields = "Code, " ;}
			if (NameText.Text == string.Empty)
			{ fields = fields + "Program Name " ;}

			return fields ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a program was selected
			if (ProgramList.SelectedIndex > 0)
			{
				//get selected program
				string pid = ProgramList.SelectedItem.Value.ToString() ;
				try
				{
					//clear fields
					SetFields() ;
					//create handle and save id and version
					Vha.Vtk.ServicesDirectory.Programs phdl = new Vha.Vtk.ServicesDirectory.Programs(Convert.ToInt32(pid), VtkUtility.GetAppCon()) ;
					ViewState["Id"] = phdl.ID ;
					ViewState["Version"] = phdl.Version.ToString() ;
					//set text fields to values
					ProgramIdLabel.Text = phdl.ID.ToString() ;
					CodeText.Text = phdl.Code.ToString() ;
					NameText.Text = phdl.ProgramName ;
					//enable post button
					PostButton.Enabled = true ;
					phdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Program Record: " + err.Message) ;}
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Program to Edit") ;
			}		
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			//clear the program list
			ProgramList.SelectedIndex = 0 ;
			SetFields() ;
			//set id label
			ProgramIdLabel.Text = "New" ;
			PostButton.Enabled = true ;		
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			string missingdata = MissingFields() ;
			if (missingdata != string.Empty)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "The following fields are Required: " + missingdata) ;}
			else
			{
				bool versionOk = true ;
				try
				{
					//define handle
					Vha.Vtk.ServicesDirectory.Programs phdl ;
					//check if new or existing record
					if (ViewState["Id"].ToString() != string.Empty)
					{
						string pid = ViewState["Id"].ToString() ;
						phdl = new Vha.Vtk.ServicesDirectory.Programs(Convert.ToInt32(pid), VtkUtility.GetAppCon()) ;
						//check version
						if (ViewState["Version"].ToString() != phdl.Version.ToString())
						{
							VtkUtility.ErrMsgAdd(ErrorMessage, "Current Program record has changed while you were editing, Please press EXIT and start over. ") ;
							versionOk = false ;
						}
					}
					else
					{
						//new record
						phdl = Vha.Vtk.ServicesDirectory.Programs.AddRecord(VtkUtility.GetAppCon()) ;
					}
					if (versionOk)
					{
						//file fields
						phdl.Code = Convert.ToInt32(CodeText.Text) ;
						phdl.ProgramName = NameText.Text ;
						phdl.Scope = "N" ;
						//save & close
						phdl.Save() ;
						phdl.Dispose() ;
						//update confirmation message
						ConfirmationMessage.Text = "Record Posted!" ;
						//update Organization List
						GetProgramList() ;
						SetFields() ;
					}
					//disable postbutton, record has been saved
					PostButton.Enabled = false ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Program Record: " + err.Message) ;}
			}		
		}

		private void ExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx") ;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
