using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.DataClasses ;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.National
{
	/// <summary>
	/// Summary description for NationalServiceAssignmentEdit.
	/// </summary>
	public class NationalServiceAssignmentEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.TextBox ServiceSubdivisionText;
		protected System.Web.UI.WebControls.TextBox ServiceAbbreviationText;
		protected System.Web.UI.WebControls.TextBox ServiceNameText;
		protected System.Web.UI.WebControls.TextBox ServiceIdText;
		protected System.Web.UI.WebControls.DropDownList ServiceCodeList;
		protected System.Web.UI.HtmlControls.HtmlForm ServiceAssignment;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button EditButton;
		protected System.Web.UI.WebControls.Button NewButton;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label RecordIdLabel;
		protected System.Web.UI.WebControls.Button PostButton;
	
		public NationalServiceAssignmentEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("National Service Codes"))
				{
					if (!Page.IsPostBack)
					{
						//update service list
						GetServiceList() ;

						SetFields() ;
						PostButton.Enabled = true ;
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + err.Message) ;}
		}

		private void GetServiceList()
		{
			try
			{
				//populate list of Services, get dataset, sort by code
				DataSet dssrv = Vha.Vtk.Common.Service.GetNationalQuickListByCode() ;
				dssrv.Tables["ServiceList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable dtsrv = dssrv.Tables["ServiceList"] ;

				//add the first row
				DataRow drsrv = dtsrv.NewRow() ;
				drsrv["DisplayName"] = " -Select Service Code- " ;
				drsrv["Id"] = 0 ;
				dtsrv.Rows.InsertAt(drsrv, 0) ;

				//define columns in list box
				ServiceCodeList.DataTextField = "DisplayName" ;
				ServiceCodeList.DataValueField = "Id" ;

				//bind list box to DataTable and dispose
				ServiceCodeList.DataSource = dtsrv ;
				ServiceCodeList.DataBind() ;
				dssrv.Dispose() ;
				dtsrv.Dispose() ;
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service List: " + err.Message) ;}
		}

		protected void SetFields()
		{
			//set text fields to empty
			ServiceIdText.Text = string.Empty ;
			ServiceNameText.Text = string.Empty ;
			ServiceAbbreviationText.Text = string.Empty ;
			ServiceSubdivisionText.Text = string.Empty ;
			RecordIdLabel.Text = "New" ;

			//clear variables
			ViewState["serviceId"] = string.Empty ;
			ViewState["serviceVersion"] = string.Empty ;
		}

		private void EditButton_Click(object sender, System.EventArgs e)
		{
			//check that a Service was selected
			if (ServiceCodeList.SelectedIndex>0)
			{
				//get selected Service
				string srvid = ServiceCodeList.SelectedItem.Value.ToString() ;
				try
				{
					//create handle and save Id and version
					//ref. Vha.Vtk.Common.Service
					Vha.Vtk.Common.Service srvhdl = new Vha.Vtk.Common.Service(Convert.ToInt32(srvid), VtkUtility.GetAppCon()) ;
					ViewState["serviceId"] = srvhdl.ID.ToString() ;
					ViewState["serviceVersion"] = srvhdl.Version.ToString() ;

					//set text fields to values
					RecordIdLabel.Text = srvhdl.ID.ToString() ;
					ServiceIdText.Text = srvhdl.Code.ToString() ;
					ServiceNameText.Text = srvhdl.ServiceName.ToString() ;
					ServiceAbbreviationText.Text = srvhdl.Abbreviation.ToString() ;
					ServiceSubdivisionText.Text = srvhdl.Subdivision.ToString() ;
					//enable Save button
					PostButton.Enabled = true ;

					//place focus on ServiceNameText field
					//serviceBody.Attributes.Add("onLoad","document.serviceForm.ServiceNameText.focus()") ;

					srvhdl.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Service Record: " + err.Message) ;}
			}
			else
			{
				SetFields() ;
				VtkUtility.ErrMsgAdd(ErrorMessage, "You must select a Service Code to Edit") ;
			}
		}

		private void NewButton_Click(object sender, System.EventArgs e)
		{
			SetFields() ;
			ServiceCodeList.SelectedIndex = 0 ;
			PostButton.Enabled = true ;
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			//flag to check if version number has changed
			bool versionOk = true ;
			if (ServiceIdText.Text != string.Empty)
			{
				try
				{
					//check code, must be less than 800
					if (Convert.ToInt32(ServiceIdText.Text.Substring(0,3)) > 799)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Service Code must be less than 800") ;}
					else
					{
						//ref. Vha.Vtk.Common.Service
						Vha.Vtk.Common.Service srvhdl ;
						//check if edit existing record
						if (ViewState["serviceId"].ToString() != string.Empty)
						{
							string srvid = ViewState["serviceId"].ToString() ;
							//create handle and open current record
							srvhdl = new Vha.Vtk.Common.Service(Convert.ToInt32(srvid), VtkUtility.GetAppCon()) ;
							//check version
							if (ViewState["serviceVersion"].ToString() != srvhdl.Version.ToString())
							{
								VtkUtility.ErrMsgAdd(ErrorMessage, "Current Service record has changed while you were editing, Please press EXIT and start over. ") ;
								versionOk = false ;
							}
						}
							//new record
						else
						{
							//create handle and open new record
							srvhdl = Vha.Vtk.Common.Service.AddRecord(VtkUtility.GetAppCon()) ;
						}
						if (versionOk)
						{
							//save current fields
							srvhdl.Code = ServiceIdText.Text ;
							srvhdl.ServiceName = ServiceNameText.Text ;
							srvhdl.Abbreviation = ServiceAbbreviationText.Text ;
							srvhdl.Subdivision = ServiceSubdivisionText.Text ;
							srvhdl.Scope = "N" ;

							//save and close
							srvhdl.Save() ;
							srvhdl.Dispose() ;

							//update confirmation message
							ConfirmationMessage.Text = "Record Posted!" ;
							//update service list and reset fields
							GetServiceList() ;
							SetFields() ;
						}
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Service Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "You must enter a New Service Code") ;}
		}

		private void ServiceExitButton_Click(object sender, System.EventArgs e)
		{
			Response.Redirect("Index.aspx") ;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.EditButton.Click += new System.EventHandler(this.EditButton_Click);
			this.NewButton.Click += new System.EventHandler(this.NewButton_Click);
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
