using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Kernel.Common;
using Vha.Vss.Utility;

using VTK.Utility;
using System.Text;
using CrystalDecisions.Shared;
using CrystalDecisions.CrystalReports.Engine;

namespace VTK.National
{
	/// <summary>
	/// Summary description for ReportsRSOccHoursVHA37part2.
	/// </summary>
	public class ReportsRSOccHoursVHA37part2 : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.RadioButtonList MonthsRadioButton;
		protected System.Web.UI.WebControls.DropDownList FiscalYearList;
		protected System.Web.UI.WebControls.ListBox StationListBox;
		protected System.Web.UI.WebControls.RadioButtonList StationTypeRadioButton;
		protected System.Web.UI.WebControls.CustomValidator SortReportByValidator;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidatorSortByListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Regular Scheduled and Occasional Hours VHA37 Part 2"))
				{
					if (!Page.IsPostBack)
					{
						// set the default to All stations
						StationTypeRadioButton.SelectedIndex=3;
						// initialize all the controls on the page
						InitializePageControls();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializePageControls()
		{
			if (StationTypeRadioButton.SelectedItem.Value=="V")
			{
				StationListBox.Items.Clear();
				PopulateVISNList();
				StationListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a VISN.";
			}
			else if (StationTypeRadioButton.SelectedItem.Value=="S")
			{
				StationListBox.Items.Clear();
				PopulateStateList();
				StationListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a State.";
			}
			else if (StationTypeRadioButton.SelectedItem.Value=="A")
			{
				StationListBox.Items.Clear();
				StationListBox.Visible=false;
			}
			else  // default = Facility
			{
				StationListBox.Items.Clear();
				PopulateInstitutionList();
				StationListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a Facility.";
			}
			// populate fiscal year list
			PopulateFiscalYearList();
		}
		private void PopulateInstitutionList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList();
				ds.Tables["InstitutionList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable idt = ds.Tables["InstitutionList"] ;
				//define columns in list box
				StationListBox.DataTextField = "DisplayName" ;
				StationListBox.DataValueField = "ID" ;
				StationListBox.DataSource = idt ;
				StationListBox.DataBind() ;
				ds.Dispose() ;
				idt.Dispose() ;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}
		private void PopulateVISNList() 
		{
			try 
			{
				//get visn list
				DataSet vds = Vha.Vtk.Kernel.Data.SystemTables.AdministrativeUnit.GetQuickList() ;
				DataTable vdt = vds.Tables["AdministrativeUnitList"] ;
				//sort on unitnumber, which is the visn number
				vds.Tables["AdministrativeUnitList"].DefaultView.Sort = "UnitNumber ASC" ;
				//create a new column that will combine unitnumber and name
				vdt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
				//loop and build string for the new column, DisplayName
				foreach (DataRow dr in vdt.Rows)
				{
					string s = String.Copy("(" + dr["UnitNumber"] + ") " + dr["UnitName"].ToString()) ;
					dr["DisplayName"] = s ;
				}
				//add the first row, uses Rows.InsertAt(
				//DataRow vdr = vdt.NewRow() ;
				//vdr["DisplayName"] = " -Select VISN- " ;
				//vdr["ID"] = -1 ;
				//vdt.Rows.InsertAt(vdr, 0) ;
				//define columns in list box
				StationListBox.DataTextField = "DisplayName" ;
				StationListBox.DataValueField = "ID" ;
				StationListBox.DataSource = vdt ;
				StationListBox.DataBind() ;
				vds.Dispose() ;
				vdt.Dispose() ;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}
		private void PopulateStateList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList();
				StationListBox.DataSource=ds.Tables["StateList"].DefaultView;
				StationListBox.DataTextField="StateName";
				StationListBox.DataValueField="ID";
				StationListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}
		private void PopulateFiscalYearList() 
		{
			int currentFiscalYear=VtkUtility.GetCurrentFiscalYear();
			// start from 1990 to current
			for (int i=1990;i<=currentFiscalYear;i++)
			{
				FiscalYearList.Items.Add(new ListItem(i.ToString(),i.ToString()));
			}
			// set current fiscal year as default.  the last entry in the list is the current fiscal year
			// and is indexed as count-1 (since the item list starts at 0)
			FiscalYearList.SelectedIndex=FiscalYearList.Items.Count-1;
			// set the months as 12 for the year
			MonthsRadioButton.SelectedIndex=3;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.StationTypeRadioButton.SelectedIndexChanged += new System.EventHandler(this.StationTypeRadioButton_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void StationTypeRadioButton_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			InitializePageControls();
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();

				// report type (name of crystal report file)
				rp.ReportType=UIReportType.VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2;
				// report format
				rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
				// type of selection: 'F'acility, 'V'ISN, 'S'tate, 'A'll
				rp.AT_InputType=StationTypeRadioButton.SelectedItem.Value;
				// inputId based on type of selection (either facilityid, visnid, stateid)
				if (StationTypeRadioButton.SelectedItem.Value!="A")
				{
					rp.AT_InputId=Convert.ToInt32(StationListBox.SelectedItem.Value);
				}
				// fiscal year
				rp.AT_InputFiscalYear=Convert.ToInt32(FiscalYearList.SelectedItem.Value);
				// number of months
				rp.AT_InputMonths=Convert.ToInt32(MonthsRadioButton.SelectedItem.Value);

				// Put UIParams into Context
				Context.Items["ReportParams"]=rp;

				if (rp.ReportFormat==UIReportFormat.Web) 
				{
					Server.Transfer(RptUtility.GetNationalCrystalWebTransferString(rp.ReportType));
				} 
				else 
				{
					Server.Transfer("NationalCrystalExport.aspx");
				}
			}
		}
		// ==================================================================
		// verify and validate the input on the web form
		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			//
			// put code here to validate input on form
			if (StationTypeRadioButton.SelectedItem.Value=="F")
			{
				if (StationListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a Facility");
				}
			}
			else if (StationTypeRadioButton.SelectedItem.Value=="V")
			{
				if (StationListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a VISN");
				}
			}
			else if (StationTypeRadioButton.SelectedItem.Value=="S")
			{
				if (StationListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a State");
				}
			}
			else if (StationTypeRadioButton.SelectedItem.Value=="A")
			{
			}
			else
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select the stations for this report");
			}
			return printOKFlag;
		}
		// ==================================================================
		// initialize the report parameters (called from print click)
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public string AT_InputType;
			public int AT_InputId;
			public int AT_InputFiscalYear;
			public int AT_InputMonths;

			public UIReportParams() 
			{
				AT_InputType="";
				AT_InputId=0;
				AT_InputFiscalYear=1990;
				AT_InputMonths=3;
			}
			//
		}
		// ==================================================================
	}
}
