using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.National
{
	/// <summary>
	/// Summary description for ReportsVS01DataViewUI.
	/// </summary>
	public class ReportsVS01DataViewUI : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.RadioButtonList MonthsRadioButton;
		protected System.Web.UI.WebControls.DropDownList FiscalYearList;
		protected System.Web.UI.WebControls.Panel InputPanel;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.CheckBoxList ShowDataCheckBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("VS01 Data View"))
				{
					if (!Page.IsPostBack)
					{
						// populate fiscal year list
						PopulateFiscalYearList();
					}
                    //save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateFiscalYearList() 
		{
			int currentFiscalYear=VtkUtility.GetCurrentFiscalYear();
			// start from 1990 to current
			for (int i=1990;i<=currentFiscalYear;i++)
			{
				FiscalYearList.Items.Add(new ListItem(i.ToString(),i.ToString()));
			}
			// set current fiscal year as default.  the last entry in the list is the current fiscal year
			// and is indexed as count-1 (since the item list starts at 0)
			FiscalYearList.SelectedIndex=FiscalYearList.Items.Count-1;
			// set the months as 12 for the year
			MonthsRadioButton.SelectedIndex=3;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion


		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			string showlist = "";
			//visn detail
			showlist = showlist + "&visn=" + ShowDataCheckBox.Items[0].Selected.ToString();
			//station detail
			showlist = showlist + "&station=" + ShowDataCheckBox.Items[1].Selected.ToString();
			//count on rolls
			showlist = showlist + "&countrolls=" + ShowDataCheckBox.Items[2].Selected.ToString();
			//count on rolls logging hours
			showlist = showlist + "&loghours=" + ShowDataCheckBox.Items[3].Selected.ToString();
			//rs hours
			showlist = showlist + "&rshours=" + ShowDataCheckBox.Items[4].Selected.ToString();
			//occasional hours
			showlist = showlist + "&occhours=" + ShowDataCheckBox.Items[5].Selected.ToString();
			//adjusted hours
			showlist = showlist + "&adjhours=" + ShowDataCheckBox.Items[6].Selected.ToString();
			//total hours
			showlist = showlist + "&tothours=" + ShowDataCheckBox.Items[7].Selected.ToString();

			Response.Redirect("../National/ReportsVS01DataView.aspx?fiscalYear=" + FiscalYearList.SelectedItem.Value + "&months=" + MonthsRadioButton.SelectedItem.Value + showlist + "&StationId=" + VtkPageHeader1.DivSelectedId.ToString());
		}


		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public UIReportParams() 
			{
				// there are no params for a report
			}
		}
	}
}
