using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for Alphabetical.
	/// </summary>
	public class Alphabetical : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.RequiredFieldValidator DivisionListValidator;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		public Alphabetical()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Alphabetical Volunteers"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();
				// AT_InInstitutionList
				foreach (ListItem li in DivisionList.Items) 
				{
					if (li.Selected) 
					{
						//rp.AT_InInstitutionList.Add(li.Value,li.Text);
						rp.AT_InInstitutionList+=li.Value+"^";
					}
				}

				// report type
				rp.ReportType=UIReportType.VtkAlphaListOfRSVolunteers;

				// report format
				rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);

				// Put UIParams into Context
				Context.Items["ReportParams"]=rp;

				// transfer
				if (rp.ReportFormat==UIReportFormat.Web) 
				{
					Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
				} 
				else 
				{
					Server.Transfer("../RptCR/CrystalExport.aspx");
				}
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InInstitutionList;

			public UIReportParams() 
			{
				AT_InInstitutionList="";
			}
		}
		
		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			// validate they chose a division
			if (DivisionList.SelectedIndex<0) 
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a division");
			}
			return printOKFlag;
		}

		private void DivisionChange(object sender, System.EventArgs e)
		{

		}
	}
}
