using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for DailyVolunteerList.
	/// </summary>
	public class DailyVolunteerList : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.RangeValidator BeginDateRangeValidator;
		protected System.Web.UI.WebControls.RangeValidator EndDateRangeValidator;
		protected System.Web.UI.WebControls.TextBox txtDateBegin;
		protected System.Web.UI.WebControls.TextBox txtDateEnd;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Daily Volunteer List"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						//set the selected datetime to today
						txtDateBegin.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						txtDateEnd.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) 
				{
					rp.AT_InputInstIdList+=li.Value+"^";
				}
			}
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// date of report
			rp.AT_InputBeginDate=System.Convert.ToDateTime(txtDateBegin.Text);
			rp.AT_InputEndDate=System.Convert.ToDateTime(txtDateEnd.Text);

			// report type (name of crystal report file)
			// from radio button, either print the list or the form
			rp.ReportType=UIReportType.VtkSL_DailyVolunteerList;

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InputInstIdList;
			public DateTime AT_InputBeginDate;
			public DateTime AT_InputEndDate;

			public UIReportParams() 
			{
				AT_InputInstIdList="^";
				AT_InputBeginDate=DateTime.Today;
				AT_InputEndDate=DateTime.Today;
			}
		}
	}
}
