using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for DonationReceipt.
	/// </summary>
	public class DonationReceipt : System.Web.UI.Page
	{
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.TextBox txtDateTime;
		protected System.Web.UI.WebControls.RangeValidator BeginDateRangeValidator;
		protected System.Web.UI.WebControls.ListBox DonationList;
		protected System.Web.UI.WebControls.CustomValidator DonationListValidator;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.CustomValidator txtDateTimeValidator;
		protected System.Web.UI.WebControls.Label ErrorMessage;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Generate Receipt"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					txtDateTime.Attributes.Add("OnKeyDown", "return stopKeys()");
					DonationList.Attributes.Add("OnClick", "Set_NoBlank()");

					if (!Page.IsPostBack)
					{
						//set the selected datetime to today
						txtDateTime.Text=System.Convert.ToString(System.DateTime.Today.ToShortDateString());
						PopulateDonationList();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateDonationList() 
		{
			DonationList.Items.Clear();

			try 
			{
				string display;
				string indivName;

				//populate list of services
				DataSet ds = Vha.Vtk.Donations.Donation.GetQuickListBy_StationId_DonationDate(VtkPageHeader1.DivSelectedId, Convert.ToDateTime(txtDateTime.Text)); 
				DataTable dt = ds.Tables["GetQuickListBy_StationId_DonationDate"] ;

				if (dt.Rows.Count > 0)
				{
					//define columns in list box
					DonationList.DataTextField = "DisplayName" ;
					DonationList.DataValueField = "Id" ;
					//create a new column for display name
					dt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;

					//loop and build string for the new column, DisplayName
					foreach (DataRow dr in dt.Rows)
					{
						display = Convert.ToDateTime(dr["DonationDate"].ToString()).ToShortDateString() ;
						indivName = String.Copy(dr["LastName"] + ", " + dr["FirstName"]) ;
						//Donor Type: 1=Individual, 2=Ind&Org, 3=Ind&Affil, 4=Organization, 5=Affiliate
						switch (dr["DonorTypeFK"].ToString())
						{
							case "2":
								indivName = indivName + " Org: " + dr["OrganizationName"] + "(" + dr["OrganizationCode"] + ")" ;
								break ;
							case "3":
								indivName = indivName + " Affl: " + dr["DonorAffiliation"] ;
								break ;
							case "4":
								indivName = dr["OrganizationName"] + "(" + dr["OrganizationCode"] + ")" ;
								break ;
							case "5":
								indivName = dr["DonorAffiliation"].ToString() ;
								break ;
							default:
								break ;
						}
						display = display + " " + indivName + " " + dr["DonationType"] ;
						dr["DisplayName"] = display ;
					}

					//bind list box to DataTable and clean up
					DonationList.DataSource = dt;
					DonationList.DataBind() ;
				}
				
				ds.Dispose() ;
				dt.Dispose() ;
			}

			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Donation List: " + err.Message) ;}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.txtDateTime.TextChanged += new System.EventHandler(this.txtDateTime_TextChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
		
		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			rp.AT_InputId=Convert.ToInt32(DonationList.SelectedItem.Value);

			// report type
			rp.ReportType=UIReportType.VtkSL_DonationReceipt2815;

			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;


			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		private void txtDateTime_TextChanged(object sender, System.EventArgs e)
		{
			PopulateDonationList();
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public int AT_InputId;

			public UIReportParams() 
			{
				AT_InputId=0;
			}
		}
	}
}
