using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for OccHoursByDate.
	/// </summary>
	public class OccHoursByDate : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.DropDownList EndMonthYearList;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Occasional Hours By Date"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						// populate fiscal year list
						InitializeDates();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+2); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					// put a 0 in front of the month if it is month 1-9, you need this or the validator will fail
					string monthdisplay = month.ToString();
					if (month < 10) monthdisplay = "0" + monthdisplay;

					count = count + 1;
					if (new DateTime(year, month, 1) < System.DateTime.Today)
					{
						BegMonthYearList.Items.Add(monthdisplay + "/01/" + year.ToString());
						EndMonthYearList.Items.Add(monthdisplay + "/" + System.DateTime.DaysInMonth(year, month).ToString() + "/" + year.ToString());
					}
					// stop if greater than current month year
					else break;
				}
			}
			// set current month year as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			BegMonthYearList.SelectedIndex=BegMonthYearList.Items.Count-1;
			EndMonthYearList.SelectedIndex=EndMonthYearList.Items.Count-1;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) 
				{
					rp.AT_InputInstIdList+=li.Value+"^";
				}
			}

			// set up the begin and end month year for the report
			rp.AT_InputBeginDate=Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			rp.AT_InputEndDate=Convert.ToDateTime(EndMonthYearList.SelectedItem.Value);

			// report type
			rp.ReportType=UIReportType.VtkSL_OccHoursByDate;
			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InputInstIdList;
			public DateTime AT_InputBeginDate;
			public DateTime AT_InputEndDate;

			public UIReportParams() 
			{
				AT_InputInstIdList="";
				AT_InputBeginDate=DateTime.Today;
				AT_InputEndDate=DateTime.Today;
			}
		}
	}
}
