using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using Vha.Vtk;
using Vha.Vtk.TimeKeeping;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;
using CrystalDecisions.Shared;
using CrystalDecisions.CrystalReports.Engine;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for OccHoursByOrganization.
	/// </summary>

	public class OccHoursByOrganization : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.CompareValidator BeginEndDateValidator;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.DropDownList EndMonthYearList;
		protected System.Web.UI.WebControls.ListBox SelectedOrgListBox;
		protected System.Web.UI.WebControls.ListBox OrganizationListBox;
		protected System.Web.UI.WebControls.RequiredFieldValidator OrgListBoxValidator;
		const string emptySelectedListItemText = " - select organizations from list - ";
		const string emptySelectedListItemValue = "-1";
		const string emptyOrganizationListItemText = " - no organizations to select from - ";
		const string emptyOrganizationListItemValue = "-1";

		public OccHoursByOrganization()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Occasional Hours By Organization"))
				{
					Page.RegisterHiddenField("Action", String.Empty);
					OrganizationListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					SelectedOrgListBox.Attributes.Add("OnClick", "Set_NoBlank()");
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
						// populate fiscal year list
						InitializeDates();
						// remove all selected organizations and populate organization list
						RemoveAllOrgButton();
					}
					else
					{
						if(Request.Form["Action"] != String.Empty)
						{
							if(Request.Form["Action"] == "Add")
							{
								Page.Trace.Warn("Action", "Add");
								AddOrgButton();
							}
							else if (Request.Form["Action"] == "AddAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								AddAllOrgButton();
							}
							else if (Request.Form["Action"] == "RemoveAll")
							{
								Page.Trace.Warn("Action", "AddAll");
								RemoveAllOrgButton();
							}
							else //action = remove
							{
								Page.Trace.Warn("Action", "Remove");
								RemoveOrgButton();
							}
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+2); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					// put a 0 in front of the month if it is month 1-9, you need this or the validator will fail
					string monthdisplay = month.ToString();
					if (month < 10) monthdisplay = "0" + monthdisplay;

					count = count + 1;
					if (new DateTime(year, month, 1) < System.DateTime.Today)
					{
						BegMonthYearList.Items.Add(monthdisplay + "/01/" + year.ToString());
						EndMonthYearList.Items.Add(monthdisplay + "/" + System.DateTime.DaysInMonth(year, month).ToString() + "/" + year.ToString());
					}

					// stop if greater than current month year
					else break;
					//if (new DateTime(year, month, 1) > System.DateTime.Today)
					//{
					//	break;
					//}
				}
			}
			// set current month year as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			BegMonthYearList.SelectedIndex=BegMonthYearList.Items.Count-1;
			EndMonthYearList.SelectedIndex=EndMonthYearList.Items.Count-1;
		}


		private void PopulateOrganizationList() 
		{
			//TODO: filter by division. Just set up a loop and build the list into the 
			// same dataset, it should just add the new entries.  Not to sure that is the 
			// best method for performance though.
			//int division=0;
			try 
			{
				//DataSet ds = Vha.Vtk.TimeKeeping.OccasionalHours.GetQuickList(division, VtkUtility.GetAppCon());
				//DataSet ds = Vha.Vtk.Common.Organization.GetActiveQuickList();
				DataSet ds = Vha.Vtk.Common.Organization.GetSiteActiveQuickListByName(Convert.ToInt32(DivisionList.SelectedItem.Value));
				OrganizationListBox.DataSource=ds.Tables["OrganizationList"].DefaultView;
				OrganizationListBox.DataTextField="Name";
				OrganizationListBox.DataValueField="ID";
				OrganizationListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.OccHoursByOrganization");
			}
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.DivisionList.SelectedIndexChanged += new System.EventHandler(this.DivisionList_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void AddOrgButton()
		{
			//make sure item is selected
			if (OrganizationListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (OrganizationListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering orgs, remove it
					if (SelectedOrgListBox.Items[0].Value=="-1") 
					{
						SelectedOrgListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(OrganizationListBox, SelectedOrgListBox);
				}
			}
			//if the organization list box has no items, add the text for adding new ones
			if (OrganizationListBox.Items.Count==0) 
			{
				OrganizationListBox.Items.Add(new ListItem(emptyOrganizationListItemText,emptyOrganizationListItemValue.ToString()));
			}
		}

		private void AddAllOrgButton()
		{
			//remove all selected organizations first
			SelectedOrgListBox.Items.Clear();
			OrganizationListBox.Items.Clear();
			// re-populate organization list
			PopulateOrganizationList();
			//add all organizations
			for (int i=0;i<OrganizationListBox.Items.Count;i++)
			{
				OrganizationListBox.SelectedIndex=i;
				SelectedOrgListBox.Items.Add(new ListItem(OrganizationListBox.SelectedItem.Text, OrganizationListBox.SelectedItem.Value));
			}
			OrganizationListBox.Items.Clear();
			OrganizationListBox.Items.Add(new ListItem(emptyOrganizationListItemText,emptyOrganizationListItemValue.ToString()));
			//set the focus on the first item in selected list (to keep the validator from firing)
			SelectedOrgListBox.SelectedIndex=0;
		}

		private void RemoveOrgButton()
		{
			//make sure item is selected
			if (SelectedOrgListBox.SelectedIndex>-1)
			{
				//make sure text is not selected
				if (SelectedOrgListBox.Items[0].Value!="-1") 
				{
					//if the first entry is the text for entering orgs, remove it
					if (OrganizationListBox.Items[0].Value=="-1") 
					{
						OrganizationListBox.Items.RemoveAt(0);
					}
					//move the selected item from one list to the other
					MoveSelectedItem(SelectedOrgListBox, OrganizationListBox);
				}
				//if the selected list box has no items, add the text for adding new ones
				if (SelectedOrgListBox.Items.Count==0) 
				{
					SelectedOrgListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
				}
				else
				{
					//set the focus on the first item in selected list (to keep the validator from firing)
					SelectedOrgListBox.SelectedIndex=0;
				}
			}
		}

		private void RemoveAllOrgButton()
		{
			// populate organization list
			PopulateOrganizationList();
			//remove all selected organizations
			SelectedOrgListBox.Items.Clear();
			//add the selection text
			SelectedOrgListBox.Items.Add(new ListItem(emptySelectedListItemText,emptySelectedListItemValue.ToString()));
		}

		//move selected item from one list to the other
		private void MoveSelectedItem(ListBox FromList, ListBox ToList) 
		{
			// if item selected, remove it from Org list and add it to selected list
			while (FromList.SelectedIndex>-1) 
			{
				ListItem li = new ListItem(FromList.SelectedItem.Text,
					FromList.SelectedItem.Value);
				FromList.Items.RemoveAt(FromList.SelectedIndex);
				int pos=-1;
				for (int i=0;i<ToList.Items.Count;i++) 
				{
					if (String.Compare(ToList.Items[i].Text, li.Text,
						true, System.Globalization.CultureInfo.CurrentUICulture)>=0) 
					{
						pos=i;
						break;
					}
				}
				if (pos>-1) 
				{
					ToList.Items.Insert(pos,li);
				} 
				else 
				{
					ToList.Items.Add(li);
				}
			}
			if(ToList.Items.Count > 0)
			{
				ToList.SelectedIndex = 0;
			}
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			UIReportParams rp = new UIReportParams();

			// Build input institution list
			foreach (ListItem li in DivisionList.Items) 
			{
				if (li.Selected) 
				{
					rp.AT_InputInstIdList+=li.Value+"^";
				}
			}

			// Build input organization list
			foreach (ListItem li in SelectedOrgListBox.Items) 
			{
				rp.AT_InputOrganizationIdList+=li.Value+"^";
			}
			// if all selected, set to ^
			if (OrganizationListBox.Items[0].Value=="-1")
			{
				rp.AT_InputOrganizationIdList="^";
			}

			// set up the begin and end month year for the report
			rp.AT_InputBeginDate=Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);
			rp.AT_InputEndDate=Convert.ToDateTime(EndMonthYearList.SelectedItem.Value);

			// report type
			//rp.ReportType=UIReportType.OccasionalSelectedOrganizationPrint;
			rp.ReportType=UIReportType.VtkSL_OccHoursByOrganization;

			// report format
			rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);

			// Put UIParams into Context
			Context.Items["ReportParams"]=rp;

			// transfer
			if (rp.ReportFormat==UIReportFormat.Web) 
			{
				Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
			} 
			else 
			{
				Server.Transfer("../RptCR/CrystalExport.aspx");
			}
		}

		private void DivisionList_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			// remove all selected organizations and populate organization list
			RemoveAllOrgButton();
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InputInstIdList;
			public string AT_InputOrganizationIdList;
			public DateTime AT_InputBeginDate;
			public DateTime AT_InputEndDate;

			public UIReportParams() 
			{
				AT_InputInstIdList="";
				AT_InputOrganizationIdList="";
				AT_InputBeginDate=DateTime.Today;
				AT_InputEndDate=DateTime.Today;
			}
		}
	}
}
