using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for PotentialAward.
	/// </summary>
	public class PotentialAwards : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.RadioButtonList AdultYouthList;
		protected System.Web.UI.WebControls.ListBox DivisionList;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidator1;
		protected System.Web.UI.WebControls.DropDownList BegMonthYearList;
		protected System.Web.UI.WebControls.RadioButtonList ShowTerminatedRadioButtonList1;
		protected System.Web.UI.WebControls.RadioButtonList PrintLabelsRadioButtonList1;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		public PotentialAwards()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Potential Awards Report"))
				{
					if (!Page.IsPostBack)
					{
						// populate Division List
						VtkUtility.PopulateDivisionList(Page, DivisionList.Items, ErrorMessage, VtkPageHeader1.DivSelectedId);
					    // initialize dates
					    InitializeDates();
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void InitializeDates() 
		{
			// populate begin and end list month year
			int count=0;
			for (int year = 1990; year < (System.DateTime.Today.Year+1); year++)
			{
				for (int month = 1; month < 13; month++)
				{
					// put a 0 in front of the month if it is month 1-9, you need this or the validator will fail
					string monthdisplay = month.ToString();
					if (month < 10) monthdisplay = "0" + monthdisplay;

					// get number of days in the month
					int daysInMonth = System.DateTime.DaysInMonth(year, month);

					count = count + 1;
					BegMonthYearList.Items.Add(monthdisplay + "/" + daysInMonth.ToString() + "/" + year.ToString());

					// stop if current month year
					if ((month.ToString() + "/" + year.ToString()) == 
						(System.Convert.ToString(System.DateTime.Today.ToString("M/yyyy"))))
					{
						break;
					}
				}
			}
			// set 12 months from today as default.  the last entry in the list is the current month year
			// and is indexed as count-1 (since the item list starts at 0)
			int begmonthcounter=BegMonthYearList.Items.Count-12;
			if (begmonthcounter<0) begmonthcounter=0;
			BegMonthYearList.SelectedIndex=begmonthcounter;
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();
				// AT_InInstitutionList
				foreach (ListItem li in DivisionList.Items) 
				{
					if (li.Selected) 
					{
						rp.AT_InInstitutionList+=li.Value+"^";
					}
				}
				// date input
				rp.AT_InputEndDate=Convert.ToDateTime(BegMonthYearList.SelectedItem.Value);

				// Adult/Youth/Both
				rp.AT_YouthAdultBoth=AdultYouthList.SelectedItem.Value;

				// included terminated volunteers on the report
				rp.AT_InputIncludeTerminated=0;
				if (ShowTerminatedRadioButtonList1.SelectedIndex == 1) rp.AT_InputIncludeTerminated=1;

				// report format
				rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);

				// reportType
				rp.ReportType=UIReportType.VtkPotentialAwardsListing;
				// if labels checked, print label report
				if (PrintLabelsRadioButtonList1.SelectedIndex == 1) rp.ReportType=UIReportType.VtkPotentialAwardsLabels;

				// Put UIParams into Context
				Context.Items["ReportParams"]=rp;

				// transfer
				if (rp.ReportFormat==UIReportFormat.Web) 
				{
					Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
				} 
				else 
				{
					Server.Transfer("../RptCR/CrystalExport.aspx");
				}
			}
		}

		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			public string AT_InInstitutionList;
			public string AT_YouthAdultBoth;
			public DateTime AT_InputEndDate;
			public int AT_InputIncludeTerminated;

			public UIReportParams() 
			{
				AT_InInstitutionList="";
				AT_YouthAdultBoth="";
				AT_InputEndDate=DateTime.Today;
				AT_InputIncludeTerminated=1;
			}
		}

		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			// validate they chose a division
			if (DivisionList.SelectedIndex<0) 
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a division");
			}
			// Adult/Youth/Both
			if (AdultYouthList.SelectedIndex<0) 
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please choose whether to print for Adults, Youths, or Both");
			}

			return printOKFlag;
		}

		private void DivisionChange(object sender, System.EventArgs e)
		{

		}

	}
}
