using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

// add these classes to each report user interface
// ==========================================================================
using Vha.Vtk.Kernel.Common;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Text;
// ==========================================================================

namespace VTK.Reports
{
	/// <summary>
	/// Summary description for VSDServiceDirectory.
	/// </summary>
	public class VSDServiceDirectory : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Button PrintButton;
		protected System.Web.UI.WebControls.RadioButtonList PrintFormatList;
		protected System.Web.UI.WebControls.ListBox SortByListBox;
		protected System.Web.UI.WebControls.RadioButtonList SortByRadioButton;
		protected System.Web.UI.WebControls.CustomValidator SortReportByValidator;
		protected System.Web.UI.WebControls.RequiredFieldValidator RequiredFieldValidatorSortByListBox;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Service Directory"))
				{
					if (!Page.IsPostBack)
					{
						PopulateInstitutionList();
						// set the default institution to the one the user entered on
						VtkUtility.SetSelectedSingle(SortByListBox.Items, VtkPageHeader1.DivSelectedId.ToString());
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{ Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Programs List: " + err.Message) ;}
		}

		private void PopulateInstitutionList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.Institution.GetQuickList();
				ds.Tables["InstitutionList"].DefaultView.Sort = "DisplayName ASC" ;
				DataTable idt = ds.Tables["InstitutionList"] ;
				//define columns in list box
				SortByListBox.DataTextField = "DisplayName" ;
				SortByListBox.DataValueField = "ID" ;
				SortByListBox.DataSource = idt ;
				SortByListBox.DataBind() ;
				ds.Dispose() ;
				idt.Dispose() ;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}
		private void PopulateVISNList() 
		{
			try 
			{
				//get visn list
				DataSet vds = Vha.Vtk.Kernel.Data.SystemTables.AdministrativeUnit.GetQuickList() ;
				DataTable vdt = vds.Tables["AdministrativeUnitList"] ;
				//sort on unitnumber, which is the visn number
				vds.Tables["AdministrativeUnitList"].DefaultView.Sort = "UnitNumber ASC" ;
				//create a new column that will combine unitnumber and name
				vdt.Columns.Add("DisplayName", System.Type.GetType("System.String")) ;
				//loop and build string for the new column, DisplayName
				foreach (DataRow dr in vdt.Rows)
				{
					string s = String.Copy("(" + dr["UnitNumber"] + ") " + dr["UnitName"].ToString()) ;
					dr["DisplayName"] = s ;
				}
				//add the first row, uses Rows.InsertAt(
				//DataRow vdr = vdt.NewRow() ;
				//vdr["DisplayName"] = " -Select VISN- " ;
				//vdr["ID"] = -1 ;
				//vdt.Rows.InsertAt(vdr, 0) ;
				//define columns in list box
				SortByListBox.DataTextField = "DisplayName" ;
				SortByListBox.DataValueField = "ID" ;
				SortByListBox.DataSource = vdt ;
				SortByListBox.DataBind() ;
				vds.Dispose() ;
				vdt.Dispose() ;
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}
		private void PopulateStateList() 
		{
			try 
			{
				DataSet ds = Vha.Vtk.Kernel.Data.SystemTables.State.GetQuickList();
				SortByListBox.DataSource=ds.Tables["StateList"].DefaultView;
				SortByListBox.DataTextField="StateName";
				SortByListBox.DataValueField="ID";
				SortByListBox.DataBind();
				ds.Dispose();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message, "VTK.DailyTimeKeeping.RptSummarySheet");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.SortByRadioButton.SelectedIndexChanged += new System.EventHandler(this.SortByRadioButton_SelectedIndexChanged);
			this.PrintButton.Click += new System.EventHandler(this.PrintButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void SortByRadioButton_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (SortByRadioButton.SelectedItem.Value=="V")
			{
				SortByListBox.Items.Clear();
				PopulateVISNList();
				SortByListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a VISN.";
			}
			else if (SortByRadioButton.SelectedItem.Value=="S")
			{
				SortByListBox.Items.Clear();
				PopulateStateList();
				SortByListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a State.";
			}
			else if (SortByRadioButton.SelectedItem.Value=="A")
			{
				SortByListBox.Items.Clear();
				SortByListBox.Visible=false;
			}
			else  // default = Facility
			{
				SortByListBox.Items.Clear();
				PopulateInstitutionList();
				SortByListBox.Visible=true;
				RequiredFieldValidatorSortByListBox.ErrorMessage="Please select a Facility.";
			}
		
		}

		private void PrintButton_Click(object sender, System.EventArgs e)
		{
			if (ValidateForm()) 
			{
				UIReportParams rp = new UIReportParams();

				// report type (name of crystal report file)
				rp.ReportType=UIReportType.VtkS_VoluntaryPrintDirectory;
				// report format
				rp.ReportFormat=RptUtility.GetUIReportFormat(PrintFormatList.SelectedItem.Value);
				// type of selection: 'F'acility, 'V'ISN, 'S'tate, 'A'll
				rp.AT_InputType=SortByRadioButton.SelectedItem.Value;
				// inputId based on type of selection (either facilityid, visnid, stateid)
				if (SortByRadioButton.SelectedItem.Value!="A")
				{
					rp.AT_InputId=Convert.ToInt32(SortByListBox.SelectedItem.Value);
				}

				// Put UIParams into Context
				Context.Items["ReportParams"]=rp;

				// transfer
				if (rp.ReportFormat==UIReportFormat.Web) 
				{
					Server.Transfer(RptUtility.GetCrystalWebTransferString(rp.ReportType, VtkPageHeader1, Request.ApplicationPath));
				} 
				else 
				{
					Server.Transfer("../RptCR/CrystalExport.aspx");
				}
			}
		}

		// ==================================================================
		// verify and validate the input on the web form
		private bool ValidateForm() 
		{
			bool printOKFlag=true;
			//
			// put code here to validate input on form
			if (SortByRadioButton.SelectedItem.Value=="F")
			{
				if (SortByListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a Facility");
				}
			}
			else if (SortByRadioButton.SelectedItem.Value=="V")
			{
				if (SortByListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a VISN");
				}
			}
			else if (SortByRadioButton.SelectedItem.Value=="S")
			{
				if (SortByListBox.SelectedIndex<0)
				{
					printOKFlag=false;
					VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a State");
				}
			}
			else if (SortByRadioButton.SelectedItem.Value=="A")
			{
			}
			else
			{
				printOKFlag=false;
				VtkUtility.ErrMsgAdd(ErrorMessage, "Please select how the labels should be sorted");
			}
			return printOKFlag;
		}

		// ==================================================================
		// initialize the report parameters (called from print click)
		public class UIReportParams : VTK.Utility.UIReportParams 
		{
			//
			// put code here to set the parameters (name must be the same as
			// in crystal reports (@InputInstId = AT_InputInstId)
			public string AT_InputType;
			public int AT_InputId;

			public UIReportParams() 
			{
				AT_InputType="";
				AT_InputId=0;
			}
			//
		}
		// ==================================================================

	}
}
