namespace VTK.RptCR
{
  using System;
  using System.Collections;
  using System.Collections.Specialized;
  using System.ComponentModel;
  using System.Data;
  using System.Drawing;
  using System.Web;
  using System.Web.SessionState;
  using System.Web.UI;
  using System.Web.UI.WebControls;
  using System.Web.UI.HtmlControls;
  using System.Diagnostics;

	using CREngine = CrystalDecisions.CrystalReports.Engine;
	using CrystalDecisions.Shared;
	using Vha.Vtk;
	using VTK.Utility;
	using VTK.RptCR;
	using VTK.Reports;
  using System.Configuration;
  using Vha.Vss.Utility;
  
	using System.IO;
	using System.Text;

  /// <summary>
  ///    Summary description for CrystalExport.
  /// </summary>
  public class CrystalExport : Page
  {
    //protected override String GetApplicationName() { return "VTK"; }
    //protected override String GetLogSource() { return "VTK"; }
    private IDictionary config;
    internal UIReportParams par = null;
    internal CREngine.ReportDocument rpt = null;
    private CREngine.Database crDatabase;
    private CREngine.Tables crTables;
    private TableLogOnInfo crTableLogOnInfo;
    private ConnectionInfo crConnectionInfo;

    private CREngine.Sections crSections;
    private CREngine.ReportObjects crReportObjects;
    private CREngine.SubreportObject crSubReportObject;


	  public CrystalExport()
    {
      try
      {
        config = (IDictionary)ConfigurationSettings.GetConfig("VssConfiguration/DSN");
      }
      catch{}
	    Page.Init += new System.EventHandler(Page_Init);
    }

    private void Page_Load(object sender, EventArgs e)
    {
			ExportReport();
		}

		protected void ExportReport() 
		{
			par = RptUtility.GetParams(Context);

			rpt = new CREngine.ReportDocument();

			// set up filenames 
			StringBuilder sb = new StringBuilder(RptUtility.UniqueReportName(Page.User.Identity.Name));
			sb.Append(par.ReportType.ToString());
			sb.Append(RptUtility.ExportExtension(par.ReportFormat));
			string reportName = sb.ToString();
			string writeFileName=Request.ApplicationPath+"/temp/"+reportName;
			string deleteFileName=Request.PhysicalApplicationPath+"temp\\"+reportName;

			// load the report
			RptUtility.LoadReport(par.ReportType.ToString(), out rpt);
		
			//Creating connection to database from ODBC 
			
			DataEncoder dataDecoder = new DataEncoder("VhaVss");

			crConnectionInfo = new ConnectionInfo();
			crConnectionInfo.ServerName = (string)config["Name"];
			crConnectionInfo.UserID = (string)config["UserId"];
			crConnectionInfo.Password = dataDecoder.DecodeString(((string)config["Password"]).Substring(1, ((string)config["Password"]).Length - 2));
			crConnectionInfo.DatabaseName = (string)config["DBName"];
  

      //Looping thru each Table on the report to add the connection
      crDatabase = rpt.Database;
      crTables = crDatabase.Tables;

      foreach (CREngine.Table crTable in crTables)
      {
        crTableLogOnInfo = crTable.LogOnInfo;
        crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
        crTable.ApplyLogOnInfo(crTableLogOnInfo);
      }
      
      //Looping Through each of the sections, Reports in those sections, 
      //and SubReports in those Reports.
      crSections = rpt.ReportDefinition.Sections;
      foreach (CREngine.Section crSection in crSections)
      {
        crReportObjects = crSection.ReportObjects;
        foreach(CREngine.ReportObject crReportObject in crReportObjects)
        {
          if(crReportObject.Kind == ReportObjectKind.SubreportObject)
          {
            crSubReportObject = (CREngine.SubreportObject)crReportObject;
            crDatabase = crSubReportObject.OpenSubreport(crSubReportObject.SubreportName).Database;
            crTables = crDatabase.Tables;

            foreach(CREngine.Table crTable in crTables)
            {
              crTableLogOnInfo = crTable.LogOnInfo;
              crTableLogOnInfo.ConnectionInfo = crConnectionInfo;
              crTable.ApplyLogOnInfo(crTableLogOnInfo);              
            }
          }
        }
      }

			// load the parameters
			RptUtility.LoadReportParamsExport(par, rpt);
			// set the export options
			ExportOptions opts = rpt.ExportOptions;
			RptUtility.SetExportOptions(opts,par.ReportFormat,reportName,Request.PhysicalApplicationPath);
  
			try 
			{
				//export the report to appdirectory\temp
				rpt.Export();
				rpt.Dispose(); 
				// Clear anything already in the response buffer
				Response.Clear();
				// set up mime type stuff
				switch (par.ReportFormat) 
				{
					case UIReportFormat.Acrobat:
						Response.ContentType="application/pdf";
						break;
					case UIReportFormat.Excel:
						Response.ContentType="application/vnd.ms-excel";
						break;
					case UIReportFormat.Word:
						Response.ContentType="application/msword";
						break;
					default:
						break;
				} 
				// set up a FileInfo object to delete the file
				FileInfo fileInfo=new FileInfo(deleteFileName);
				// add other http stuff
				Response.AppendHeader("content-disposition", " INLINE");
				Response.AppendHeader("content-length", fileInfo.Length.ToString());
				// write the file to the browser
				Response.WriteFile(writeFileName); 
				// flush so that the file pointer will be closed before calling delete()
				Response.Flush();
				// delete the file
				fileInfo.Delete();
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(err.Message,"CrystalExport: "+par.ReportType.ToString());
			} 
			finally 
			{
				// Return everything to the user and close the request
				Response.End();
			}
		}

		private void Page_Init(object sender, EventArgs e)
    {
        //
        // CODEGEN: This call is required by the ASP+ Windows Form Designer.
        //
        InitializeComponent();
    }

    /// <summary>
    ///    Required method for Designer support - do not modify
    ///    the contents of this method with the code editor.
    /// </summary>
    private void InitializeComponent()
    {
      this.Load += new System.EventHandler(this.Page_Load);
    }
	}
}
