using System;

using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.ReportSource;
using CrystalDecisions.Shared;
using CrystalDecisions.Web;
using System.Web.UI.WebControls;
using System.Collections;
using System.Web;
using System.Web.UI;
using System.Text;
using Vha.Vtk.WebControlLibrary;
using VTK.Utility;
using System.Reflection;
using VTK.RptCR;

namespace VTK.Utility
{
	/// <summary>
	/// Summary description for RptUtility.
	/// </summary>
	public class RptUtility
	{
		/// <summary>
		/// Called by CrystalWeb, CrystalExport, NationalCrystalWeb and NationalCrystalExport to 
		/// load any report. When adding a report to VTK, add a case in the switch statement in this
		/// function so that the new report can be loaded.
		/// </summary>
		/// <param name="reportName">Name of the report (same as the UIReportType, classname and filename of
		/// the report)</param>
		/// <param name="rpt">Report Document in which to load the report.</param>
		public static void LoadReport(string reportName,
			out CrystalDecisions.CrystalReports.Engine.ReportDocument rpt)
		{
			rpt=null;
			switch (reportName) 
			{
			// add additional cases for each report type
				case "MasterRecordDisplayPrint":
					rpt = new MasterRecordDisplayPrint();
					rpt.Load("MasterRecordDisplayPrint");
					break;
				case "VtkAlphaListOfRSVolunteers":
					rpt = new VtkAlphaListOfRSVolunteers();
					rpt.Load("VtkAlphaListOfRSVolunteers");
					break;
				case "VtkSL_AnnualVolunteersVS30":
					rpt = new VtkSL_AnnualVolunteersVS30();
					rpt.Load("VtkSL_AnnualVolunteersVS30");
					break;
				case "VtkPotentialAwardsListing":
					rpt = new VtkPotentialAwardsListing();
					rpt.Load("VtkPotentialAwardsListing");
					break;
				case "VtkPotentialAwardsLabels":
					rpt = new VtkPotentialAwardsLabels();
					rpt.Load("VtkPotentialAwardsLabels");
					break;
				case "VtkSL_AwardsProcessedReport":
					rpt = new VtkSL_AwardsProcessedReport();
					rpt.Load("VtkSL_AwardsProcessedReport");
					break;
				case "VtkSL_AwardsProcessedLabels":
					rpt = new VtkSL_AwardsProcessedLabels();
					rpt.Load("VtkSL_AwardsProcessedLabels");
					break;
				case "VtkSignInCodeList":
					rpt = new VtkSignInCodeList();
					rpt.Load("VtkSignInCodeList");
					break;
				case "VtkUserRoleByRole":
					rpt = new VtkUserRoleByRole();
					rpt.Load("VtkUserRoleByRole");
					break;
				case "VtkUserRoleByUser":
					rpt = new VtkUserRoleByUser();
					rpt.Load("VtkUserRoleByUser");
					break; 
				case "VtkUtilizingServicesSubdivisionsI":
					rpt = new VtkUtilizingServicesSubdivisionsI();
					rpt.Load("VtkUtilizingServicesSubdivisionsI");
					break;
				case "VtkUtilizingServicesSubdivisionsII":
					rpt = new VtkUtilizingServicesSubdivisionsII();
					rpt.Load("VtkUtilizingServicesSubdivisionsII");
					break;
				case "VtkVolunteerAddressLabels":
					rpt = new VtkVolunteerAddressLabels();
					rpt.Load("VtkVolunteerAddressLabels");
					break;
				case "VtkVolunteerTelephoneList":
					rpt = new VtkVolunteerTelephoneList();
					rpt.Load("VtkVolunteerTelephoneList");
					break;
				// occasional hours by date
				case "VtkSL_OccHoursByDate":
					rpt = new VtkSL_OccHoursByDate();
					rpt.Load("VtkSL_OccHoursByDate");
					break;
				// occasional hours by organization
				case "VtkSL_OccHoursByOrganization":
					rpt = new VtkSL_OccHoursByOrganization();
					rpt.Load("VtkSL_OccHoursByOrganization");
					break;
				// occasional hours by service
				case "VtkSL_OccHoursByService":
					rpt = new VtkSL_OccHoursByService();
					rpt.Load("VtkSL_OccHoursByService");
					break;
				// regular scheduled hours by organization by day
				case "VtkSL_HoursByOrganization_Day":
					rpt = new VtkSL_HoursByOrganization_Day();
					rpt.Load("VtkSL_HoursByOrganization_Day");
					break;
				// regular scheduled hours by service by day
				case "VtkSL_HoursByService_Day":
					rpt = new VtkSL_HoursByService_Day();
					rpt.Load("VtkSL_HoursByService_Day");
					break;
				// meal ticket list and form
				case "VtkSL_VtkMealTicketForm":
					rpt = new VtkSL_VtkMealTicketForm();
					rpt.Load("VtkSL_VtkMealTicketForm");
					break; 
				case "VtkSL_VtkMealTicketList":
					rpt = new VtkSL_VtkMealTicketList();
					rpt.Load("VtkSL_VtkMealTicketList");
					break;
				// potential termination list vs07
				case "VtkSL_TerminationList_VS07":
					rpt = new VtkSL_TerminationList_VS07();
					rpt.Load("VtkSL_TerminationList_VS07");
					break; 
				// terminated volunteers
				case "VtkSL_TerminatedVolunteers":
					rpt = new VtkSL_TerminatedVolunteers();
					rpt.Load("VtkSL_TerminatedVolunteers");
					break; 
				// new volunteers
				case "VtkSL_NewVolunteers":
					rpt = new VtkSL_NewVolunteers();
					rpt.Load("VtkSL_NewVolunteers");
					break; 
				// volunteers by using organization VS26 and service VS28
				case "VtkSL_OrganizationsRSOccHours_VS26":
					rpt = new VtkSL_OrganizationsRSOccHours_VS26();
					rpt.Load("VtkSL_OrganizationsRSOccHours_VS26");
					break; 
				case "VtkSL_ServicesRSOccHours_VS28":
					rpt = new VtkSL_ServicesRSOccHours_VS28();
					rpt.Load("VtkSL_ServicesRSOccHours_VS28");
					break;
				// volunteers by using organization summary VS27 and service VS29
				case "VtkSL_OrganizationsRSOccHoursSummary_VS27":
					rpt = new VtkSL_OrganizationsRSOccHoursSummary_VS27();
					rpt.Load("VtkSL_OrganizationsRSOccHoursSummary_VS27");
					break; 
				case "VtkSL_ServicesRSOccHoursSummary_VS29":
					rpt = new VtkSL_ServicesRSOccHoursSummary_VS29();
					rpt.Load("VtkSL_ServicesRSOccHoursSummary_VS29");
					break;
					// view daily entries
				case "VtkSL_VolunteerDailyReview":
					rpt = new VtkSL_VolunteerDailyReview();
					rpt.Load("VtkSL_VolunteerDailyReview");
					break; 
				// voluntary service directory reports
				case "VtkS_VoluntaryStationInformation":
					rpt = new VtkS_VoluntaryStationInformation();
					rpt.Load("VtkS_VoluntaryStationInformation");
					break; 
				case "VtkS_VoluntaryServiceChiefs":
					rpt = new VtkS_VoluntaryServiceChiefs();
					rpt.Load("VtkS_VoluntaryServiceChiefs");
					break; 
				case "VtkS_VoluntaryProgramsSupervised":
					rpt = new VtkS_VoluntaryProgramsSupervised();
					rpt.Load("VtkS_VoluntaryProgramsSupervised");
					break; 
				case "VtkS_VoluntaryPrintDirectory":
					rpt = new VtkS_VoluntaryPrintDirectory();
					rpt.Load("VtkS_VoluntaryPrintDirectory");
					break; 
				case "VtkS_VoluntarySingleStationInformation":
					rpt = new VtkS_VoluntarySingleStationInformation();
					rpt.Load("VtkS_VoluntarySingleStationInformation");
					break; 
				case "VtkS_VoluntaryDirectoryLabels":
					rpt = new VtkS_VoluntaryDirectoryLabels();
					rpt.Load("VtkS_VoluntaryDirectoryLabels");
					break;
				// voluntary national officials reports
				case "VtkSNO_VoluntaryAllNatRepsLabels":
					rpt = new VtkSNO_VoluntaryAllNatRepsLabels();
					rpt.Load("VtkSNO_VoluntaryAllNatRepsLabels");
					break;
				case "VtkSNO_VoluntaryAnnualJointReview":
					rpt = new VtkSNO_VoluntaryAnnualJointReview();
					rpt.Load("VtkSNO_VoluntaryAnnualJointReview");
					break;
				case "VtkSNO_VoluntaryNationalOrganizations":
					rpt = new VtkSNO_VoluntaryNationalOrganizations();
					rpt.Load("VtkSNO_VoluntaryNationalOrganizations");
					break;
				// national reports
				case "VtkSN_VoluntaryCommitteeAttendanceListing":
					rpt = new VtkSN_VoluntaryCommitteeAttendanceListing();
					rpt.Load("VtkSN_VoluntaryCommitteeAttendanceListing");
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01":
					rpt = new VtkSN_VoluntaryServicesRSOccHours_VS01();
					rpt.Load("VtkSN_VoluntaryServicesRSOccHours_VS01");
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01_part2":
					rpt = new VtkSN_VoluntaryServicesRSOccHours_VS01_part2();
					rpt.Load("VtkSN_VoluntaryServicesRSOccHours_VS01_part2");
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01_part2_summary":
					rpt = new VtkSN_VoluntaryServicesRSOccHours_VS01_part2_summary();
					rpt.Load("VtkSN_VoluntaryServicesRSOccHours_VS01_part2_summary");
					break;
				case "VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part1":
					rpt = new VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part1();
					rpt.Load("VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part1");
					break;
				case "VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2":
					rpt = new VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2();
					rpt.Load("VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2");
					break;
				case "VtkSN_NACOrganizationsYearlyComparison":
					rpt = new VtkSN_NACOrganizationsYearlyComparison();
					rpt.Load("VtkSN_NACOrganizationsYearlyComparison");
					break;
				case "VtkSN_VoluntaryDonationsByVISN":
					rpt = new VtkSN_VoluntaryDonationsByVISN();
					rpt.Load("VtkSN_VoluntaryDonationsByVSIN");
					break;
				case "VtkSL_DonationReceipt":
					rpt = new VtkSL_DonationReceipt();
					rpt.Load("VtkSL_DonationReceipt");
					break;
				case "VtkSL_DonationReceipt2815":
					rpt = new VtkSL_DonationReceipt2815();
					rpt.Load("VtkSL_DonationReceipt2815");
					break;
				case "VtkSL_DonationReceipt2815FromEdit":
					rpt = new VtkSL_DonationReceipt2815();
					rpt.Load("VtkSL_DonationReceipt2815");
					break;
				case "VtkSL_DonationGrandTotalDetail":
					rpt = new VtkSL_DonationGrandTotalDetail();
					rpt.Load("VtkSL_DonationGrandTotalDetail");
					break;
				case "VtkSL_DonationReceiptFromEdit":
					rpt = new VtkSL_DonationReceipt();
					rpt.Load("VtkSL_DonationReceipt");
					break;
				case "VtkSL_DailyVolunteerList":
					rpt = new VtkSL_DailyVolunteerList();
					rpt.Load("VtkSL_DailyVolunteerList");
					break;
				// games reports
				case "VtkSG_DailyWorkSchedule":
					rpt = new VtkSG_DailyWorkSchedule();
					rpt.Load("VtkSG_DailyWorkSchedule");
					break;
				case "VtkSG_SignInRosterByName":
					rpt = new VtkSG_SignInRosterByName();
					rpt.Load("VtkSG_SignInRosterByName");
					break;
				case "VtkSG_SignInRosterBySvc":
					rpt = new VtkSG_SignInRosterBySvc();
					rpt.Load("VtkSG_SignInRosterBySvc");
					break;
				case "VtkSG_MasterRegistrationList":
					rpt = new VtkSG_MasterRegistrationList();
					rpt.Load("VtkSG_MasterRegistrationList");
					break;
				case "VtkSG_ShirtIssueList":
					rpt = new VtkSG_ShirtIssueList();
					rpt.Load("VtkSG_ShirtIssueList");
					break;
				case "VtkSG_ServiceAssignmentSchedule":
					rpt = new VtkSG_ServiceAssignmentSchedule();
					rpt.Load("VtkSG_ServiceAssignmentSchedule");
					break;
				case "VtkSG_GamesTelephoneList":
					rpt = new VtkSG_GamesTelephoneList();
					rpt.Load("VtkSG_GamesTelephoneList");
					break;
				case "VtkSG_GamesAddressLabels":
					rpt = new VtkSG_GamesAddressLabels();
					rpt.Load("VtkSG_GamesAddressLabels");
					break;
				case "VtkSG_GamesOrganizationRSHours":
					rpt = new VtkSG_GamesOrganizationRSHours();
					rpt.Load("VtkSG_GamesOrganizationRSHours");
					break;
				case "VtkSG_GamesServiceRSHours":
					rpt = new VtkSG_GamesServiceRSHours();
					rpt.Load("VtkSG_GamesServiceRSHours");
					break;
				default:
					break;
			} 
		}

		/// <summary>
		/// Called from CrystalWeb.aspx and NationalCrystalWeb.aspx to load report parameters
		/// from UIReportParams into the CrystalReportViewer web control.
		/// </summary>
		/// <param name="par">UIReportParams object containing report parameters.</param>
		/// <param name="paramFields">ParameterFields object from the CR web control.</param>
		public static void LoadReportParamsWeb(UIReportParams par,
			CrystalDecisions.Shared.ParameterFields paramFields) 
		{
			LoadReportParamsInternal(par, null, paramFields, false);
		}

		/// <summary>
		/// Called from CrystalExport.aspx and NationalCrystalExport.aspx to load report parameters
		/// from UIReportParams into the Crystal report engine.
		/// </summary>
		/// <param name="par">UIReportParams object containing report parameters.</param>
		/// <param name="rpt">The report document, with the report already loaded.</param>
		public static void LoadReportParamsExport(UIReportParams par,
			CrystalDecisions.CrystalReports.Engine.ReportDocument rpt) 
		{
			LoadReportParamsInternal(par, rpt, null, true);
		}
 
		/// <summary>
		/// Called by LoadReportParamsWeb and LoadReportParamsExport. When adding a report to VTK, add
		/// a case to the switch statement below for to export parameters for the report.
		/// </summary>
		/// <param name="par"></param>
		/// <param name="rpt"></param>
		/// <param name="paramFields"></param>
		/// <param name="IsExport"></param>
		private static void LoadReportParamsInternal(UIReportParams par,
			CrystalDecisions.CrystalReports.Engine.ReportDocument rpt,
			CrystalDecisions.Shared.ParameterFields paramFields,
			bool IsExport) 
		{
			switch (par.ReportType.ToString()) 
			{
			// add additional cases for each report type
				case "MasterRecordDisplayPrint":
					if (IsExport) {((VTK.Volunteer.ViewVolunteer.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Volunteer.ViewVolunteer.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkAlphaListOfRSVolunteers":
					if (IsExport) {((VTK.Reports.Alphabetical.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.Alphabetical.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_AnnualVolunteersVS30":
					if (IsExport) {((VTK.Reports.Annual.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.Annual.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkPotentialAwardsListing":
					if (IsExport) {((VTK.Reports.PotentialAwards.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.PotentialAwards.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkPotentialAwardsLabels":
					if (IsExport) {((VTK.Reports.PotentialAwards.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.PotentialAwards.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_AwardsProcessedReport":
					if (IsExport) {((VTK.Reports.AwardsProcessedReport.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.AwardsProcessedReport.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_AwardsProcessedLabels":
					if (IsExport) {((VTK.Reports.AwardsProcessedReport.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.AwardsProcessedReport.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSignInCodeList":
					if (IsExport) {((VTK.Reports.SignInList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.SignInList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkUtilizingServicesSubdivisionsI":
					if (IsExport) {((VTK.National.UtilizingServicesSubdivision.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.UtilizingServicesSubdivision.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkUtilizingServicesSubdivisionsII":
					if (IsExport) {((VTK.National.UtilizingServicesSubdivision.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.UtilizingServicesSubdivision.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkUserRoleByRole":
					if (IsExport) {((VTK.FileMaintenance.UserReport.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.FileMaintenance.UserReport.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkUserRoleByUser":
					if (IsExport) {((VTK.FileMaintenance.UserReport.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.FileMaintenance.UserReport.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkVolunteerAddressLabels":
					if (IsExport) {((VTK.Reports.AddressLabels.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.AddressLabels.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkVolunteerTelephoneList":
					if (IsExport) {((VTK.Reports.TelephoneList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.TelephoneList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// occasional hours by date
				case "VtkSL_OccHoursByDate":
					if (IsExport) {((VTK.Reports.OccHoursByDate.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.OccHoursByDate.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// occasional hours by organization
				case "VtkSL_OccHoursByOrganization":
					if (IsExport) {((VTK.Reports.OccHoursByOrganization.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.OccHoursByOrganization.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// occasional hours by service
				case "VtkSL_OccHoursByService":
					if (IsExport) {((VTK.Reports.OccHoursByService.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.OccHoursByService.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// regular scheduled hours by organization by day
				case "VtkSL_HoursByOrganization_Day":
					if (IsExport) {((VTK.Reports.HoursByOrganization.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.HoursByOrganization.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// regular scheduled hours by organization by day
				case "VtkSL_HoursByService_Day":
					if (IsExport) {((VTK.Reports.HoursByService.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.HoursByService.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// meal ticket form and list (crystal report name .rpt)
				case "VtkSL_VtkMealTicketForm":
					if (IsExport) {((VTK.Reports.MealTicket.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.MealTicket.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkSL_VtkMealTicketList":
					if (IsExport) {((VTK.Reports.MealTicket.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.MealTicket.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// potential termination list
				case "VtkSL_TerminationList_VS07":
					if (IsExport) {((VTK.Reports.TerminationListVS07.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.TerminationListVS07.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// terminated volunteers
				case "VtkSL_TerminatedVolunteers":
					if (IsExport) {((VTK.Reports.TerminatedVolunteers.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.TerminatedVolunteers.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// new volunteers
				case "VtkSL_NewVolunteers":
					if (IsExport) {((VTK.Reports.NewVolunteers.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.NewVolunteers.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// volunteer by using organization and service
				case "VtkSL_OrganizationsRSOccHours_VS26":
					if (IsExport) {((VTK.Reports.VolunteersByUsingOrganizationVS26.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VolunteersByUsingOrganizationVS26.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_ServicesRSOccHours_VS28":
					if (IsExport) {((VTK.Reports.VolunteersByUsingServiceVS28.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VolunteersByUsingServiceVS28.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// volunteer by using organization and service (summary)
				case "VtkSL_OrganizationsRSOccHoursSummary_VS27":
					if (IsExport) {((VTK.Reports.VolunteersByUsingOrganizationSummaryVS27.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VolunteersByUsingOrganizationSummaryVS27.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_ServicesRSOccHoursSummary_VS29":
					if (IsExport) {((VTK.Reports.VolunteersByUsingServiceSummaryVS29.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VolunteersByUsingServiceSummaryVS29.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// volunteer daily review
				case "VtkSL_VolunteerDailyReview":
					if (IsExport) {((VTK.Reports.VolunteerDailyReview.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VolunteerDailyReview.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// voluntary service directory reports
				case "VtkS_VoluntaryStationInformation":
					if (IsExport) {((VTK.Reports.VSDStationInformation.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDStationInformation.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkS_VoluntaryServiceChiefs":
					if (IsExport) {((VTK.Reports.VSDServiceChiefs.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDServiceChiefs.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkS_VoluntaryProgramsSupervised":
					if (IsExport) {((VTK.Reports.VSDProgramsSupervised.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDProgramsSupervised.UIReportParams) par).SetWebParams(paramFields);}
					break; 
		        case "VtkS_VoluntaryPrintDirectory":
					if (IsExport) {((VTK.Reports.VSDServiceDirectory.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDServiceDirectory.UIReportParams) par).SetWebParams(paramFields);}
					break; 
		 		case "VtkS_VoluntarySingleStationInformation":
					if (IsExport) {((VTK.Reports.VSDStationInformationDetail.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDStationInformationDetail.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkS_VoluntaryDirectoryLabels":
					if (IsExport) {((VTK.Reports.VSDDirectoryLabels.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VSDDirectoryLabels.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// voluntary national officials reports
				case "VtkSNO_VoluntaryAllNatRepsLabels":
					if (IsExport) {((VTK.Reports.VNONationalOfficialsLabels.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VNONationalOfficialsLabels.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSNO_VoluntaryAnnualJointReview":
					if (IsExport) {((VTK.Reports.VNOAnnualJointReview.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VNOAnnualJointReview.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSNO_VoluntaryNationalOrganizations":
					if (IsExport) {((VTK.Reports.VNONationalOrganizations.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.VNONationalOrganizations.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// national reports
				case "VtkSN_VoluntaryCommitteeAttendanceListing":
					if (IsExport) {((VTK.National.ReportsCommitteeAttendanceListing.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsCommitteeAttendanceListing.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01":
					if (IsExport) {((VTK.National.ReportsRSOccHoursVS01part1.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsRSOccHoursVS01part1.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01_part2":
					if (IsExport) {((VTK.National.ReportsRSOccHoursVS01part2.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsRSOccHoursVS01part2.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryServicesRSOccHours_VS01_part2_summary":
					if (IsExport) {((VTK.National.ReportsRSOccHoursVS01part2.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsRSOccHoursVS01part2.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part1":
					if (IsExport) {((VTK.National.ReportsRSOccHoursVHA37part1.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsRSOccHoursVHA37part1.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2":
					if (IsExport) {((VTK.National.ReportsRSOccHoursVHA37part2.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsRSOccHoursVHA37part2.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_NACOrganizationsYearlyComparison":
					if (IsExport) {((VTK.National.ReportsNACOrganizationYearlyComparison.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsNACOrganizationYearlyComparison.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSN_VoluntaryDonationsByVISN":
					if (IsExport) {((VTK.National.ReportsDonationsByVISN.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.National.ReportsDonationsByVISN.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSL_DonationReceipt":
					if (IsExport) {((VTK.Reports.DonationMemo.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.DonationMemo.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkSL_DonationReceipt2815":
					if (IsExport) {((VTK.Reports.DonationReceipt.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.DonationReceipt.UIReportParams) par).SetWebParams(paramFields);}
					break;
				// print the donation report from the donation edit
				case "VtkSL_DonationReceipt2815FromEdit":
					if (IsExport) {((VTK.FileMaintenance.DonationPrint.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.FileMaintenance.DonationPrint.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkSL_DonationReceiptFromEdit":
					if (IsExport) {((VTK.FileMaintenance.DonationPrint.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.FileMaintenance.DonationPrint.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkSL_DonationGrandTotalDetail":
					if (IsExport) {((VTK.Reports.DonationsDailyGrandTotal.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.DonationsDailyGrandTotal.UIReportParams) par).SetWebParams(paramFields);}
					break; 
				case "VtkSL_DailyVolunteerList":
					if (IsExport) {((VTK.Reports.DailyVolunteerList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.DailyVolunteerList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				//games reports
				case "VtkSG_DailyWorkSchedule":
					if (IsExport) {((VTK.Reports.GamesDailyWorkSchedule.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesDailyWorkSchedule.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_SignInRosterByName":
					if (IsExport) {((VTK.Reports.GamesSignInRoster.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesSignInRoster.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_SignInRosterBySvc":
					if (IsExport) {((VTK.Reports.GamesSignInRoster.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesSignInRoster.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_MasterRegistrationList":
					if (IsExport) {((VTK.Reports.GamesMasterRegistrationList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesMasterRegistrationList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_ShirtIssueList":
					if (IsExport) {((VTK.Reports.GamesShirtIssueList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesShirtIssueList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_ServiceAssignmentSchedule":
					if (IsExport) {((VTK.Reports.GamesSvcAssignSchedule.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesSvcAssignSchedule.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_GamesTelephoneList":
					if (IsExport) {((VTK.Reports.GamesTelephoneList.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesTelephoneList.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_GamesAddressLabels":
					if (IsExport) {((VTK.Reports.GamesAddressLabels.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesAddressLabels.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_GamesOrganizationRSHours":
					if (IsExport) {((VTK.Reports.GamesOrganizationRSHours.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesOrganizationRSHours.UIReportParams) par).SetWebParams(paramFields);}
					break;
				case "VtkSG_GamesServiceRSHours":
					if (IsExport) {((VTK.Reports.GamesServiceRSHours.UIReportParams) par).SetExportParams(rpt.DataDefinition.ParameterFields);}
					else {((VTK.Reports.GamesServiceRSHours.UIReportParams) par).SetWebParams(paramFields);}
					break;
				default:
					break;
			}
		} 

		/// <summary>
		/// For VTK reports only (not National reports) use this function to get the URL to use when you're 
		/// ready to redirect from a report parameter collection page to the CrystalWeb.aspx page. It returns a 
		/// url of the form (depending on the report type):
		///   "/VTK/RptCR/CrystalWeb.aspx?rpt=VtkVolunteerAddressLabels&StationId=3"
		/// </summary>
		/// <param name="reportType">The type of report</param>
		/// <param name="vtkPageHeader">A reference to the instantiated VtkPageHeader control on the calling page</param>
		/// <param name="requestPhysicalApplicationPath">Pass Request.PhysicalApplicationPath here.</param>
		/// <returns>A string representing the URL to response.redirect to, when transferring to the CrystalWeb.aspx page.</returns>
		/// 
		public static string GetCrystalWebTransferString(UIReportType reportType, VtkPageHeader vtkPageHeader,
			string requestApplicationPath) 
		{
			StringBuilder sb = new StringBuilder(requestApplicationPath+"/RptCR/CrystalWeb.aspx?rpt=");
			sb.Append(reportType.ToString());
			sb.Append("&");
			sb.Append(VtkPageHeader.GetURLParameterString());
			sb.Append("=");
			sb.Append(vtkPageHeader.DivSelectedId.ToString());
			return sb.ToString();
		} 

		/// <summary>
		/// For National reports only, use this function to get the URL to use when you're ready to redirect
		/// from a report parameter collection page to the NationalCrystalWeb.aspx page. It returns a URL of the
		/// form (depending on the report type):
		///   "NationalCrystalWeb.aspx?rpt=VtkAgeGroupCounts"
		/// </summary>
		/// <param name="reportType">UIReportType of the report.</param>
		/// <returns></returns>
		public static string GetNationalCrystalWebTransferString(UIReportType reportType) 
		{
			StringBuilder sb = new StringBuilder("NationalCrystalWeb.aspx?rpt=");
			sb.Append(reportType.ToString());
			return sb.ToString();
		} 

		/// <summary>
		/// Typically used for quickly setting the user-selected report format type into the 
		/// UIReportParams.ReportFormat field. Given one of the following strings ("Web", "Word", "Excel", 
		/// "Acrobat", the possible values the user can choose in the standard UI RadioButton report format list), 
		/// it returns the corresponding UIReportFormat enumeration. If there's no match for the string, the 
		/// function returns UIReportFormat.None. 
		/// </summary>
		/// <param name="format">String to get UIReportParams.ReportFormat for. Currently supported: 
		/// "Web", "Word", "Excel", and "Acrobat".</param>
		/// <returns>Returns the UIReportFormat enumeration corresponding to the string passed. If there's no
		/// match, returns UIReportFormat.None.</returns>
		public static UIReportFormat GetUIReportFormat(string format) 
		{
			UIReportFormat rf = UIReportFormat.None;
			switch (format) 
			{
				case "Web":
					rf=UIReportFormat.Web;
					break;
				case "Word":
					rf=UIReportFormat.Word;
					break;
				case "Excel":
					rf=UIReportFormat.Excel;
					break;
				case "Acrobat":
					rf=UIReportFormat.Acrobat;
					break;
				default:
					break;
			}
			return rf;
		}

		/// <summary>
		/// Sets a single parameter into the CR web control. Mostly for internal use. Given the ParameterFields
		/// object from a CR web control, and a CR parameter name and value, it sets a discrete parameter into
		/// the CR web control.
		/// </summary>
		/// <param name="paramFields">ParameterFields object from a CR web control.</param>
		/// <param name="paramName">Name of the parameter to set.</param>
		/// <param name="paramValue">Value of the parameter to set.</param>
		public static void AddDiscreteParameter(ParameterFields paramFields, string paramName, object paramValue) 
		{
			ParameterDiscreteValue discreteValue = new ParameterDiscreteValue();
			discreteValue.Value=paramValue;
			ParameterField paramField = paramFields[paramName];
			ParameterValues curValues = paramField.CurrentValues;
			curValues.Add(discreteValue);
		}

		/// <summary>
		/// Sets a single range-valued parameter into the CR web control. Mostly for internal use. Given the 
		/// ParameterFields object from a CR web control, and a CR parameter name, start and end values, it 
		/// sets a discrete parameter into the CR web control.
		/// </summary>
		/// <param name="paramFields">ParameterFields object from a CR web control.</param>
		/// <param name="paramName"></param>
		/// <param name="startValue">Start value of the parameter to set.</param>
		/// <param name="endValue">End value of the parameter to set.</param>
		public static void AddRangeParameter(ParameterFields paramFields, string paramName, object startValue, object endValue) 
		{
			// TODO: set start Value to 12am
			// TODO: set end Value to 59:59:59...
			ParameterRangeValue rangeVal=new ParameterRangeValue();
			rangeVal.StartValue=startValue;
			rangeVal.EndValue=endValue;
			rangeVal.LowerBoundType=CrystalDecisions.Shared.RangeBoundType.BoundInclusive;
			rangeVal.UpperBoundType=CrystalDecisions.Shared.RangeBoundType.BoundInclusive;
			rangeVal.Kind=CrystalDecisions.Shared.DiscreteOrRangeKind.RangeValue;
			ParameterField paramField = paramFields[paramName]; 
			ParameterValues curValues = paramField.CurrentValues;
			curValues.Add(rangeVal);
		}		

		/// <summary>
		/// for internal use
		/// </summary>
		/// <param name="reportParamDefs"></param>
		/// <param name="pdv"></param>
		/// <param name="fieldName"></param>
		public static void AddDiscreteParameterExport(ParameterFieldDefinitions reportParamDefs,
			ParameterDiscreteValue pdv, string fieldName)
		{
			ParameterValues currentValues;
			ParameterFieldDefinition paramField = reportParamDefs[fieldName];
			currentValues=paramField.CurrentValues;
			currentValues.Add(pdv);
			paramField.ApplyCurrentValues(currentValues);
		}

		/// <summary>
		/// for internal use
		/// </summary>
		/// <param name="reportParamDefs"></param>
		/// <param name="rv"></param>
		/// <param name="fieldName"></param>
		public static void AddRangeParameterExport(ParameterFieldDefinitions reportParamDefs,
			ParameterRangeValue rv, string fieldName)
		{
			ParameterValues currentValues;
			ParameterFieldDefinition paramField = reportParamDefs[fieldName];
			currentValues=paramField.CurrentValues;
			currentValues.Add(rv);
			paramField.ApplyCurrentValues(currentValues);
		}

		/// <summary>
		/// For internal use by CrystalExport.aspx and NationalCrystalExport.aspx. Sets various export options
		/// dependent on the export format type (Acrobat, Excel or Word).
		/// </summary>
		/// <param name="opts">Crystal Reports options object to set (some) options into</param>
		/// <param name="format">The UIReportFormat (Word, Excel, PDF) of the report</param>
		/// <param name="reportName">The report name (used to create a temporary file for report export)</param>
		/// <param name="physicalApplicationPath">Set this to the application's physical path</param>
		public static void SetExportOptions(CrystalDecisions.Shared.ExportOptions opts, UIReportFormat format, 
			string reportName, string physicalApplicationPath) 
		{
			opts.ExportDestinationType=ExportDestinationType.DiskFile;
			DiskFileDestinationOptions diskOpts = new DiskFileDestinationOptions();
			switch (format)
			{
				case UIReportFormat.Acrobat:
					opts.ExportFormatType=ExportFormatType.PortableDocFormat;
					diskOpts.DiskFileName=physicalApplicationPath+"\\temp\\"+reportName;
					opts.FormatOptions=new PdfRtfWordFormatOptions();
					break;
				case UIReportFormat.Excel:
					opts.ExportFormatType=ExportFormatType.Excel;
					diskOpts.DiskFileName=physicalApplicationPath+"\\temp\\"+reportName;
					opts.FormatOptions=new ExcelFormatOptions();
					break;
				case UIReportFormat.Word:
					opts.ExportFormatType=ExportFormatType.WordForWindows;
					diskOpts.DiskFileName=physicalApplicationPath+"\\temp\\"+reportName;
					opts.FormatOptions=new PdfRtfWordFormatOptions();
					break;
				default:
					break;
			}
			opts.DestinationOptions=diskOpts;
		}

		/// <summary>
		/// For internal use. Given a particular UIReportFormat, it returns the file extension to use with that
		/// report format.
		/// </summary>
		/// <param name="format"></param>
		/// <returns></returns>
		public static string ExportExtension(UIReportFormat format) 
		{
			string returnValue;

			switch (format)
			{
				case UIReportFormat.Acrobat:
					returnValue=".PDF";
					break;
				case UIReportFormat.Excel:
					returnValue=".XLS";
					break;
				case UIReportFormat.Word:
					returnValue=".DOC";
					break;
				default:
					returnValue=".unknown";
					break;
			}
			return returnValue;
		}

		/// <summary>
		/// For internal use by CrystalExport and NationalCrystalExport pages. It generates what should be a unique filename
		/// for the exported reports, based on the end user's NtUsername, and the current date/time down to the
		/// millisecond.
		/// </summary>
		/// <param name="NtUserName">NT Username of the end-user</param>
		/// <returns>Returns what should be a system-unique "name" portion for a temporary file's filename</returns>
		public static string UniqueReportName(string NtUserName) 
		{
			DateTime now = DateTime.Now;
			string reportName = NtUserName.Replace('\\','_')+
				now.Hour.ToString()+now.Minute.ToString()+now.Second.ToString()+
				now.Millisecond.ToString()+now.Ticks.ToString();
			return reportName;
		}

		/// <summary>
		/// For internal use by CrystalExport and NationalCrystalExport pages. It plucks a UIReportParams
		/// object out Context.Items, under the key "ReportParams". If the object is not present, an exception
		/// is thrown.
		/// </summary>
		/// <param name="context"></param>
		/// <returns></returns>
		public static UIReportParams GetParams(System.Web.HttpContext context) 
		{
			// Get params from Context
			UIReportParams par = new UIReportParams();
			if (context.Items["ReportParams"]!=null) 
			{
				par = (UIReportParams) context.Items["ReportParams"];
			} 
			else 
			{
				throw new Exception("Report parameters not found!");
			} 
			return par;
		}
	}

	/// <summary>
	/// This enum contains one enumeration per Crystal Report .RPT. When you add a new report to the VTK project,
	/// add a new enumeration corresponding to the class name of the report (which corresponds to the physical file
	/// name of the report). This enumeration will then be used to load the report, by both "Web" and "Export"
	/// pages.
	/// </summary>
	public enum UIReportType 
	{
		MasterRecordDisplayPrint, 
		VtkAgeGroupCounts,
		VtkAlphaListOfRSVolunteers,
		VtkSL_AnnualVolunteersVS30,
		VtkPotentialAwardsListing,
		VtkPotentialAwardsLabels,
		VtkSL_AwardsProcessedReport,
		VtkSL_AwardsProcessedLabels,
		VtkSignInCodeList,
		VtkUserRoleByRole,
		VtkUserRoleByUser,
		VtkUtilizingServicesSubdivisionsI,
		VtkUtilizingServicesSubdivisionsII,
		VtkVolunteerAddressLabels,
		VtkVolunteerTelephoneList,
		// occasional hours by date
		VtkSL_OccHoursByDate,
		// occasional hours by organization
		VtkSL_OccHoursByOrganization,
		// occasional hours by service
		VtkSL_OccHoursByService,
		// regular scheduled hours by organization by day
		VtkSL_HoursByOrganization_Day,
		// regular scheduled hours by organization by day
		VtkSL_HoursByService_Day,
		// meal ticket (crystal report name .rpt)
		VtkSL_VtkMealTicketForm,
		VtkSL_VtkMealTicketList,
		// potential termination list vs07
		VtkSL_TerminationList_VS07,
		// terminated volunteers
		VtkSL_TerminatedVolunteers,
		// new volunteers
		VtkSL_NewVolunteers,
		// volunteers by using organization VS26 and service VS28
		VtkSL_OrganizationsRSOccHours_VS26,
		VtkSL_ServicesRSOccHours_VS28,
		// volunteers by using organization VS27 and service VS29
		VtkSL_OrganizationsRSOccHoursSummary_VS27,
		VtkSL_ServicesRSOccHoursSummary_VS29,
		// volunteer daily review
		VtkSL_VolunteerDailyReview,
		// voluntary service directory reports
		VtkS_VoluntaryStationInformation,
		VtkS_VoluntaryServiceChiefs,
		VtkS_VoluntaryProgramsSupervised,
		VtkS_VoluntaryPrintDirectory,
		VtkS_VoluntarySingleStationInformation,
		VtkS_VoluntaryDirectoryLabels,
		// voluntary national officials reports
        VtkSNO_VoluntaryAllNatRepsLabels,
		VtkSNO_VoluntaryAnnualJointReview,
		VtkSNO_VoluntaryNationalOrganizations,
		// national reports
		VtkSN_VoluntaryCommitteeAttendanceListing,
		VtkSN_VoluntaryServicesRSOccHours_VS01,
		VtkSN_VoluntaryServicesRSOccHours_VS01_part2,
		VtkSN_VoluntaryServicesRSOccHours_VS01_part2_summary,
		VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part1,
		VtkSN_VoluntaryOrganizationsRSOccHours_VHA37_part2,
		VtkSN_NACOrganizationsYearlyComparison,
		VtkSN_VoluntaryDonationsByVISN,
		VtkSL_DonationReceipt,
		VtkSL_DonationReceipt2815,
		VtkSL_DonationReceipt2815FromEdit,
		VtkSL_DonationReceiptFromEdit,
		VtkSL_DonationGrandTotalDetail,
		VtkSL_DailyVolunteerList,
		// games reports
		VtkSG_DailyWorkSchedule,
		VtkSG_SignInRosterByName,
		VtkSG_SignInRosterBySvc,
		VtkSG_MasterRegistrationList,
		VtkSG_ShirtIssueList,
		VtkSG_ServiceAssignmentSchedule,
		VtkSG_GamesTelephoneList,
		VtkSG_GamesAddressLabels,
		VtkSG_GamesOrganizationRSHours,
		VtkSG_GamesServiceRSHours,
		None
	}

	/// <summary>
	/// Enumerates the acceptable CrystalReport formats used by the VTK application. It is used as the 
	/// property type for one of the property in the UIReportParams class, and is also used as a type in several 
	/// other places.
	/// </summary>
	public enum UIReportFormat { Word, Excel, Acrobat, Web, None }

	/// <summary>
	/// Each report has a unique set of report parameters that must be gathered from the user, and then passed 
	/// to Crystal Reports. And yet in order to have standardized pages for displaying pages to the web 
	/// (CrystalWeb.aspx) or exporting (CrystalExport.aspx), we need to pass report parameters around in a 
	/// standard object. The solution used by VTK reports is to have a base class to hold the common fields and 
	/// functionality needed for all reports. Then each UI page class derives a class from UIReportParams and 
	/// adds fields to hold the specific parameters for each class. Using this base, powerful functionality has 
	/// been added to the UIReportParams class to automate much of the work necessary to pass these parameters 
	/// to Crystal Reports as run-time.
	/// </summary>
	public class UIReportParams
	{
		public UIReportType ReportType;
		public UIReportFormat ReportFormat;

		public UIReportParams() 
		{
			ReportType = UIReportType.None;
			ReportFormat = UIReportFormat.None;
		}

		/// <summary>
		/// When exporting a report, call this function to go through all of the fields you've added to the class
		/// you've derived from UIReportParams. For each field it finds added to the class, it will attempt to 
		/// set a CR parameter of the same name, to the value of the field, for use by the Crystal Engine.  
		///
		/// Three kinds of fields (which must all correspond to parameters to pass to the Crystal Report) are 
		/// currently supported, based on type:
		/// 
		///   * System.Collections.SortedList (holds a list of discrete parameters to set into a CR parameter type
		///     that accepts multiple values for a single parameter)
		///   * UIDateRange (holds a from and a to date, to set into a "RangeValue" CR parameter type for a date 
		///     range
		///   * Any other simple type, which is then set into a CR parameter as-is (Int32, string, etc.)
		///   
		///  Each field you add to classes derived from UIReportParams should be one of these three kinds. 
		///  The name of the field should correspond precisely to the name of the Crystal Reports parameter 
		///  it is representing. If, however, the Crystal Reports parameter begins with "@", begin the field 
		///  name with "AT_".
		/// </summary>
		/// <param name="pfd">The parameter field object from: 
		///    CrystalDecisions.CrystalReports.Engine.ReportDocument.DataDefinition.ParameterFields</param>
		public void SetExportParams(CrystalDecisions.CrystalReports.Engine.ParameterFieldDefinitions pfd) 
		{
			Type myType = this.GetType();
			FieldInfo[] fInfo = myType.GetFields();
			foreach (FieldInfo f in fInfo) 
			{
				switch (f.Name) 
				{
					case "ReportType":
						break;
					case "ReportFormat":
						break;
					default:
						SetExportParamsInternal(pfd, f);
						break;
				}
			}
		}

		/// <summary>
		/// for internal use by UIReportParams.SetExportParams. When SetExportParams finds a field type that 
		/// requires "setting" as a parameter into Crystal Reports, it calls this function. The function decides
		/// what type of Crystal Reports parameter is required, and then sets the Crystal Reports parameter based
		/// on type and on the field name. "AT_" at the beginning of a field name is transformed into "@", as in
		/// "AT_ID" -> "@ID".
		/// </summary>
		/// <param name="pfd"></param>
		/// <param name="myField"></param>
		private void SetExportParamsInternal(CrystalDecisions.CrystalReports.Engine.ParameterFieldDefinitions pfd,
			System.Reflection.FieldInfo myField) 
		{
			if (myField.FieldType.ToString()=="System.Collections.SortedList") 
			{
				//Systems.Collections.SortedList -- loop through each, set one discrete parameter per item found
				ParameterDiscreteValue pdv;
				System.Collections.SortedList myList = (System.Collections.SortedList) myField.GetValue(this);
				foreach (string key in myList.Keys) 
				{
					pdv = new ParameterDiscreteValue();
					pdv.Value=Convert.ToInt32(key);
					RptUtility.AddDiscreteParameterExport(pfd,pdv, GetParamName(myField.Name));
				}
			} 
			else if (myField.FieldType.ToString()=="VTK.Utility.UIDateRange") 
			{
				//UIDateRange -- do a date range, which is a rangevalue
				ParameterRangeValue rv = new ParameterRangeValue();
				VTK.Utility.UIDateRange myDateRange = (VTK.Utility.UIDateRange) myField.GetValue(this);
				rv.StartValue=myDateRange.FromDate;
				rv.EndValue=myDateRange.ToDate;
				RptUtility.AddRangeParameterExport(pfd,rv, GetParamName(myField.Name));
			}
			else 
			{
				//It's a plain old discrete value parameter
				ParameterDiscreteValue pdv = new ParameterDiscreteValue();
				pdv.Value=myField.GetValue(this);
				RptUtility.AddDiscreteParameterExport(pfd, pdv, GetParamName(myField.Name));
			}
		}

		/// <summary>
		/// When displaying a report in the CR web control, call this function to go through all of the fields 
		/// you've added to the class you've derived from UIReportParams. For each field it finds added to the 
		/// class, it will attempt to set a CR parameter of the same name, to the value of the field, for use 
		/// by the CR web control. 
		///
		/// Three kinds of fields (which must all correspond to parameters to pass to the Crystal Report) are 
		/// currently supported, based on type:
		/// 
		///   * System.Collections.SortedList (holds a list of discrete parameters to set into a CR parameter type
		///     that accepts multiple values for a single parameter)
		///   * UIDateRange (holds a from and a to date, to set into a "RangeValue" CR parameter type for a date 
		///     range
		///   * Any other simple type, which is then set into a CR parameter as-is (Int32, string, etc.)
		///   
		///  Each field you add to classes derived from UIReportParams should be one of these three kinds. 
		///  The name of the field should correspond precisely to the name of the Crystal Reports parameter 
		///  it is representing. If, however, the Crystal Reports parameter begins with "@", begin the field 
		///  name with "AT_".
		/// </summary>
		/// <param name="paramFields">The parameter field info object from:
		/// CrystalReportViewer1.ParameterFieldInfo</param>
		public void SetWebParams(CrystalDecisions.Shared.ParameterFields paramFields) 
		{
			Type myType = this.GetType();
			FieldInfo[] fInfo = myType.GetFields();
			foreach (FieldInfo f in fInfo) 
			{
				switch (f.Name) 
				{
					case "ReportType":
						break;
					case "ReportFormat":
						break;
					default:
						SetWebParamsInternal(paramFields, f);
						break;
				}
			}
		}

		/// <summary>
		/// for internal use by UIReportParams.SetWebParams
		/// </summary>
		/// <param name="paramFields"></param>
		/// <param name="myField"></param>
		private void SetWebParamsInternal(CrystalDecisions.Shared.ParameterFields paramFields,
			System.Reflection.FieldInfo myField) 
		{
			if (myField.FieldType.ToString()=="System.Collections.SortedList") 
			{
				//Systems.Collections.SortedList -- loop through each
				System.Collections.SortedList myList = (System.Collections.SortedList) myField.GetValue(this);
				foreach (string key in myList.Keys) 
				{
					RptUtility.AddDiscreteParameter(paramFields, GetParamName(myField.Name),
						Convert.ToInt32(key));				
				}
			} 
			else if (myField.FieldType.ToString()=="VTK.Utility.UIDateRange") 
			{
				//UIDateRange -- do a date range
				VTK.Utility.UIDateRange myDateRange = (VTK.Utility.UIDateRange) myField.GetValue(this);
				RptUtility.AddRangeParameter(paramFields, GetParamName(myField.Name),
					myDateRange.FromDate, myDateRange.ToDate);
			}
			else 
			{
				RptUtility.AddDiscreteParameter(paramFields, GetParamName(myField.Name), myField.GetValue(this));
			}
		}

		/// <summary>
		/// for internal use
		/// </summary>
		/// <param name="fieldName"></param>
		/// <returns></returns>
		private string GetParamName(string fieldName) 
		{
			if (fieldName.Substring(0,3)=="AT_") 
			{
				return "@"+fieldName.Substring(3,fieldName.Length-3);
			} 
			else 
			{
				return fieldName; 
			}
		}
	}

	/// <summary>
	/// 
	/// </summary>
	public class UIDateRange
	{
		public DateTime FromDate;
		public DateTime ToDate;
		public UIDateRange() 
		{
			FromDate=DateTime.MinValue;
			ToDate=DateTime.MinValue;
		}
	}
}
