using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Xml;
using System.Xml.XPath;
using System.Xml.Xsl;

using Vha.Vtk.WebControlLibrary;
using Vha.Vtk.Kernel.Common;
using Vha.Vtk.Kernel.Data.SystemTables;
using VTK.Utility;

namespace VTK.Utility
{
	/// <summary>
	/// Summary description for UserPreference.
	/// </summary>
	public class UserPreference : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button CloseButton;
		protected System.Web.UI.WebControls.ListBox StationList;
		protected System.Web.UI.WebControls.Label ErrorMessage;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			if (!IsPostBack) 
			{
				try 
				{
					//get the list of stations the user can access
					XmlDocument xmlDivisionList = Vha.Vtk.Kernel.Common.ApplicationConnection.GetXmlDivisionList(Page.User.Identity.Name);
					XmlNodeList nodeList = xmlDivisionList.SelectNodes("/DivisionList/Division") ;
					ListItem divItem;
					string defaultDivision = string.Empty ;
					//check if user has a default station
					if (xmlDivisionList.SelectSingleNode("/DivisionList/@DefaultDivision") != null)
					{ defaultDivision = xmlDivisionList.SelectSingleNode("/DivisionList/@DefaultDivision").Value ;}
					//loop thru the stations for this user and add to StationList control
					foreach (XmlNode divNode in nodeList)
					{
						divItem = new ListItem(divNode.Attributes.GetNamedItem("DisplayName").Value, divNode.Attributes.GetNamedItem("Id").Value) ;
						StationList.Items.Add(divItem) ;
						//check if this is the default staion, if yes than mark as selected
						if (defaultDivision == divNode.Attributes.GetNamedItem("Id").Value)
						{
							divItem.Selected = true;
						}						
					}

				} 
				catch (Exception err) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
				}
			} 
			else 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage,"No Station Information Found!");
			}
		}

		private void CloseButton_Click(object sender, System.EventArgs e)
		{
			int usrId ;
			//get the user record using the NTUser Name
			DataSet ulds = Vha.Vtk.Kernel.Data.SystemTables.User.GetUserInfoByNTUserName(Page.User.Identity.Name);
			DataTable uldt = ulds.Tables["UserList"] ;
			//there can be only 1 user record per NTUser Name
			Page.Trace.Warn("RowsOfSites",uldt.Rows.Count.ToString()) ;
			if (uldt.Rows.Count==1) 
			{
				usrId = Convert.ToInt32(uldt.Rows[0]["Id"]) ;
				Vha.Vtk.Kernel.Data.SystemTables.User usrhdl = new Vha.Vtk.Kernel.Data.SystemTables.User(usrId, VtkUtility.GetAppCon());
				//Vha.Vtk.Kernel.Data.SystemTables.User user = new Vha.Vtk.Kernel.Data.SystemTables.User(
					//(int) ds.Tables["UserList"].Rows[0]["Id"], VtkUtility.GetAppCon());
				//save the default station
				usrhdl.DefaultInstitutionId=Convert.ToInt32(StationList.SelectedItem.Value);
				usrhdl.Save();
				usrhdl.Dispose();
			}
			ulds.Dispose();
			uldt.Dispose() ;
			Page.RegisterClientScriptBlock("Close", "<script language=\"javascript\">window.close();</script>");
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.CloseButton.Click += new System.EventHandler(this.CloseButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
