namespace VTK.Volunteer
{
	using System;
	using System.Data;
	using System.Drawing;
	using System.Web;
	using System.Web.UI.WebControls;
	using System.Web.UI.HtmlControls;
	using System.Text.RegularExpressions;

	using VTK.Utility;
	using Vha.Vtk.Kernel.Common;

	/// <summary>
	///		Summary description for VolunteerChooserControl.
	/// </summary>
	public abstract class VolunteerChooserControl : System.Web.UI.UserControl
	{

		const string emptyText="Enter info above and press one of the list buttons";
		private bool volunteerChooserSuccess = false ;
		private int volunteerChooserId = -1 ;
		private string volunteerChooserName = "" ;
		private bool volunteerChooserTerminated = false ;
		private int volunteerChooserStationId = -1 ;
		protected System.Web.UI.WebControls.TextBox NameText;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.TextBox SSNText;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator;
		protected System.Web.UI.WebControls.TextBox CodeText;
		protected System.Web.UI.WebControls.RegularExpressionValidator CodeValidator2;
		protected System.Web.UI.WebControls.ListBox VolunteerList;
		protected System.Web.UI.WebControls.ListBox TermList;
		protected System.Web.UI.WebControls.RegularExpressionValidator NameValidator;

		protected System.Web.UI.HtmlControls.HtmlInputButton GetMoreButton;
		protected System.Web.UI.HtmlControls.HtmlInputButton ChooseButton;


		private void Page_Load(object sender, System.EventArgs e)
		{
			Page.RegisterHiddenField("Action", String.Empty);
			if (!Page.IsPostBack)
			{
				Refresh() ;
			}					
			else
			{
				if(Request.Form["Action"] != null)
				{
					if(Request.Form["Action"] == "RefreshNameButton")
					{
						RefreshName();
					}
					else if (Request.Form["Action"] == "RefreshSSNButton")
					{
						RefreshSSN();
					}
					else if (Request.Form["Action"] == "RefreshCodeButton")
					{
						RefreshCode();
					}
					else if (Request.Form["Action"] == "ChooseButton")
					{
						Choose();
					}
					else if (Request.Form["Action"] == "GetMoreButton")
					{
						GetMore();
					}
				}
			}
		}

		private void Refresh()
		{
			VolunteerList.Items.Clear() ;
			VolunteerList.Items.Add(new ListItem(emptyText,int.MinValue.ToString()));
			VolunteerList.Enabled = false ;
			NameText.Text = string.Empty ;
			SSNText.Text = string.Empty ;
			CodeText.Text = string.Empty ;
			GetMoreButton.Disabled = true;
			ChooseButton.Disabled = true ;
			//GetMoreButton1.Style.Add("font-weigth", "bold");
		}

		private int StationId()
		{
			//return station Id, if zero then no station, search all stations for volunteer
			int stationId = 0 ;
			string station = Request.Form["StationId"] ;
			if (station != string.Empty)
			{ stationId = Convert.ToInt32(station) ;}
			return stationId ;
		}

		protected void PopulateList(SelectCriteria sc)
		{
			int stationId = StationId() ;
			DataSet ds ;
			try
			{
				if (stationId == 0)
				{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerList(sc, VtkUtility.GetAppCon()) ;}
				else
				{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerList(sc, stationId, VtkUtility.GetAppCon()) ;}
				DataTable dt = ds.Tables["VolunteerList"] ;
				if (dt.Rows.Count > 0)
				{
					//enable the choose button and list
					ChooseButton.Disabled = false ;
					VolunteerList.Enabled = true ;
					//define columns in list box
					if (stationId == 0)
					{
						VolunteerList.DataTextField = "DisplayNameWithSSN" ;
						VolunteerList.DataValueField = "IdAndStationId" ;
					}
					else
					{
						VolunteerList.DataTextField = "DisplayName" ;
						VolunteerList.DataValueField = "ID" ;
					}

					//bind list box to DataTable
					VolunteerList.DataSource = dt ;
					VolunteerList.DataBind() ;

					//define column in term list box, this track termination date
					TermList.DataTextField = "TerminationDate" ;
					if (stationId == 0)
					{ TermList.DataValueField = "IdAndStationId" ;}
					else
					{ TermList.DataValueField = "ID" ;}
					TermList.DataSource = dt ;
					TermList.DataBind() ;
					//if only one volunteer, select it
					if (dt.Rows.Count == 1)
					{ VolunteerList.SelectedIndex = 0 ;}
					VolunteerList.Enabled = true ;
				}
				else
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}
				
				ds.Dispose() ;
				dt.Dispose() ;

				if (!sc.AtEnd)
				{
					ViewState["sc"] = sc ;
					GetMoreButton.Disabled = false ;
					//GetMoreButton.Enabled = true ;
					//GetMoreButton.Font.Bold = true ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		private void RefreshName()
		{
			NameText.Text = NameText.Text.ToUpper().Trim() ;

			if (NameText.Text.Length < 1)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first 2 or more characters of the Volunteer's last name and press List") ;}
			else
			{
				SelectCriteria sc = new SelectCriteria() ;
				sc.StartsWith = NameText.Text ;
				sc.MaxRecords = 200 ;
				Refresh() ;
				PopulateList(sc) ;
			}
		}

		private void RefreshSSN()
		{
			if (SSNText.Text.Length < 1)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the Volunteer's 9 digit Social Security Number and press List") ;}
			else
			{
				int stationId = StationId() ;
				string ssn = SSNText.Text ;
				DataSet ds ;
				//if ssn contains dashes, remove
				if (Regex.IsMatch(ssn, @"^\d{3}-\d{2}-\d{4}"))
				{ ssn = ssn.Substring(0,3) + ssn.Substring(4,2) + ssn.Substring(7,4) ;}
				Refresh() ;
				try
				{
					if (stationId == 0)
					{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn) ;}
					else
					{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListBySSN(ssn, stationId) ;}
					DataTable dt = ds.Tables["VolunteerList"] ;

					if (dt.Rows.Count > 0)
					{
						//enable the choose button and list
						ChooseButton.Disabled = false ;
						VolunteerList.Enabled = true ;
						//define columns in list box
						if (stationId == 0)
						{
							VolunteerList.DataTextField = "DisplayNameWithSSN" ;
							VolunteerList.DataValueField = "IdAndStationId" ;
						}
						else
						{
							VolunteerList.DataTextField = "DisplayName" ;
							VolunteerList.DataValueField = "ID" ;
						}

						//bind list box to DataTable and dispose
						VolunteerList.DataSource = dt ;
						VolunteerList.DataBind() ;

						//define column in term list box, this track termination date
						TermList.DataTextField = "TerminationDate" ;
						if (stationId == 0)
						{ TermList.DataValueField = "IdAndStationId" ;}
						else
						{ TermList.DataValueField = "ID" ;}

						TermList.DataSource = dt ;
						TermList.DataBind() ;
						//if only one volunteer, select it
						if (dt.Rows.Count == 1)
						{ VolunteerList.SelectedIndex = 0 ;}
						VolunteerList.Enabled = true ;
					}
					else
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}

					ds.Dispose() ;
					dt.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
			}
		}

		private void RefreshCode()
		{
			if (CodeText.Text.Length < 1)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please enter the first character of the Volunteer's last name and the last 4 digits of their SSN and press List") ;}
			else
			{
				int stationId = StationId() ;
				string code = CodeText.Text.Trim() ;
				DataSet ds ;
				Refresh() ;
				try
				{
					if (stationId == 0)
					{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListByIdentifierCode(code, true) ;}
					else
					{ ds = Vha.Vtk.TimeKeeping.Volunteer.GetVolunteerListByIdentifierCode(code, stationId, true) ;}
					DataTable dt = ds.Tables["VolunteerList"] ;

					if (dt.Rows.Count > 0)
					{
						//enable the choose button and list
						ChooseButton.Disabled = false ;
						VolunteerList.Enabled = true ;
						//define columns in list box
						if (stationId == 0)
						{
							VolunteerList.DataTextField = "DisplayNameWithSSN" ;
							VolunteerList.DataValueField = "IdAndStationId" ;
						}
						else
						{
							VolunteerList.DataTextField = "DisplayName" ;
							VolunteerList.DataValueField = "ID" ;
						}

						//bind list box to DataTable and dispose
						VolunteerList.DataSource = dt ;
						VolunteerList.DataBind() ;

						//define column in term list box, this track termination date
						TermList.DataTextField = "TerminationDate" ;
						if (stationId == 0)
						{ TermList.DataValueField = "IdAndStationId" ;}
						else
						{ TermList.DataValueField = "ID" ;}
						TermList.DataSource = dt ;
						TermList.DataBind() ;
						//if only one volunteer, select it
						if (dt.Rows.Count == 1)
						{ VolunteerList.SelectedIndex = 0 ;}
						VolunteerList.Enabled = true ;
					}
					else
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "No matching volunteers found") ;}

					ds.Dispose() ;
					dt.Dispose() ;
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
			}
		}

		private void Choose()
		{
			string volId ;
			int stationId ;
			string[] vsArray ;
			bool term = false ;
			//check to see if they selected one
			if (VolunteerList.SelectedIndex > -1)
			{
				//volId can be either Id or 'Id&stationId'
				volId = VolunteerList.SelectedItem.Value.ToString() ;
				volunteerChooserName = VolunteerList.SelectedItem.Text.ToString() ;
				volunteerChooserSuccess = true ;

				//also get site id, it is part of id field if no station was given
				stationId = StationId() ;

				//find volunteer and check termination data in list
				foreach (ListItem li in TermList.Items)
				{
					//this is the selected volunteer
					if (li.Value == volId)
					{
						//get termination date & check it exist
						if (li.Text != null)
						{ 
							if (li.Text.ToString() != string.Empty)
							{term = true ;}
						}
						//if stationId is not set, set it and volId
						if (stationId == 0)
						{
							//Value = volunteerId & stationId
							//vsArray[0] = volId, vsArray[1] = stationId
							vsArray = li.Value.Split('&') ;
							stationId = Convert.ToInt32(vsArray[1].ToString()) ;
							volId = vsArray[0].ToString() ;
						}
						break ;
					}
				}

				//set properties
				volunteerChooserId = Convert.ToInt32(volId) ;
				volunteerChooserStationId = stationId ;
				volunteerChooserTerminated = term ;
				Refresh() ;
				RaiseBubbleEvent(this, System.EventArgs.Empty);
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Please select a Volunteer from the list before pressing Choose") ;}
		}
		/// <summary>
		/// Call this method to reset the "True" values in the BubbleEvent properties, once you process an event
		/// bubbled by this control in the container page's OnBubbleEvent(). This will prevent repetitive 
		/// processing, as well as the possibility of an infinite loop, if some other control embedded in the
		/// container page also bubbles an event. 
		/// </summary>
		public void BubbleEventClear() 
		{
			volunteerChooserId=-1;
			volunteerChooserName="";
			volunteerChooserSuccess=false;
			volunteerChooserTerminated=false;
			volunteerChooserStationId=0;
		}

		private void CancelButton_Click(object sender, System.EventArgs e)
		{
			BubbleEventClear() ;
			RaiseBubbleEvent(this, System.EventArgs.Empty);
		}

		private void GetMore()
		{
			SelectCriteria sc = null ;
			//get SelectCriteria from viewstate
			if (ViewState["sc"] != null)
			{ sc = (SelectCriteria) ViewState["sc"] ;}
			PopulateList(sc) ;
		}

		public int VolunteerChooserId 
		{
			get 
			{
				return volunteerChooserId ;
			}
			set
			{
				volunteerChooserId = value ;
			}
		}

		public string VolunteerChooserName 
		{
			get 
			{
				return volunteerChooserName ;
			}
		}

		public bool VolunteerChooserSuccess 
		{
			get
			{
				return volunteerChooserSuccess ;
			}
		}

		public bool VolunteerChooserTerminated 
		{
			get
			{
				return volunteerChooserTerminated ;
			}
		}

		public int VolunteerChooserStationId 
		{
			get 
			{
				return volunteerChooserStationId ;
			}
			set
			{
				volunteerChooserStationId = value ;
			}
		}


		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		///		Required method for Designer support - do not modify
		///		the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
	}
}
