using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;
using System.Text;

using Vha.Vtk.Common;
using Vha.Vtk.Kernel.Common;
using VTK.Utility;
using Vha.Vtk.WebControlLibrary;

namespace VTK.Volunteer
{
	/// <summary>
	/// Summary VoluteerEdit.
	/// input:
	///	 Context.Items["vtkVolunteerChooserId"]
	///	 Context.Items["vtkVolunteerChooserName"]
	/// </summary>
	public class VolunteerEdit : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label ConfirmationMessage;
		protected System.Web.UI.WebControls.ValidationSummary ValidationSummary1;
		protected System.Web.UI.WebControls.Panel EditPanel;
		protected System.Web.UI.WebControls.LinkButton ComboLink;
		protected System.Web.UI.WebControls.LinkButton StationLink;
		protected System.Web.UI.WebControls.LinkButton KinLink;
		protected System.Web.UI.WebControls.LinkButton ContactLink;
		protected System.Web.UI.WebControls.Button PostButton;
		protected System.Web.UI.WebControls.Label ImpreciseMonthLabel;
		protected System.Web.UI.WebControls.Label ImpreciseDayLabel;
		protected Vha.Vtk.WebControlLibrary.VtkCompositeDate DateOfBirthDate;
		protected System.Web.UI.WebControls.CheckBox PseudoCheckBox;
		protected System.Web.UI.WebControls.RegularExpressionValidator SSNValidator;
		protected System.Web.UI.WebControls.TextBox SSNText;
		protected System.Web.UI.WebControls.RadioButtonList SexList;
		protected System.Web.UI.WebControls.TextBox NickNameText;
		protected System.Web.UI.WebControls.TextBox SuffixText;
		protected System.Web.UI.WebControls.TextBox MiddleNameText;
		protected System.Web.UI.WebControls.TextBox FirstNameText;
		protected System.Web.UI.WebControls.TextBox LastNameText;
		protected System.Web.UI.WebControls.Panel ChooserPanel;
		protected Vha.Vtk.WebControlLibrary.VtkPageHeader VtkPageHeader1;
		protected System.Web.UI.WebControls.LinkButton ParkingButton;
		protected System.Web.UI.WebControls.TextBox RemarksText;
		protected System.Web.UI.WebControls.CheckBox VAEmployeeCheck;
		protected System.Web.UI.WebControls.DropDownList LanguageList;
		protected VTK.Volunteer.VolunteerChooserControl VolunteerChooserControl1;
	
		public VolunteerEdit()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			try
			{
				if (VtkPageHeader1.IsDivSelected("Edit Volunteer"))
				{
					if (!Page.IsPostBack)
					{
						//build language list
						DataSet dsL = Vha.Vtk.Kernel.Data.SystemTables.Language.GetQuickList() ;
						DataTable dtL = dsL.Tables["LanguageList"] ;
						LanguageList.DataTextField = "LanguageName" ;
						LanguageList.DataValueField = "ID" ;
						LanguageList.DataSource = dtL ;
						LanguageList.DataBind() ;
						dsL.Dispose() ;
						dtL.Dispose() ;
						if (Page.Request.QueryString.Count > 1)
						{
							if (Page.Request.QueryString["volId"] != null)
							{
								//these inputs come from query strings, these are the subordinate pages
								ViewState["volId"] = Page.Request.QueryString["volId"].ToString() ;
							}
						}
						if (ViewState["volId"] != null)
						{
							GetVolunteerData(Convert.ToInt32(ViewState["volId"])) ;
							//turn off chooser
							ChooserPanel.Visible = false ;
							EditPanel.Visible = true ;
						}
					}
					//save the stationId on the form
					Page.RegisterHiddenField("StationId", VtkPageHeader1.DivSelectedId.ToString()) ;
				}
				else
				{
					Response.Redirect("/Vtk/Welcome.aspx?" + VtkPageHeader.GetURLParameterString()+"=" + VtkPageHeader1.DivSelectedId) ;
				}
			}
			catch (VhaValidationException valErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + valErr.Message) ;}
			catch (VhaTransactionException transErr)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + transErr.Message) ;}
			catch (Exception err)
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error loading the Volunteer Record: " + err.Message) ;}
		}

		override protected bool OnBubbleEvent(object Sender, EventArgs e) 
		{
			bool bubbleValue = false ;
			if (VolunteerChooserControl1.VolunteerChooserSuccess)
			{
				ViewState["volId"] = VolunteerChooserControl1.VolunteerChooserId.ToString() ;
				ViewState["volName"] = VolunteerChooserControl1.VolunteerChooserName.ToString() ;
				ViewState["volTerm"] = VolunteerChooserControl1.VolunteerChooserTerminated.ToString() ;
				VolunteerChooserControl1.BubbleEventClear() ;
				//populate voluteer information
				GetVolunteerData(Convert.ToInt32(ViewState["volId"])) ;
				//turn off chooser
				ChooserPanel.Visible = false ;
				EditPanel.Visible = true ;
				bubbleValue = true ;
			}
			return bubbleValue ;
		}

		private void GetVolunteerData(int volId)
		{
			//create handle
			Vha.Vtk.TimeKeeping.Volunteer volhdl = new Vha.Vtk.TimeKeeping.Volunteer(volId, VtkUtility.GetAppCon()) ;
			//save version & name
			ViewState["volId"] = volId.ToString() ;
			ViewState["version"] = volhdl.Version.ToString() ;
			ViewState["volName"] = volhdl.FullNameForReports.ToString() ;
			//get field values
			LastNameText.Text = volhdl.LastName.ToString() ;
			FirstNameText.Text = volhdl.FirstName.ToString() ;
			MiddleNameText.Text = volhdl.MiddleName.ToString() ;
			NickNameText.Text = volhdl.NickName.ToString() ;
			SuffixText.Text = volhdl.NameSuffix.ToString() ;
			SSNText.Text = volhdl.SocialSecurityNumber.ToString() ;
			PseudoCheckBox.Checked = volhdl.IsPseudoSSN ;
			RemarksText.Text = volhdl.Remarks ;
			VAEmployeeCheck.Checked = volhdl.IsVAEmployee ;
			VtkUtility.SetSelectedSingle(LanguageList.Items, volhdl.PreferredLanguageForLoginId.ToString()) ;
			if (volhdl.Sex == "M")
			{ SexList.SelectedIndex = 0 ;}
			if (volhdl.Sex == "F")
			{ SexList.SelectedIndex = 1 ;}
			//set year list
			DateOfBirthDate.YearListBegin = 1890 ;
			DateOfBirthDate.YearListEnd = DateTime.Now.Year ;
			DateOfBirthDate.InitializeControl() ;
			DateOfBirthDate.Date = volhdl.DateOfBirth ;
			//check if birthdate is imprecise
			if (volhdl.DateOfBirthImprecision == "D")
			{ ImpreciseDayLabel.Visible = true ;}
			if (volhdl.DateOfBirthImprecision == "M")
			{ ImpreciseMonthLabel.Visible = true ;}
			//display message if volunteer has been terminated
			if (Convert.ToBoolean(ViewState["volTerm"]))
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer is TERMINATED") ;}
		}

		private void PostButton_Click(object sender, System.EventArgs e)
		{
			if (ViewState["volId"].ToString() != string.Empty)
			{
				try
				{
					//check that date of birth is valid
					if (DateOfBirthDate.Date == DateTime.MinValue)
					{ VtkUtility.ErrMsgAdd(ErrorMessage, "Date Of Birth is invalid.") ;}
					else
					{
						int volId = Convert.ToInt32(ViewState["volId"]) ;
						string ssn = SSNText.Text ;
						//if ssn contains dashes, remove
						if (Regex.IsMatch(ssn, @"^\d{3}-\d{2}-\d{4}"))
						{ ssn = ssn.Substring(0,3) + ssn.Substring(4,2) + ssn.Substring(7,4) ;}

						Vha.Vtk.TimeKeeping.Volunteer volhdl = new Vha.Vtk.TimeKeeping.Volunteer(volId, VtkUtility.GetAppCon()) ;
						//check version
						if (ViewState["version"].ToString() == volhdl.Version.ToString())
						{
							//post values
							volhdl.LastName = LastNameText.Text.ToString().Trim() ;
							volhdl.FirstName = FirstNameText.Text.ToString().Trim() ;
							volhdl.MiddleName = MiddleNameText.Text.ToString() ;
							volhdl.NickName = NickNameText.Text.ToString() ;
							volhdl.NameSuffix = SuffixText.Text.ToString() ;
							volhdl.SocialSecurityNumber = ssn ;
							//if date of birth was edited, then remove imprecision flag
							if (!(volhdl.DateOfBirth == DateOfBirthDate.Date))
							{
								ImpreciseDayLabel.Visible = false ;
								ImpreciseMonthLabel.Visible = false ;
								volhdl.DateOfBirthImprecision = string.Empty ;
							}
							volhdl.DateOfBirth = DateOfBirthDate.Date ;
							volhdl.IsPseudoSSN = PseudoCheckBox.Checked ;
							volhdl.IsVAEmployee = VAEmployeeCheck.Checked ;
							volhdl.PreferredLanguageForLoginId = Convert.ToInt32(LanguageList.SelectedItem.Value) ;
							volhdl.Remarks = RemarksText.Text ;
							if (SexList.SelectedIndex == 0)
							{ volhdl.Sex = "M" ;}
							if (SexList.SelectedIndex == 1)
							{ volhdl.Sex = "F" ;}

							volhdl.Save() ;
							//reset viewstate so they can repost if they want
							ViewState["volName"] = volhdl.FullNameForReports.ToString() ;
							ViewState["version"] = volhdl.Version.ToString() ;
							volhdl.Dispose() ;
							//update confirmation message
							ConfirmationMessage.Text = "Record Posted!" ;
						}
						else
						{ VtkUtility.ErrMsgAdd(ErrorMessage, "Current Volunteer record has changed while you were editing, Please press EXIT and start over. ") ;}
					}
				}
				catch (VhaValidationException valErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Volunteer Record: " + valErr.Message) ;}
				catch (VhaTransactionException transErr)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Volunteer Record: " + transErr.Message) ;}
				catch (Exception err)
				{ VtkUtility.ErrMsgAdd(ErrorMessage, "There was an error posting the Volunteer Record: " + err.Message) ;}
			}
			else
			{ VtkUtility.ErrMsgAdd(ErrorMessage, "Volunteer selection failed, can't post data") ;}
		}

		private string NavBuilder(string destination)
		{
			//build url string to navigate too, input the destination and add query strings
			StringBuilder sb = new StringBuilder(destination) ;
			sb.Append("?") ;
			//add division
			sb.Append(VtkPageHeader.GetURLParameterString()) ;
			sb.Append("=") ;
			sb.Append(VtkPageHeader1.DivSelectedId.ToString()) ;
			//add volunteer id
			sb.Append("&volId=") ;
			sb.Append(ViewState["volId"]) ;
			//add volunteer name
			sb.Append("&volName=") ;
			sb.Append(ViewState["volName"]) ;
			return sb.ToString() ;
		}

		private void StationLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerStationEdit.aspx")) ;
		}

		private void KinLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerKinEdit.aspx")) ;
		}

		private void ContactLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerMultContactEdit.aspx")) ;
		}

		private void ComboLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerComboEdit.aspx")) ;
		}

		private void ParkingLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerParkingEdit.aspx")) ;
		}

		private void MergeLink_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(NavBuilder("VolunteerChooserMerge.aspx")) ;		
		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.PostButton.Click += new System.EventHandler(this.PostButton_Click);
			this.ContactLink.Click += new System.EventHandler(this.ContactLink_Click);
			this.KinLink.Click += new System.EventHandler(this.KinLink_Click);
			this.StationLink.Click += new System.EventHandler(this.StationLink_Click);
			this.ComboLink.Click += new System.EventHandler(this.ComboLink_Click);
			this.ParkingButton.Click += new System.EventHandler(this.ParkingLink_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

	}
}
