using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using VtkUser.Utility;
using Vha.Vtk.WebControlLibrary;
using System.Resources;
using System.Threading;
using System.Globalization;
using System.Reflection;
using System.Web.Security;
using System.Xml;
using System.Xml.XPath;
using Vha.Vss.Utility;
using Vha.Vtk.TimeKeeping;

namespace VtkUser
{
	/// <summary>
	/// Summary description for ComboCodeChooser.
	/// </summary>
	public class index : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Literal MetaRefresh;
		protected System.Web.UI.WebControls.Label ErrorMessage;
		protected System.Web.UI.WebControls.Label HeadingLabel;
		protected Vha.Vtk.WebControlLibrary.VtkUserPageHeader VtkUserPageHeader1;
		protected System.Web.UI.WebControls.DataGrid DataGrid1;
	
		const string CURRENTLANGUAGECULTURE="CurrentLanguage";
		const string DEFAULTLANGUAGECULTURE="DefaultLanguageCulture";
		const string ALTERNATELANGUAGECULTURE="AlternateLanguageCulture";

		/* EXPECTED INPUT:
		   Context.Items["USERID"]: optional; should be present if index.aspx was bypassed(not displayed to user)
		   ** for the following four items, CONSTs are used for the Context.Items subscripts **
		   Context.Items[INFOVOLFULLNAMEFORREPORTS]: volunteer's full name, for page header control
		   Context.Items[INFOSTATIONID]: station ID, for page header control
		   Context.Items[INFOSTATIONDISPLAYNAME]: station name, for page header control
		   Context.Items[INFOLANGUAGE]: language to use, for page header control
		*/
		public index()
		{
			Page.Init += new System.EventHandler(Page_Init);
		}

		private void Page_Load(object sender, System.EventArgs e)
		{
			// get the userId passed from the login form, write auth cookie if necessary
			int userId = 0;
			if (Context.Items["USERID"]!=null) 
			{
				userId = (int) Context.Items["USERID"];
				Context.Items.Remove("USERID");
				FormsAuthentication.SetAuthCookie(userId.ToString(), false);
			} 
			else 
			{
				userId=Convert.ToInt32(Page.User.Identity.Name);
			}

			if (!IsPostBack) 
			{
				string indexErrorNoCodes;
				LanguageResourcesLoad(out indexErrorNoCodes);
				try 
				{
					VtkUserPageHeader1.VerifyStation();

					string language=VtkUserPageHeader1.CurrentLanguage;
					Thread.CurrentThread.CurrentCulture = CultureInfo.CreateSpecificCulture(language);
					Thread.CurrentThread.CurrentUICulture = Thread.CurrentThread.CurrentCulture;


					// Determine whether multiple combo codes are present for this user. If multiple, give choice
					//   to user. If only one, skip this page and go directly to timecard. If none, give error.

//					DataSet ds = Vha.Vtk.TimeKeeping.CombinationAssignment.GetQuickListForAutoLogin(userId, VtkUserPageHeader1.CurrentStationId);

					NameObjectCollection combList = Vha.Vtk.TimeKeeping.CombinationAssignment.GetQuickListDRForAutoLogin(userId, VtkUserPageHeader1.CurrentStationId);

					DataSet ds = MakeCombinationDS(combList);

					if (ds.Tables["CombinationAssignmentList"].Rows.Count==0) 
					{
						VtkUtility.ErrMsgAdd(ErrorMessage,indexErrorNoCodes);					
					} 
					else if (ds.Tables["CombinationAssignmentList"].Rows.Count==1) 
					{
						// temporary (next line)
						// ds.WriteXml("c:\\temp\\GetActiveQuickList.xml");
						// end of temporary
						Context.Items.Add("CombinationCodeName", ds.Tables["CombinationAssignmentList"].Rows[0]["DisplayName"]);
						Context.Items.Add("OrganizationId", ds.Tables["CombinationAssignmentList"].Rows[0]["OrganizationId"]);
						Context.Items.Add("ScheduleId", ds.Tables["CombinationAssignmentList"].Rows[0]["ScheduleId"]);
						Context.Items.Add("BenefitingServiceId", ds.Tables["CombinationAssignmentList"].Rows[0]["BenefitingServiceId"]); 
						// Context.Items.Add("CombinationCodeDataRow", ds.Tables["CombinationAssignmentList"].Rows[0]);
						Context.Items["USERID"]=userId;
						VtkUserPageHeader1.ServerTransfer("Timecard.aspx");
						//Server.Transfer("Timecard.aspx?"+VtkUserPageHeader.GetURLParameterString()+"="+VtkUserPageHeader1.CurrentStationId);
					} 
					else 
					{
						DataGrid1.DataSource=ds;
						DataGrid1.DataKeyField="Id";
						DataGrid1.DataMember="CombinationAssignmentList";
						DataGrid1.DataBind();
					}
					ds.Dispose();
				} 
				catch (Exception err) 
				{
					VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
				}
			}
			try
			{
				//get the timeout value from web.config, it in in Path
				AppConfiguration VssConfig = new AppConfiguration(Server.MapPath("") + @"\web.config") ;
				VssConfig.Load() ;
				XmlNode ApplicationNode = VssConfig.GetAppConfigData("VssConfiguration", string.Empty) ;
				//save the timeout value and the stationId on form so it can be retrieve in HTML code
				string timeOut = ApplicationNode.Attributes.GetNamedItem("TimeOut").Value;
				string stationId = VtkUserPageHeader1.CurrentStationId.ToString();
				MetaRefresh.Text = "<meta http-equiv=\"refresh\" content=\"" + timeOut + "; url=ThankYou.aspx?StationId=" + stationId + "\">";
			} 
			catch (Exception err) 
			{
				VtkUtility.ErrMsgAdd(ErrorMessage, err.Message);
			}
		}

		private void LanguageResourcesLoad(out string indexErrorNoCodes) 
		{
			Assembly a = Assembly.Load("VtkUser");
			ResourceManager rm = new ResourceManager("VtkUser.strings", a);
			HeadingLabel.Text=rm.GetString("indexHeader");
			indexErrorNoCodes=rm.GetString("indexErrorNoCodes");
			DataGrid1.Columns[1].HeaderText=rm.GetString("txtCode");
			DataGrid1.Columns[2].HeaderText=rm.GetString("txtOrganization");
			DataGrid1.Columns[3].HeaderText=rm.GetString("txtService");
			((ButtonColumn)DataGrid1.Columns[4]).Text=rm.GetString("txtSelect");
		}

		private DataSet MakeCombinationDS(NameObjectCollection combinationList)
		{
			//Create dataset explicitly out of NameObjectCollection object by creating Datatable
			//and add the respective values from the collection into the datarow of the datatable. 
			//12/02/2003. Sachy.
			DataSet ds = new DataSet("CombinationAssignment");

			try
			{

				NameObjectCollection combRec = new NameObjectCollection();
				DataTable dtComb = new DataTable("CombinationAssignmentList");
				DataColumn dcComb;
				DataRow drComb;

				// Create new DataColumn, set DataType, ColumnName and add to DataTable.    
				//Column 1
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "Id";
				string sId="Column1";
				dtComb.Columns.Add(dcComb);
				//Column 2
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(bool);
				dcComb.ColumnName = "IsInactive";
				string sIsInactive="Column2";
				dtComb.Columns.Add(dcComb);
				//Column 3
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "OrganizationId";
				string sOrganizationId="Column3";
				dtComb.Columns.Add(dcComb);
				//Column 4
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(string);
				dcComb.MaxLength = 35;
				dcComb.ColumnName = "OrganizationName";
				string sOrganizationName="Column4";
				dtComb.Columns.Add(dcComb);
				//Column 5
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "StationProfileId";
				string sStationProfileId="Column5";
				dtComb.Columns.Add(dcComb);
				//Column 6
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(string);
				dcComb.MaxLength = 100;
				dcComb.ColumnName = "DisplayName";
				string sDisplayName="Column6";
				dtComb.Columns.Add(dcComb);
				//Column 7
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "ScheduleId";
				string sScheduleId="Column7";
				dtComb.Columns.Add(dcComb);
				//Column 8
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "BenefitingServiceId";
				string sBenefitingServiceId="Column8";
				dtComb.Columns.Add(dcComb);
				//Column 9
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(string);
				dcComb.MaxLength = 35;
				dcComb.ColumnName = "BenefitingServiceName";
				string sBenefitingServiceName="Column9";
				dtComb.Columns.Add(dcComb);
				//Column 10
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(string);
				dcComb.MaxLength = 8;
				dcComb.ColumnName = "CombinationCode";
				string sCombinationCode="Column10";
				dtComb.Columns.Add(dcComb);
				//Column 11
				dcComb= new DataColumn();
				dcComb.DataType  = typeof(bool);
				dcComb.ColumnName = "Inactive";
				string sInactive="Column11";
				dtComb.Columns.Add(dcComb);
				//Column 12
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "StationId";
				string sStationId="Column12";
				dtComb.Columns.Add(dcComb);
				//Column 13
				dcComb= new DataColumn();
				dcComb.DataType = System.Type.GetType("System.Int32");
				dcComb.ColumnName = "VolunteerId";
				string sVolunteerId="Column13";
				dtComb.Columns.Add(dcComb);
				int combCount = 0;

				combCount = combinationList.Count;
				int intCnt;
				for (intCnt=1; intCnt <= combCount; intCnt++)
				{
					combRec = (NameObjectCollection)combinationList.Get(intCnt-1);

					if (combRec.Count > 0)
					{
						drComb = dtComb.NewRow();
						drComb["Id"] = (Int32)combRec.Get(sId);
						drComb["IsInactive"] = (bool)combRec.Get(sIsInactive);
						drComb["OrganizationId"] = (Int32)combRec.Get(sOrganizationId);
						drComb["OrganizationName"] = (string)combRec.Get(sOrganizationName);
						drComb["StationProfileId"] = (Int32)combRec.Get(sStationProfileId);
						drComb["DisplayName"] = (string)combRec.Get(sDisplayName);
						drComb["ScheduleId"] = (Int32)combRec.Get(sScheduleId);
						drComb["BenefitingServiceId"] = (Int32)combRec.Get(sBenefitingServiceId);
						drComb["BenefitingServiceName"] = (string)combRec.Get(sBenefitingServiceName);
						drComb["CombinationCode"] = (string)combRec.Get(sCombinationCode);
						//drComb["Inactive"] = (bool)combRec.Get(sInactive).Equals null;
						if (!combRec.Get(sInactive).Equals(System.DBNull.Value)) drComb["Inactive"] = drComb["Inactive"] = (bool)combRec.Get(sInactive); 
						drComb["StationId"] = (Int32)combRec.Get(sStationId);
						drComb["VolunteerId"] = (Int32)combRec.Get(sVolunteerId);
					
						dtComb.Rows.Add(drComb);
					}
				}

				ds.Tables.Add(dtComb);
				return ds;
			}
			catch (Exception ex)
			{
				return ds;
			}

		}

		private void Page_Init(object sender, EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
		}

		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.VtkUserPageHeader1.Click += new System.EventHandler(this.PageHeader_Click);
			this.DataGrid1.ItemCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.CombinationCode_Select);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void CombinationCode_Select(object source, System.Web.UI.WebControls.DataGridCommandEventArgs e)
		{
			Context.Items.Add("CombinationCodeId", Convert.ToInt32(e.Item.Cells[0].Text));
			Context.Items.Add("CombinationCodeName", e.Item.Cells[5].Text);
			Context.Items.Add("OrganizationId", Convert.ToInt32(e.Item.Cells[6].Text));
			Context.Items.Add("ScheduleId", Convert.ToInt32(e.Item.Cells[7].Text));
			Context.Items.Add("BenefitingServiceId", Convert.ToInt32(e.Item.Cells[8].Text));
			VtkUserPageHeader1.ServerTransfer("Timecard.aspx");
		}

		private void PageHeader_Click(object sender, System.EventArgs e)
		{
			;//
		}
	}
}
